// ============================================================================
// Rocks'n'Diamonds - McDuffin Strikes Back!
// ----------------------------------------------------------------------------
// (c) 1995-2014 by Artsoft Entertainment
//                  Holger Schemel
//                  info@artsoft.org
//                  https://www.artsoft.org/
// ----------------------------------------------------------------------------
// conf_var.c
// ============================================================================

// ------- this file was automatically generated -- do not edit by hand -------

#ifndef CONF_VAR_C
#define CONF_VAR_C

// values for image and layout parameter configuration

struct TokenIntPtrInfo image_config_vars[] =
{
  {
    "[title_initial].fade_mode",
    &title_initial_default.fade_mode
  },
  {
    "[title_initial].fade_mode",
    &title_initial_first_default.fade_mode
  },
  {
    "[title_initial].fade_delay",
    &title_initial_default.fade_delay
  },
  {
    "[title_initial].fade_delay",
    &title_initial_first_default.fade_delay
  },
  {
    "[title_initial].post_delay",
    &title_initial_default.post_delay
  },
  {
    "[title_initial].post_delay",
    &title_initial_first_default.post_delay
  },
  {
    "[title_initial].auto_delay",
    &title_initial_default.auto_delay
  },
  {
    "[title_initial].auto_delay",
    &title_initial_first_default.auto_delay
  },
  {
    "[title_initial].auto_delay_unit",
    &title_initial_default.auto_delay_unit
  },
  {
    "[title_initial].auto_delay_unit",
    &title_initial_first_default.auto_delay_unit
  },
  {
    "[title].fade_mode",
    &title_default.fade_mode
  },
  {
    "[title].fade_mode",
    &title_first_default.fade_mode
  },
  {
    "[title].fade_delay",
    &title_default.fade_delay
  },
  {
    "[title].fade_delay",
    &title_first_default.fade_delay
  },
  {
    "[title].post_delay",
    &title_default.post_delay
  },
  {
    "[title].post_delay",
    &title_first_default.post_delay
  },
  {
    "[title].auto_delay",
    &title_default.auto_delay
  },
  {
    "[title].auto_delay",
    &title_first_default.auto_delay
  },
  {
    "[title].auto_delay_unit",
    &title_default.auto_delay_unit
  },
  {
    "[title].auto_delay_unit",
    &title_first_default.auto_delay_unit
  },
  {
    "[titlescreen_initial].sort_priority",
    &titlescreen_initial_default.sort_priority
  },
  {
    "[titlescreen_initial].fade_mode",
    &titlescreen_initial_default.fade_mode
  },
  {
    "[titlescreen_initial].fade_delay",
    &titlescreen_initial_default.fade_delay
  },
  {
    "[titlescreen_initial].post_delay",
    &titlescreen_initial_default.post_delay
  },
  {
    "[titlescreen_initial].auto_delay",
    &titlescreen_initial_default.auto_delay
  },
  {
    "[titlescreen_initial].auto_delay_unit",
    &titlescreen_initial_default.auto_delay_unit
  },
  {
    "[titlescreen].sort_priority",
    &titlescreen_default.sort_priority
  },
  {
    "[titlescreen].fade_mode",
    &titlescreen_default.fade_mode
  },
  {
    "[titlescreen].fade_delay",
    &titlescreen_default.fade_delay
  },
  {
    "[titlescreen].post_delay",
    &titlescreen_default.post_delay
  },
  {
    "[titlescreen].auto_delay",
    &titlescreen_default.auto_delay
  },
  {
    "[titlescreen].auto_delay_unit",
    &titlescreen_default.auto_delay_unit
  },
  {
    "titlescreen_initial_1.sort_priority",
    &titlescreen_initial[0].sort_priority
  },
  {
    "titlescreen_initial_1.sort_priority",
    &titlescreen_initial_first[0].sort_priority
  },
  {
    "titlescreen_initial_1.fade_mode",
    &titlescreen_initial[0].fade_mode
  },
  {
    "titlescreen_initial_1.fade_mode",
    &titlescreen_initial_first[0].fade_mode
  },
  {
    "titlescreen_initial_1.fade_delay",
    &titlescreen_initial[0].fade_delay
  },
  {
    "titlescreen_initial_1.fade_delay",
    &titlescreen_initial_first[0].fade_delay
  },
  {
    "titlescreen_initial_1.post_delay",
    &titlescreen_initial[0].post_delay
  },
  {
    "titlescreen_initial_1.post_delay",
    &titlescreen_initial_first[0].post_delay
  },
  {
    "titlescreen_initial_1.auto_delay",
    &titlescreen_initial[0].auto_delay
  },
  {
    "titlescreen_initial_1.auto_delay",
    &titlescreen_initial_first[0].auto_delay
  },
  {
    "titlescreen_initial_1.auto_delay_unit",
    &titlescreen_initial[0].auto_delay_unit
  },
  {
    "titlescreen_initial_1.auto_delay_unit",
    &titlescreen_initial_first[0].auto_delay_unit
  },
  {
    "titlescreen_initial_2.sort_priority",
    &titlescreen_initial[1].sort_priority
  },
  {
    "titlescreen_initial_2.sort_priority",
    &titlescreen_initial_first[1].sort_priority
  },
  {
    "titlescreen_initial_2.fade_mode",
    &titlescreen_initial[1].fade_mode
  },
  {
    "titlescreen_initial_2.fade_mode",
    &titlescreen_initial_first[1].fade_mode
  },
  {
    "titlescreen_initial_2.fade_delay",
    &titlescreen_initial[1].fade_delay
  },
  {
    "titlescreen_initial_2.fade_delay",
    &titlescreen_initial_first[1].fade_delay
  },
  {
    "titlescreen_initial_2.post_delay",
    &titlescreen_initial[1].post_delay
  },
  {
    "titlescreen_initial_2.post_delay",
    &titlescreen_initial_first[1].post_delay
  },
  {
    "titlescreen_initial_2.auto_delay",
    &titlescreen_initial[1].auto_delay
  },
  {
    "titlescreen_initial_2.auto_delay",
    &titlescreen_initial_first[1].auto_delay
  },
  {
    "titlescreen_initial_2.auto_delay_unit",
    &titlescreen_initial[1].auto_delay_unit
  },
  {
    "titlescreen_initial_2.auto_delay_unit",
    &titlescreen_initial_first[1].auto_delay_unit
  },
  {
    "titlescreen_initial_3.sort_priority",
    &titlescreen_initial[2].sort_priority
  },
  {
    "titlescreen_initial_3.sort_priority",
    &titlescreen_initial_first[2].sort_priority
  },
  {
    "titlescreen_initial_3.fade_mode",
    &titlescreen_initial[2].fade_mode
  },
  {
    "titlescreen_initial_3.fade_mode",
    &titlescreen_initial_first[2].fade_mode
  },
  {
    "titlescreen_initial_3.fade_delay",
    &titlescreen_initial[2].fade_delay
  },
  {
    "titlescreen_initial_3.fade_delay",
    &titlescreen_initial_first[2].fade_delay
  },
  {
    "titlescreen_initial_3.post_delay",
    &titlescreen_initial[2].post_delay
  },
  {
    "titlescreen_initial_3.post_delay",
    &titlescreen_initial_first[2].post_delay
  },
  {
    "titlescreen_initial_3.auto_delay",
    &titlescreen_initial[2].auto_delay
  },
  {
    "titlescreen_initial_3.auto_delay",
    &titlescreen_initial_first[2].auto_delay
  },
  {
    "titlescreen_initial_3.auto_delay_unit",
    &titlescreen_initial[2].auto_delay_unit
  },
  {
    "titlescreen_initial_3.auto_delay_unit",
    &titlescreen_initial_first[2].auto_delay_unit
  },
  {
    "titlescreen_initial_4.sort_priority",
    &titlescreen_initial[3].sort_priority
  },
  {
    "titlescreen_initial_4.sort_priority",
    &titlescreen_initial_first[3].sort_priority
  },
  {
    "titlescreen_initial_4.fade_mode",
    &titlescreen_initial[3].fade_mode
  },
  {
    "titlescreen_initial_4.fade_mode",
    &titlescreen_initial_first[3].fade_mode
  },
  {
    "titlescreen_initial_4.fade_delay",
    &titlescreen_initial[3].fade_delay
  },
  {
    "titlescreen_initial_4.fade_delay",
    &titlescreen_initial_first[3].fade_delay
  },
  {
    "titlescreen_initial_4.post_delay",
    &titlescreen_initial[3].post_delay
  },
  {
    "titlescreen_initial_4.post_delay",
    &titlescreen_initial_first[3].post_delay
  },
  {
    "titlescreen_initial_4.auto_delay",
    &titlescreen_initial[3].auto_delay
  },
  {
    "titlescreen_initial_4.auto_delay",
    &titlescreen_initial_first[3].auto_delay
  },
  {
    "titlescreen_initial_4.auto_delay_unit",
    &titlescreen_initial[3].auto_delay_unit
  },
  {
    "titlescreen_initial_4.auto_delay_unit",
    &titlescreen_initial_first[3].auto_delay_unit
  },
  {
    "titlescreen_initial_5.sort_priority",
    &titlescreen_initial[4].sort_priority
  },
  {
    "titlescreen_initial_5.sort_priority",
    &titlescreen_initial_first[4].sort_priority
  },
  {
    "titlescreen_initial_5.fade_mode",
    &titlescreen_initial[4].fade_mode
  },
  {
    "titlescreen_initial_5.fade_mode",
    &titlescreen_initial_first[4].fade_mode
  },
  {
    "titlescreen_initial_5.fade_delay",
    &titlescreen_initial[4].fade_delay
  },
  {
    "titlescreen_initial_5.fade_delay",
    &titlescreen_initial_first[4].fade_delay
  },
  {
    "titlescreen_initial_5.post_delay",
    &titlescreen_initial[4].post_delay
  },
  {
    "titlescreen_initial_5.post_delay",
    &titlescreen_initial_first[4].post_delay
  },
  {
    "titlescreen_initial_5.auto_delay",
    &titlescreen_initial[4].auto_delay
  },
  {
    "titlescreen_initial_5.auto_delay",
    &titlescreen_initial_first[4].auto_delay
  },
  {
    "titlescreen_initial_5.auto_delay_unit",
    &titlescreen_initial[4].auto_delay_unit
  },
  {
    "titlescreen_initial_5.auto_delay_unit",
    &titlescreen_initial_first[4].auto_delay_unit
  },
  {
    "titlescreen_1.sort_priority",
    &titlescreen[0].sort_priority
  },
  {
    "titlescreen_1.sort_priority",
    &titlescreen_first[0].sort_priority
  },
  {
    "titlescreen_1.fade_mode",
    &titlescreen[0].fade_mode
  },
  {
    "titlescreen_1.fade_mode",
    &titlescreen_first[0].fade_mode
  },
  {
    "titlescreen_1.fade_delay",
    &titlescreen[0].fade_delay
  },
  {
    "titlescreen_1.fade_delay",
    &titlescreen_first[0].fade_delay
  },
  {
    "titlescreen_1.post_delay",
    &titlescreen[0].post_delay
  },
  {
    "titlescreen_1.post_delay",
    &titlescreen_first[0].post_delay
  },
  {
    "titlescreen_1.auto_delay",
    &titlescreen[0].auto_delay
  },
  {
    "titlescreen_1.auto_delay",
    &titlescreen_first[0].auto_delay
  },
  {
    "titlescreen_1.auto_delay_unit",
    &titlescreen[0].auto_delay_unit
  },
  {
    "titlescreen_1.auto_delay_unit",
    &titlescreen_first[0].auto_delay_unit
  },
  {
    "titlescreen_2.sort_priority",
    &titlescreen[1].sort_priority
  },
  {
    "titlescreen_2.sort_priority",
    &titlescreen_first[1].sort_priority
  },
  {
    "titlescreen_2.fade_mode",
    &titlescreen[1].fade_mode
  },
  {
    "titlescreen_2.fade_mode",
    &titlescreen_first[1].fade_mode
  },
  {
    "titlescreen_2.fade_delay",
    &titlescreen[1].fade_delay
  },
  {
    "titlescreen_2.fade_delay",
    &titlescreen_first[1].fade_delay
  },
  {
    "titlescreen_2.post_delay",
    &titlescreen[1].post_delay
  },
  {
    "titlescreen_2.post_delay",
    &titlescreen_first[1].post_delay
  },
  {
    "titlescreen_2.auto_delay",
    &titlescreen[1].auto_delay
  },
  {
    "titlescreen_2.auto_delay",
    &titlescreen_first[1].auto_delay
  },
  {
    "titlescreen_2.auto_delay_unit",
    &titlescreen[1].auto_delay_unit
  },
  {
    "titlescreen_2.auto_delay_unit",
    &titlescreen_first[1].auto_delay_unit
  },
  {
    "titlescreen_3.sort_priority",
    &titlescreen[2].sort_priority
  },
  {
    "titlescreen_3.sort_priority",
    &titlescreen_first[2].sort_priority
  },
  {
    "titlescreen_3.fade_mode",
    &titlescreen[2].fade_mode
  },
  {
    "titlescreen_3.fade_mode",
    &titlescreen_first[2].fade_mode
  },
  {
    "titlescreen_3.fade_delay",
    &titlescreen[2].fade_delay
  },
  {
    "titlescreen_3.fade_delay",
    &titlescreen_first[2].fade_delay
  },
  {
    "titlescreen_3.post_delay",
    &titlescreen[2].post_delay
  },
  {
    "titlescreen_3.post_delay",
    &titlescreen_first[2].post_delay
  },
  {
    "titlescreen_3.auto_delay",
    &titlescreen[2].auto_delay
  },
  {
    "titlescreen_3.auto_delay",
    &titlescreen_first[2].auto_delay
  },
  {
    "titlescreen_3.auto_delay_unit",
    &titlescreen[2].auto_delay_unit
  },
  {
    "titlescreen_3.auto_delay_unit",
    &titlescreen_first[2].auto_delay_unit
  },
  {
    "titlescreen_4.sort_priority",
    &titlescreen[3].sort_priority
  },
  {
    "titlescreen_4.sort_priority",
    &titlescreen_first[3].sort_priority
  },
  {
    "titlescreen_4.fade_mode",
    &titlescreen[3].fade_mode
  },
  {
    "titlescreen_4.fade_mode",
    &titlescreen_first[3].fade_mode
  },
  {
    "titlescreen_4.fade_delay",
    &titlescreen[3].fade_delay
  },
  {
    "titlescreen_4.fade_delay",
    &titlescreen_first[3].fade_delay
  },
  {
    "titlescreen_4.post_delay",
    &titlescreen[3].post_delay
  },
  {
    "titlescreen_4.post_delay",
    &titlescreen_first[3].post_delay
  },
  {
    "titlescreen_4.auto_delay",
    &titlescreen[3].auto_delay
  },
  {
    "titlescreen_4.auto_delay",
    &titlescreen_first[3].auto_delay
  },
  {
    "titlescreen_4.auto_delay_unit",
    &titlescreen[3].auto_delay_unit
  },
  {
    "titlescreen_4.auto_delay_unit",
    &titlescreen_first[3].auto_delay_unit
  },
  {
    "titlescreen_5.sort_priority",
    &titlescreen[4].sort_priority
  },
  {
    "titlescreen_5.sort_priority",
    &titlescreen_first[4].sort_priority
  },
  {
    "titlescreen_5.fade_mode",
    &titlescreen[4].fade_mode
  },
  {
    "titlescreen_5.fade_mode",
    &titlescreen_first[4].fade_mode
  },
  {
    "titlescreen_5.fade_delay",
    &titlescreen[4].fade_delay
  },
  {
    "titlescreen_5.fade_delay",
    &titlescreen_first[4].fade_delay
  },
  {
    "titlescreen_5.post_delay",
    &titlescreen[4].post_delay
  },
  {
    "titlescreen_5.post_delay",
    &titlescreen_first[4].post_delay
  },
  {
    "titlescreen_5.auto_delay",
    &titlescreen[4].auto_delay
  },
  {
    "titlescreen_5.auto_delay",
    &titlescreen_first[4].auto_delay
  },
  {
    "titlescreen_5.auto_delay_unit",
    &titlescreen[4].auto_delay_unit
  },
  {
    "titlescreen_5.auto_delay_unit",
    &titlescreen_first[4].auto_delay_unit
  },
  {
    "[titlemessage_initial].x",
    &titlemessage_initial_default.x
  },
  {
    "[titlemessage_initial].y",
    &titlemessage_initial_default.y
  },
  {
    "[titlemessage_initial].width",
    &titlemessage_initial_default.width
  },
  {
    "[titlemessage_initial].height",
    &titlemessage_initial_default.height
  },
  {
    "[titlemessage_initial].chars",
    &titlemessage_initial_default.chars
  },
  {
    "[titlemessage_initial].lines",
    &titlemessage_initial_default.lines
  },
  {
    "[titlemessage_initial].align",
    &titlemessage_initial_default.align
  },
  {
    "[titlemessage_initial].valign",
    &titlemessage_initial_default.valign
  },
  {
    "[titlemessage_initial].font",
    &titlemessage_initial_default.font
  },
  {
    "[titlemessage_initial].autowrap",
    &titlemessage_initial_default.autowrap
  },
  {
    "[titlemessage_initial].centered",
    &titlemessage_initial_default.centered
  },
  {
    "[titlemessage_initial].parse_comments",
    &titlemessage_initial_default.parse_comments
  },
  {
    "[titlemessage_initial].sort_priority",
    &titlemessage_initial_default.sort_priority
  },
  {
    "[titlemessage_initial].fade_mode",
    &titlemessage_initial_default.fade_mode
  },
  {
    "[titlemessage_initial].fade_delay",
    &titlemessage_initial_default.fade_delay
  },
  {
    "[titlemessage_initial].post_delay",
    &titlemessage_initial_default.post_delay
  },
  {
    "[titlemessage_initial].auto_delay",
    &titlemessage_initial_default.auto_delay
  },
  {
    "[titlemessage_initial].auto_delay_unit",
    &titlemessage_initial_default.auto_delay_unit
  },
  {
    "[titlemessage].x",
    &titlemessage_default.x
  },
  {
    "[titlemessage].y",
    &titlemessage_default.y
  },
  {
    "[titlemessage].width",
    &titlemessage_default.width
  },
  {
    "[titlemessage].height",
    &titlemessage_default.height
  },
  {
    "[titlemessage].chars",
    &titlemessage_default.chars
  },
  {
    "[titlemessage].lines",
    &titlemessage_default.lines
  },
  {
    "[titlemessage].align",
    &titlemessage_default.align
  },
  {
    "[titlemessage].valign",
    &titlemessage_default.valign
  },
  {
    "[titlemessage].font",
    &titlemessage_default.font
  },
  {
    "[titlemessage].autowrap",
    &titlemessage_default.autowrap
  },
  {
    "[titlemessage].centered",
    &titlemessage_default.centered
  },
  {
    "[titlemessage].parse_comments",
    &titlemessage_default.parse_comments
  },
  {
    "[titlemessage].sort_priority",
    &titlemessage_default.sort_priority
  },
  {
    "[titlemessage].fade_mode",
    &titlemessage_default.fade_mode
  },
  {
    "[titlemessage].fade_delay",
    &titlemessage_default.fade_delay
  },
  {
    "[titlemessage].post_delay",
    &titlemessage_default.post_delay
  },
  {
    "[titlemessage].auto_delay",
    &titlemessage_default.auto_delay
  },
  {
    "[titlemessage].auto_delay_unit",
    &titlemessage_default.auto_delay_unit
  },
  {
    "titlemessage_initial_1.x",
    &titlemessage_initial[0].x
  },
  {
    "titlemessage_initial_1.x",
    &titlemessage_initial_first[0].x
  },
  {
    "titlemessage_initial_1.y",
    &titlemessage_initial[0].y
  },
  {
    "titlemessage_initial_1.y",
    &titlemessage_initial_first[0].y
  },
  {
    "titlemessage_initial_1.width",
    &titlemessage_initial[0].width
  },
  {
    "titlemessage_initial_1.width",
    &titlemessage_initial_first[0].width
  },
  {
    "titlemessage_initial_1.height",
    &titlemessage_initial[0].height
  },
  {
    "titlemessage_initial_1.height",
    &titlemessage_initial_first[0].height
  },
  {
    "titlemessage_initial_1.chars",
    &titlemessage_initial[0].chars
  },
  {
    "titlemessage_initial_1.chars",
    &titlemessage_initial_first[0].chars
  },
  {
    "titlemessage_initial_1.lines",
    &titlemessage_initial[0].lines
  },
  {
    "titlemessage_initial_1.lines",
    &titlemessage_initial_first[0].lines
  },
  {
    "titlemessage_initial_1.align",
    &titlemessage_initial[0].align
  },
  {
    "titlemessage_initial_1.align",
    &titlemessage_initial_first[0].align
  },
  {
    "titlemessage_initial_1.valign",
    &titlemessage_initial[0].valign
  },
  {
    "titlemessage_initial_1.valign",
    &titlemessage_initial_first[0].valign
  },
  {
    "titlemessage_initial_1.font",
    &titlemessage_initial[0].font
  },
  {
    "titlemessage_initial_1.font",
    &titlemessage_initial_first[0].font
  },
  {
    "titlemessage_initial_1.autowrap",
    &titlemessage_initial[0].autowrap
  },
  {
    "titlemessage_initial_1.autowrap",
    &titlemessage_initial_first[0].autowrap
  },
  {
    "titlemessage_initial_1.centered",
    &titlemessage_initial[0].centered
  },
  {
    "titlemessage_initial_1.centered",
    &titlemessage_initial_first[0].centered
  },
  {
    "titlemessage_initial_1.parse_comments",
    &titlemessage_initial[0].parse_comments
  },
  {
    "titlemessage_initial_1.parse_comments",
    &titlemessage_initial_first[0].parse_comments
  },
  {
    "titlemessage_initial_1.sort_priority",
    &titlemessage_initial[0].sort_priority
  },
  {
    "titlemessage_initial_1.sort_priority",
    &titlemessage_initial_first[0].sort_priority
  },
  {
    "titlemessage_initial_1.fade_mode",
    &titlemessage_initial[0].fade_mode
  },
  {
    "titlemessage_initial_1.fade_mode",
    &titlemessage_initial_first[0].fade_mode
  },
  {
    "titlemessage_initial_1.fade_delay",
    &titlemessage_initial[0].fade_delay
  },
  {
    "titlemessage_initial_1.fade_delay",
    &titlemessage_initial_first[0].fade_delay
  },
  {
    "titlemessage_initial_1.post_delay",
    &titlemessage_initial[0].post_delay
  },
  {
    "titlemessage_initial_1.post_delay",
    &titlemessage_initial_first[0].post_delay
  },
  {
    "titlemessage_initial_1.auto_delay",
    &titlemessage_initial[0].auto_delay
  },
  {
    "titlemessage_initial_1.auto_delay",
    &titlemessage_initial_first[0].auto_delay
  },
  {
    "titlemessage_initial_1.auto_delay_unit",
    &titlemessage_initial[0].auto_delay_unit
  },
  {
    "titlemessage_initial_1.auto_delay_unit",
    &titlemessage_initial_first[0].auto_delay_unit
  },
  {
    "titlemessage_initial_2.x",
    &titlemessage_initial[1].x
  },
  {
    "titlemessage_initial_2.x",
    &titlemessage_initial_first[1].x
  },
  {
    "titlemessage_initial_2.y",
    &titlemessage_initial[1].y
  },
  {
    "titlemessage_initial_2.y",
    &titlemessage_initial_first[1].y
  },
  {
    "titlemessage_initial_2.width",
    &titlemessage_initial[1].width
  },
  {
    "titlemessage_initial_2.width",
    &titlemessage_initial_first[1].width
  },
  {
    "titlemessage_initial_2.height",
    &titlemessage_initial[1].height
  },
  {
    "titlemessage_initial_2.height",
    &titlemessage_initial_first[1].height
  },
  {
    "titlemessage_initial_2.chars",
    &titlemessage_initial[1].chars
  },
  {
    "titlemessage_initial_2.chars",
    &titlemessage_initial_first[1].chars
  },
  {
    "titlemessage_initial_2.lines",
    &titlemessage_initial[1].lines
  },
  {
    "titlemessage_initial_2.lines",
    &titlemessage_initial_first[1].lines
  },
  {
    "titlemessage_initial_2.align",
    &titlemessage_initial[1].align
  },
  {
    "titlemessage_initial_2.align",
    &titlemessage_initial_first[1].align
  },
  {
    "titlemessage_initial_2.valign",
    &titlemessage_initial[1].valign
  },
  {
    "titlemessage_initial_2.valign",
    &titlemessage_initial_first[1].valign
  },
  {
    "titlemessage_initial_2.font",
    &titlemessage_initial[1].font
  },
  {
    "titlemessage_initial_2.font",
    &titlemessage_initial_first[1].font
  },
  {
    "titlemessage_initial_2.autowrap",
    &titlemessage_initial[1].autowrap
  },
  {
    "titlemessage_initial_2.autowrap",
    &titlemessage_initial_first[1].autowrap
  },
  {
    "titlemessage_initial_2.centered",
    &titlemessage_initial[1].centered
  },
  {
    "titlemessage_initial_2.centered",
    &titlemessage_initial_first[1].centered
  },
  {
    "titlemessage_initial_2.parse_comments",
    &titlemessage_initial[1].parse_comments
  },
  {
    "titlemessage_initial_2.parse_comments",
    &titlemessage_initial_first[1].parse_comments
  },
  {
    "titlemessage_initial_2.sort_priority",
    &titlemessage_initial[1].sort_priority
  },
  {
    "titlemessage_initial_2.sort_priority",
    &titlemessage_initial_first[1].sort_priority
  },
  {
    "titlemessage_initial_2.fade_mode",
    &titlemessage_initial[1].fade_mode
  },
  {
    "titlemessage_initial_2.fade_mode",
    &titlemessage_initial_first[1].fade_mode
  },
  {
    "titlemessage_initial_2.fade_delay",
    &titlemessage_initial[1].fade_delay
  },
  {
    "titlemessage_initial_2.fade_delay",
    &titlemessage_initial_first[1].fade_delay
  },
  {
    "titlemessage_initial_2.post_delay",
    &titlemessage_initial[1].post_delay
  },
  {
    "titlemessage_initial_2.post_delay",
    &titlemessage_initial_first[1].post_delay
  },
  {
    "titlemessage_initial_2.auto_delay",
    &titlemessage_initial[1].auto_delay
  },
  {
    "titlemessage_initial_2.auto_delay",
    &titlemessage_initial_first[1].auto_delay
  },
  {
    "titlemessage_initial_2.auto_delay_unit",
    &titlemessage_initial[1].auto_delay_unit
  },
  {
    "titlemessage_initial_2.auto_delay_unit",
    &titlemessage_initial_first[1].auto_delay_unit
  },
  {
    "titlemessage_initial_3.x",
    &titlemessage_initial[2].x
  },
  {
    "titlemessage_initial_3.x",
    &titlemessage_initial_first[2].x
  },
  {
    "titlemessage_initial_3.y",
    &titlemessage_initial[2].y
  },
  {
    "titlemessage_initial_3.y",
    &titlemessage_initial_first[2].y
  },
  {
    "titlemessage_initial_3.width",
    &titlemessage_initial[2].width
  },
  {
    "titlemessage_initial_3.width",
    &titlemessage_initial_first[2].width
  },
  {
    "titlemessage_initial_3.height",
    &titlemessage_initial[2].height
  },
  {
    "titlemessage_initial_3.height",
    &titlemessage_initial_first[2].height
  },
  {
    "titlemessage_initial_3.chars",
    &titlemessage_initial[2].chars
  },
  {
    "titlemessage_initial_3.chars",
    &titlemessage_initial_first[2].chars
  },
  {
    "titlemessage_initial_3.lines",
    &titlemessage_initial[2].lines
  },
  {
    "titlemessage_initial_3.lines",
    &titlemessage_initial_first[2].lines
  },
  {
    "titlemessage_initial_3.align",
    &titlemessage_initial[2].align
  },
  {
    "titlemessage_initial_3.align",
    &titlemessage_initial_first[2].align
  },
  {
    "titlemessage_initial_3.valign",
    &titlemessage_initial[2].valign
  },
  {
    "titlemessage_initial_3.valign",
    &titlemessage_initial_first[2].valign
  },
  {
    "titlemessage_initial_3.font",
    &titlemessage_initial[2].font
  },
  {
    "titlemessage_initial_3.font",
    &titlemessage_initial_first[2].font
  },
  {
    "titlemessage_initial_3.autowrap",
    &titlemessage_initial[2].autowrap
  },
  {
    "titlemessage_initial_3.autowrap",
    &titlemessage_initial_first[2].autowrap
  },
  {
    "titlemessage_initial_3.centered",
    &titlemessage_initial[2].centered
  },
  {
    "titlemessage_initial_3.centered",
    &titlemessage_initial_first[2].centered
  },
  {
    "titlemessage_initial_3.parse_comments",
    &titlemessage_initial[2].parse_comments
  },
  {
    "titlemessage_initial_3.parse_comments",
    &titlemessage_initial_first[2].parse_comments
  },
  {
    "titlemessage_initial_3.sort_priority",
    &titlemessage_initial[2].sort_priority
  },
  {
    "titlemessage_initial_3.sort_priority",
    &titlemessage_initial_first[2].sort_priority
  },
  {
    "titlemessage_initial_3.fade_mode",
    &titlemessage_initial[2].fade_mode
  },
  {
    "titlemessage_initial_3.fade_mode",
    &titlemessage_initial_first[2].fade_mode
  },
  {
    "titlemessage_initial_3.fade_delay",
    &titlemessage_initial[2].fade_delay
  },
  {
    "titlemessage_initial_3.fade_delay",
    &titlemessage_initial_first[2].fade_delay
  },
  {
    "titlemessage_initial_3.post_delay",
    &titlemessage_initial[2].post_delay
  },
  {
    "titlemessage_initial_3.post_delay",
    &titlemessage_initial_first[2].post_delay
  },
  {
    "titlemessage_initial_3.auto_delay",
    &titlemessage_initial[2].auto_delay
  },
  {
    "titlemessage_initial_3.auto_delay",
    &titlemessage_initial_first[2].auto_delay
  },
  {
    "titlemessage_initial_3.auto_delay_unit",
    &titlemessage_initial[2].auto_delay_unit
  },
  {
    "titlemessage_initial_3.auto_delay_unit",
    &titlemessage_initial_first[2].auto_delay_unit
  },
  {
    "titlemessage_initial_4.x",
    &titlemessage_initial[3].x
  },
  {
    "titlemessage_initial_4.x",
    &titlemessage_initial_first[3].x
  },
  {
    "titlemessage_initial_4.y",
    &titlemessage_initial[3].y
  },
  {
    "titlemessage_initial_4.y",
    &titlemessage_initial_first[3].y
  },
  {
    "titlemessage_initial_4.width",
    &titlemessage_initial[3].width
  },
  {
    "titlemessage_initial_4.width",
    &titlemessage_initial_first[3].width
  },
  {
    "titlemessage_initial_4.height",
    &titlemessage_initial[3].height
  },
  {
    "titlemessage_initial_4.height",
    &titlemessage_initial_first[3].height
  },
  {
    "titlemessage_initial_4.chars",
    &titlemessage_initial[3].chars
  },
  {
    "titlemessage_initial_4.chars",
    &titlemessage_initial_first[3].chars
  },
  {
    "titlemessage_initial_4.lines",
    &titlemessage_initial[3].lines
  },
  {
    "titlemessage_initial_4.lines",
    &titlemessage_initial_first[3].lines
  },
  {
    "titlemessage_initial_4.align",
    &titlemessage_initial[3].align
  },
  {
    "titlemessage_initial_4.align",
    &titlemessage_initial_first[3].align
  },
  {
    "titlemessage_initial_4.valign",
    &titlemessage_initial[3].valign
  },
  {
    "titlemessage_initial_4.valign",
    &titlemessage_initial_first[3].valign
  },
  {
    "titlemessage_initial_4.font",
    &titlemessage_initial[3].font
  },
  {
    "titlemessage_initial_4.font",
    &titlemessage_initial_first[3].font
  },
  {
    "titlemessage_initial_4.autowrap",
    &titlemessage_initial[3].autowrap
  },
  {
    "titlemessage_initial_4.autowrap",
    &titlemessage_initial_first[3].autowrap
  },
  {
    "titlemessage_initial_4.centered",
    &titlemessage_initial[3].centered
  },
  {
    "titlemessage_initial_4.centered",
    &titlemessage_initial_first[3].centered
  },
  {
    "titlemessage_initial_4.parse_comments",
    &titlemessage_initial[3].parse_comments
  },
  {
    "titlemessage_initial_4.parse_comments",
    &titlemessage_initial_first[3].parse_comments
  },
  {
    "titlemessage_initial_4.sort_priority",
    &titlemessage_initial[3].sort_priority
  },
  {
    "titlemessage_initial_4.sort_priority",
    &titlemessage_initial_first[3].sort_priority
  },
  {
    "titlemessage_initial_4.fade_mode",
    &titlemessage_initial[3].fade_mode
  },
  {
    "titlemessage_initial_4.fade_mode",
    &titlemessage_initial_first[3].fade_mode
  },
  {
    "titlemessage_initial_4.fade_delay",
    &titlemessage_initial[3].fade_delay
  },
  {
    "titlemessage_initial_4.fade_delay",
    &titlemessage_initial_first[3].fade_delay
  },
  {
    "titlemessage_initial_4.post_delay",
    &titlemessage_initial[3].post_delay
  },
  {
    "titlemessage_initial_4.post_delay",
    &titlemessage_initial_first[3].post_delay
  },
  {
    "titlemessage_initial_4.auto_delay",
    &titlemessage_initial[3].auto_delay
  },
  {
    "titlemessage_initial_4.auto_delay",
    &titlemessage_initial_first[3].auto_delay
  },
  {
    "titlemessage_initial_4.auto_delay_unit",
    &titlemessage_initial[3].auto_delay_unit
  },
  {
    "titlemessage_initial_4.auto_delay_unit",
    &titlemessage_initial_first[3].auto_delay_unit
  },
  {
    "titlemessage_initial_5.x",
    &titlemessage_initial[4].x
  },
  {
    "titlemessage_initial_5.x",
    &titlemessage_initial_first[4].x
  },
  {
    "titlemessage_initial_5.y",
    &titlemessage_initial[4].y
  },
  {
    "titlemessage_initial_5.y",
    &titlemessage_initial_first[4].y
  },
  {
    "titlemessage_initial_5.width",
    &titlemessage_initial[4].width
  },
  {
    "titlemessage_initial_5.width",
    &titlemessage_initial_first[4].width
  },
  {
    "titlemessage_initial_5.height",
    &titlemessage_initial[4].height
  },
  {
    "titlemessage_initial_5.height",
    &titlemessage_initial_first[4].height
  },
  {
    "titlemessage_initial_5.chars",
    &titlemessage_initial[4].chars
  },
  {
    "titlemessage_initial_5.chars",
    &titlemessage_initial_first[4].chars
  },
  {
    "titlemessage_initial_5.lines",
    &titlemessage_initial[4].lines
  },
  {
    "titlemessage_initial_5.lines",
    &titlemessage_initial_first[4].lines
  },
  {
    "titlemessage_initial_5.align",
    &titlemessage_initial[4].align
  },
  {
    "titlemessage_initial_5.align",
    &titlemessage_initial_first[4].align
  },
  {
    "titlemessage_initial_5.valign",
    &titlemessage_initial[4].valign
  },
  {
    "titlemessage_initial_5.valign",
    &titlemessage_initial_first[4].valign
  },
  {
    "titlemessage_initial_5.font",
    &titlemessage_initial[4].font
  },
  {
    "titlemessage_initial_5.font",
    &titlemessage_initial_first[4].font
  },
  {
    "titlemessage_initial_5.autowrap",
    &titlemessage_initial[4].autowrap
  },
  {
    "titlemessage_initial_5.autowrap",
    &titlemessage_initial_first[4].autowrap
  },
  {
    "titlemessage_initial_5.centered",
    &titlemessage_initial[4].centered
  },
  {
    "titlemessage_initial_5.centered",
    &titlemessage_initial_first[4].centered
  },
  {
    "titlemessage_initial_5.parse_comments",
    &titlemessage_initial[4].parse_comments
  },
  {
    "titlemessage_initial_5.parse_comments",
    &titlemessage_initial_first[4].parse_comments
  },
  {
    "titlemessage_initial_5.sort_priority",
    &titlemessage_initial[4].sort_priority
  },
  {
    "titlemessage_initial_5.sort_priority",
    &titlemessage_initial_first[4].sort_priority
  },
  {
    "titlemessage_initial_5.fade_mode",
    &titlemessage_initial[4].fade_mode
  },
  {
    "titlemessage_initial_5.fade_mode",
    &titlemessage_initial_first[4].fade_mode
  },
  {
    "titlemessage_initial_5.fade_delay",
    &titlemessage_initial[4].fade_delay
  },
  {
    "titlemessage_initial_5.fade_delay",
    &titlemessage_initial_first[4].fade_delay
  },
  {
    "titlemessage_initial_5.post_delay",
    &titlemessage_initial[4].post_delay
  },
  {
    "titlemessage_initial_5.post_delay",
    &titlemessage_initial_first[4].post_delay
  },
  {
    "titlemessage_initial_5.auto_delay",
    &titlemessage_initial[4].auto_delay
  },
  {
    "titlemessage_initial_5.auto_delay",
    &titlemessage_initial_first[4].auto_delay
  },
  {
    "titlemessage_initial_5.auto_delay_unit",
    &titlemessage_initial[4].auto_delay_unit
  },
  {
    "titlemessage_initial_5.auto_delay_unit",
    &titlemessage_initial_first[4].auto_delay_unit
  },
  {
    "titlemessage_1.x",
    &titlemessage[0].x
  },
  {
    "titlemessage_1.x",
    &titlemessage_first[0].x
  },
  {
    "titlemessage_1.y",
    &titlemessage[0].y
  },
  {
    "titlemessage_1.y",
    &titlemessage_first[0].y
  },
  {
    "titlemessage_1.width",
    &titlemessage[0].width
  },
  {
    "titlemessage_1.width",
    &titlemessage_first[0].width
  },
  {
    "titlemessage_1.height",
    &titlemessage[0].height
  },
  {
    "titlemessage_1.height",
    &titlemessage_first[0].height
  },
  {
    "titlemessage_1.chars",
    &titlemessage[0].chars
  },
  {
    "titlemessage_1.chars",
    &titlemessage_first[0].chars
  },
  {
    "titlemessage_1.lines",
    &titlemessage[0].lines
  },
  {
    "titlemessage_1.lines",
    &titlemessage_first[0].lines
  },
  {
    "titlemessage_1.align",
    &titlemessage[0].align
  },
  {
    "titlemessage_1.align",
    &titlemessage_first[0].align
  },
  {
    "titlemessage_1.valign",
    &titlemessage[0].valign
  },
  {
    "titlemessage_1.valign",
    &titlemessage_first[0].valign
  },
  {
    "titlemessage_1.font",
    &titlemessage[0].font
  },
  {
    "titlemessage_1.font",
    &titlemessage_first[0].font
  },
  {
    "titlemessage_1.autowrap",
    &titlemessage[0].autowrap
  },
  {
    "titlemessage_1.autowrap",
    &titlemessage_first[0].autowrap
  },
  {
    "titlemessage_1.centered",
    &titlemessage[0].centered
  },
  {
    "titlemessage_1.centered",
    &titlemessage_first[0].centered
  },
  {
    "titlemessage_1.parse_comments",
    &titlemessage[0].parse_comments
  },
  {
    "titlemessage_1.parse_comments",
    &titlemessage_first[0].parse_comments
  },
  {
    "titlemessage_1.sort_priority",
    &titlemessage[0].sort_priority
  },
  {
    "titlemessage_1.sort_priority",
    &titlemessage_first[0].sort_priority
  },
  {
    "titlemessage_1.fade_mode",
    &titlemessage[0].fade_mode
  },
  {
    "titlemessage_1.fade_mode",
    &titlemessage_first[0].fade_mode
  },
  {
    "titlemessage_1.fade_delay",
    &titlemessage[0].fade_delay
  },
  {
    "titlemessage_1.fade_delay",
    &titlemessage_first[0].fade_delay
  },
  {
    "titlemessage_1.post_delay",
    &titlemessage[0].post_delay
  },
  {
    "titlemessage_1.post_delay",
    &titlemessage_first[0].post_delay
  },
  {
    "titlemessage_1.auto_delay",
    &titlemessage[0].auto_delay
  },
  {
    "titlemessage_1.auto_delay",
    &titlemessage_first[0].auto_delay
  },
  {
    "titlemessage_1.auto_delay_unit",
    &titlemessage[0].auto_delay_unit
  },
  {
    "titlemessage_1.auto_delay_unit",
    &titlemessage_first[0].auto_delay_unit
  },
  {
    "titlemessage_2.x",
    &titlemessage[1].x
  },
  {
    "titlemessage_2.x",
    &titlemessage_first[1].x
  },
  {
    "titlemessage_2.y",
    &titlemessage[1].y
  },
  {
    "titlemessage_2.y",
    &titlemessage_first[1].y
  },
  {
    "titlemessage_2.width",
    &titlemessage[1].width
  },
  {
    "titlemessage_2.width",
    &titlemessage_first[1].width
  },
  {
    "titlemessage_2.height",
    &titlemessage[1].height
  },
  {
    "titlemessage_2.height",
    &titlemessage_first[1].height
  },
  {
    "titlemessage_2.chars",
    &titlemessage[1].chars
  },
  {
    "titlemessage_2.chars",
    &titlemessage_first[1].chars
  },
  {
    "titlemessage_2.lines",
    &titlemessage[1].lines
  },
  {
    "titlemessage_2.lines",
    &titlemessage_first[1].lines
  },
  {
    "titlemessage_2.align",
    &titlemessage[1].align
  },
  {
    "titlemessage_2.align",
    &titlemessage_first[1].align
  },
  {
    "titlemessage_2.valign",
    &titlemessage[1].valign
  },
  {
    "titlemessage_2.valign",
    &titlemessage_first[1].valign
  },
  {
    "titlemessage_2.font",
    &titlemessage[1].font
  },
  {
    "titlemessage_2.font",
    &titlemessage_first[1].font
  },
  {
    "titlemessage_2.autowrap",
    &titlemessage[1].autowrap
  },
  {
    "titlemessage_2.autowrap",
    &titlemessage_first[1].autowrap
  },
  {
    "titlemessage_2.centered",
    &titlemessage[1].centered
  },
  {
    "titlemessage_2.centered",
    &titlemessage_first[1].centered
  },
  {
    "titlemessage_2.parse_comments",
    &titlemessage[1].parse_comments
  },
  {
    "titlemessage_2.parse_comments",
    &titlemessage_first[1].parse_comments
  },
  {
    "titlemessage_2.sort_priority",
    &titlemessage[1].sort_priority
  },
  {
    "titlemessage_2.sort_priority",
    &titlemessage_first[1].sort_priority
  },
  {
    "titlemessage_2.fade_mode",
    &titlemessage[1].fade_mode
  },
  {
    "titlemessage_2.fade_mode",
    &titlemessage_first[1].fade_mode
  },
  {
    "titlemessage_2.fade_delay",
    &titlemessage[1].fade_delay
  },
  {
    "titlemessage_2.fade_delay",
    &titlemessage_first[1].fade_delay
  },
  {
    "titlemessage_2.post_delay",
    &titlemessage[1].post_delay
  },
  {
    "titlemessage_2.post_delay",
    &titlemessage_first[1].post_delay
  },
  {
    "titlemessage_2.auto_delay",
    &titlemessage[1].auto_delay
  },
  {
    "titlemessage_2.auto_delay",
    &titlemessage_first[1].auto_delay
  },
  {
    "titlemessage_2.auto_delay_unit",
    &titlemessage[1].auto_delay_unit
  },
  {
    "titlemessage_2.auto_delay_unit",
    &titlemessage_first[1].auto_delay_unit
  },
  {
    "titlemessage_3.x",
    &titlemessage[2].x
  },
  {
    "titlemessage_3.x",
    &titlemessage_first[2].x
  },
  {
    "titlemessage_3.y",
    &titlemessage[2].y
  },
  {
    "titlemessage_3.y",
    &titlemessage_first[2].y
  },
  {
    "titlemessage_3.width",
    &titlemessage[2].width
  },
  {
    "titlemessage_3.width",
    &titlemessage_first[2].width
  },
  {
    "titlemessage_3.height",
    &titlemessage[2].height
  },
  {
    "titlemessage_3.height",
    &titlemessage_first[2].height
  },
  {
    "titlemessage_3.chars",
    &titlemessage[2].chars
  },
  {
    "titlemessage_3.chars",
    &titlemessage_first[2].chars
  },
  {
    "titlemessage_3.lines",
    &titlemessage[2].lines
  },
  {
    "titlemessage_3.lines",
    &titlemessage_first[2].lines
  },
  {
    "titlemessage_3.align",
    &titlemessage[2].align
  },
  {
    "titlemessage_3.align",
    &titlemessage_first[2].align
  },
  {
    "titlemessage_3.valign",
    &titlemessage[2].valign
  },
  {
    "titlemessage_3.valign",
    &titlemessage_first[2].valign
  },
  {
    "titlemessage_3.font",
    &titlemessage[2].font
  },
  {
    "titlemessage_3.font",
    &titlemessage_first[2].font
  },
  {
    "titlemessage_3.autowrap",
    &titlemessage[2].autowrap
  },
  {
    "titlemessage_3.autowrap",
    &titlemessage_first[2].autowrap
  },
  {
    "titlemessage_3.centered",
    &titlemessage[2].centered
  },
  {
    "titlemessage_3.centered",
    &titlemessage_first[2].centered
  },
  {
    "titlemessage_3.parse_comments",
    &titlemessage[2].parse_comments
  },
  {
    "titlemessage_3.parse_comments",
    &titlemessage_first[2].parse_comments
  },
  {
    "titlemessage_3.sort_priority",
    &titlemessage[2].sort_priority
  },
  {
    "titlemessage_3.sort_priority",
    &titlemessage_first[2].sort_priority
  },
  {
    "titlemessage_3.fade_mode",
    &titlemessage[2].fade_mode
  },
  {
    "titlemessage_3.fade_mode",
    &titlemessage_first[2].fade_mode
  },
  {
    "titlemessage_3.fade_delay",
    &titlemessage[2].fade_delay
  },
  {
    "titlemessage_3.fade_delay",
    &titlemessage_first[2].fade_delay
  },
  {
    "titlemessage_3.post_delay",
    &titlemessage[2].post_delay
  },
  {
    "titlemessage_3.post_delay",
    &titlemessage_first[2].post_delay
  },
  {
    "titlemessage_3.auto_delay",
    &titlemessage[2].auto_delay
  },
  {
    "titlemessage_3.auto_delay",
    &titlemessage_first[2].auto_delay
  },
  {
    "titlemessage_3.auto_delay_unit",
    &titlemessage[2].auto_delay_unit
  },
  {
    "titlemessage_3.auto_delay_unit",
    &titlemessage_first[2].auto_delay_unit
  },
  {
    "titlemessage_4.x",
    &titlemessage[3].x
  },
  {
    "titlemessage_4.x",
    &titlemessage_first[3].x
  },
  {
    "titlemessage_4.y",
    &titlemessage[3].y
  },
  {
    "titlemessage_4.y",
    &titlemessage_first[3].y
  },
  {
    "titlemessage_4.width",
    &titlemessage[3].width
  },
  {
    "titlemessage_4.width",
    &titlemessage_first[3].width
  },
  {
    "titlemessage_4.height",
    &titlemessage[3].height
  },
  {
    "titlemessage_4.height",
    &titlemessage_first[3].height
  },
  {
    "titlemessage_4.chars",
    &titlemessage[3].chars
  },
  {
    "titlemessage_4.chars",
    &titlemessage_first[3].chars
  },
  {
    "titlemessage_4.lines",
    &titlemessage[3].lines
  },
  {
    "titlemessage_4.lines",
    &titlemessage_first[3].lines
  },
  {
    "titlemessage_4.align",
    &titlemessage[3].align
  },
  {
    "titlemessage_4.align",
    &titlemessage_first[3].align
  },
  {
    "titlemessage_4.valign",
    &titlemessage[3].valign
  },
  {
    "titlemessage_4.valign",
    &titlemessage_first[3].valign
  },
  {
    "titlemessage_4.font",
    &titlemessage[3].font
  },
  {
    "titlemessage_4.font",
    &titlemessage_first[3].font
  },
  {
    "titlemessage_4.autowrap",
    &titlemessage[3].autowrap
  },
  {
    "titlemessage_4.autowrap",
    &titlemessage_first[3].autowrap
  },
  {
    "titlemessage_4.centered",
    &titlemessage[3].centered
  },
  {
    "titlemessage_4.centered",
    &titlemessage_first[3].centered
  },
  {
    "titlemessage_4.parse_comments",
    &titlemessage[3].parse_comments
  },
  {
    "titlemessage_4.parse_comments",
    &titlemessage_first[3].parse_comments
  },
  {
    "titlemessage_4.sort_priority",
    &titlemessage[3].sort_priority
  },
  {
    "titlemessage_4.sort_priority",
    &titlemessage_first[3].sort_priority
  },
  {
    "titlemessage_4.fade_mode",
    &titlemessage[3].fade_mode
  },
  {
    "titlemessage_4.fade_mode",
    &titlemessage_first[3].fade_mode
  },
  {
    "titlemessage_4.fade_delay",
    &titlemessage[3].fade_delay
  },
  {
    "titlemessage_4.fade_delay",
    &titlemessage_first[3].fade_delay
  },
  {
    "titlemessage_4.post_delay",
    &titlemessage[3].post_delay
  },
  {
    "titlemessage_4.post_delay",
    &titlemessage_first[3].post_delay
  },
  {
    "titlemessage_4.auto_delay",
    &titlemessage[3].auto_delay
  },
  {
    "titlemessage_4.auto_delay",
    &titlemessage_first[3].auto_delay
  },
  {
    "titlemessage_4.auto_delay_unit",
    &titlemessage[3].auto_delay_unit
  },
  {
    "titlemessage_4.auto_delay_unit",
    &titlemessage_first[3].auto_delay_unit
  },
  {
    "titlemessage_5.x",
    &titlemessage[4].x
  },
  {
    "titlemessage_5.x",
    &titlemessage_first[4].x
  },
  {
    "titlemessage_5.y",
    &titlemessage[4].y
  },
  {
    "titlemessage_5.y",
    &titlemessage_first[4].y
  },
  {
    "titlemessage_5.width",
    &titlemessage[4].width
  },
  {
    "titlemessage_5.width",
    &titlemessage_first[4].width
  },
  {
    "titlemessage_5.height",
    &titlemessage[4].height
  },
  {
    "titlemessage_5.height",
    &titlemessage_first[4].height
  },
  {
    "titlemessage_5.chars",
    &titlemessage[4].chars
  },
  {
    "titlemessage_5.chars",
    &titlemessage_first[4].chars
  },
  {
    "titlemessage_5.lines",
    &titlemessage[4].lines
  },
  {
    "titlemessage_5.lines",
    &titlemessage_first[4].lines
  },
  {
    "titlemessage_5.align",
    &titlemessage[4].align
  },
  {
    "titlemessage_5.align",
    &titlemessage_first[4].align
  },
  {
    "titlemessage_5.valign",
    &titlemessage[4].valign
  },
  {
    "titlemessage_5.valign",
    &titlemessage_first[4].valign
  },
  {
    "titlemessage_5.font",
    &titlemessage[4].font
  },
  {
    "titlemessage_5.font",
    &titlemessage_first[4].font
  },
  {
    "titlemessage_5.autowrap",
    &titlemessage[4].autowrap
  },
  {
    "titlemessage_5.autowrap",
    &titlemessage_first[4].autowrap
  },
  {
    "titlemessage_5.centered",
    &titlemessage[4].centered
  },
  {
    "titlemessage_5.centered",
    &titlemessage_first[4].centered
  },
  {
    "titlemessage_5.parse_comments",
    &titlemessage[4].parse_comments
  },
  {
    "titlemessage_5.parse_comments",
    &titlemessage_first[4].parse_comments
  },
  {
    "titlemessage_5.sort_priority",
    &titlemessage[4].sort_priority
  },
  {
    "titlemessage_5.sort_priority",
    &titlemessage_first[4].sort_priority
  },
  {
    "titlemessage_5.fade_mode",
    &titlemessage[4].fade_mode
  },
  {
    "titlemessage_5.fade_mode",
    &titlemessage_first[4].fade_mode
  },
  {
    "titlemessage_5.fade_delay",
    &titlemessage[4].fade_delay
  },
  {
    "titlemessage_5.fade_delay",
    &titlemessage_first[4].fade_delay
  },
  {
    "titlemessage_5.post_delay",
    &titlemessage[4].post_delay
  },
  {
    "titlemessage_5.post_delay",
    &titlemessage_first[4].post_delay
  },
  {
    "titlemessage_5.auto_delay",
    &titlemessage[4].auto_delay
  },
  {
    "titlemessage_5.auto_delay",
    &titlemessage_first[4].auto_delay
  },
  {
    "titlemessage_5.auto_delay_unit",
    &titlemessage[4].auto_delay_unit
  },
  {
    "titlemessage_5.auto_delay_unit",
    &titlemessage_first[4].auto_delay_unit
  },
  {
    "readme.x",
    &readme.x
  },
  {
    "readme.y",
    &readme.y
  },
  {
    "readme.width",
    &readme.width
  },
  {
    "readme.height",
    &readme.height
  },
  {
    "readme.chars",
    &readme.chars
  },
  {
    "readme.lines",
    &readme.lines
  },
  {
    "readme.align",
    &readme.align
  },
  {
    "readme.valign",
    &readme.valign
  },
  {
    "readme.font",
    &readme.font
  },
  {
    "readme.autowrap",
    &readme.autowrap
  },
  {
    "readme.centered",
    &readme.centered
  },
  {
    "readme.parse_comments",
    &readme.parse_comments
  },
  {
    "readme.sort_priority",
    &readme.sort_priority
  },
  {
    "global.num_toons",
    &global.num_toons
  },
  {
    "border.draw_masked.TITLE",
    &border.draw_masked[GFX_SPECIAL_ARG_TITLE]
  },
  {
    "border.draw_masked.MAIN",
    &border.draw_masked[GFX_SPECIAL_ARG_MAIN]
  },
  {
    "border.draw_masked.NAMES",
    &border.draw_masked[GFX_SPECIAL_ARG_NAMES]
  },
  {
    "border.draw_masked.LEVELS",
    &border.draw_masked[GFX_SPECIAL_ARG_LEVELS]
  },
  {
    "border.draw_masked.LEVELNR",
    &border.draw_masked[GFX_SPECIAL_ARG_LEVELNR]
  },
  {
    "border.draw_masked.SCORES",
    &border.draw_masked[GFX_SPECIAL_ARG_SCORES]
  },
  {
    "border.draw_masked.EDITOR",
    &border.draw_masked[GFX_SPECIAL_ARG_EDITOR]
  },
  {
    "border.draw_masked.INFO",
    &border.draw_masked[GFX_SPECIAL_ARG_INFO]
  },
  {
    "border.draw_masked.SETUP",
    &border.draw_masked[GFX_SPECIAL_ARG_SETUP]
  },
  {
    "border.draw_masked.PLAYING",
    &border.draw_masked[GFX_SPECIAL_ARG_PLAYING]
  },
  {
    "border.draw_masked.DOOR",
    &border.draw_masked[GFX_SPECIAL_ARG_DOOR]
  },
  {
    "border.draw_masked_when_fading",
    &border.draw_masked_when_fading
  },
  {
    "init.busy.x",
    &init.busy.x
  },
  {
    "init.busy.y",
    &init.busy.y
  },
  {
    "init.busy.align",
    &init.busy.align
  },
  {
    "init.busy.valign",
    &init.busy.valign
  },
  {
    "menu.enter_menu.fade_mode",
    &menu.enter_menu.fade_mode
  },
  {
    "menu.enter_menu.fade_delay",
    &menu.enter_menu.fade_delay
  },
  {
    "menu.enter_menu.post_delay",
    &menu.enter_menu.post_delay
  },
  {
    "menu.leave_menu.fade_mode",
    &menu.leave_menu.fade_mode
  },
  {
    "menu.leave_menu.fade_delay",
    &menu.leave_menu.fade_delay
  },
  {
    "menu.leave_menu.post_delay",
    &menu.leave_menu.post_delay
  },
  {
    "menu.enter_screen.fade_mode",
    &menu.enter_screen[GFX_SPECIAL_ARG_DEFAULT].fade_mode
  },
  {
    "menu.enter_screen.fade_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_DEFAULT].fade_delay
  },
  {
    "menu.enter_screen.post_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_DEFAULT].post_delay
  },
  {
    "menu.leave_screen.fade_mode",
    &menu.leave_screen[GFX_SPECIAL_ARG_DEFAULT].fade_mode
  },
  {
    "menu.leave_screen.fade_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_DEFAULT].fade_delay
  },
  {
    "menu.leave_screen.post_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_DEFAULT].post_delay
  },
  {
    "menu.next_screen.fade_mode",
    &menu.next_screen[GFX_SPECIAL_ARG_DEFAULT].fade_mode
  },
  {
    "menu.next_screen.fade_delay",
    &menu.next_screen[GFX_SPECIAL_ARG_DEFAULT].fade_delay
  },
  {
    "menu.next_screen.post_delay",
    &menu.next_screen[GFX_SPECIAL_ARG_DEFAULT].post_delay
  },
  {
    "menu.enter_screen.TITLE.fade_mode",
    &menu.enter_screen[GFX_SPECIAL_ARG_TITLE].fade_mode
  },
  {
    "menu.enter_screen.TITLE.fade_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_TITLE].fade_delay
  },
  {
    "menu.enter_screen.TITLE.post_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_TITLE].post_delay
  },
  {
    "menu.enter_screen.TITLE.auto_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_TITLE].auto_delay
  },
  {
    "menu.enter_screen.TITLE.auto_delay_unit",
    &menu.enter_screen[GFX_SPECIAL_ARG_TITLE].auto_delay_unit
  },
  {
    "menu.enter_screen.SCORES.fade_mode",
    &menu.enter_screen[GFX_SPECIAL_ARG_SCORES].fade_mode
  },
  {
    "menu.enter_screen.SCORES.fade_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_SCORES].fade_delay
  },
  {
    "menu.enter_screen.SCORES.post_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_SCORES].post_delay
  },
  {
    "menu.enter_screen.EDITOR.fade_mode",
    &menu.enter_screen[GFX_SPECIAL_ARG_EDITOR].fade_mode
  },
  {
    "menu.enter_screen.EDITOR.fade_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_EDITOR].fade_delay
  },
  {
    "menu.enter_screen.EDITOR.post_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_EDITOR].post_delay
  },
  {
    "menu.enter_screen.INFO.fade_mode",
    &menu.enter_screen[GFX_SPECIAL_ARG_INFO].fade_mode
  },
  {
    "menu.enter_screen.INFO.fade_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_INFO].fade_delay
  },
  {
    "menu.enter_screen.INFO.post_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_INFO].post_delay
  },
  {
    "menu.enter_screen.PLAYING.fade_mode",
    &menu.enter_screen[GFX_SPECIAL_ARG_PLAYING].fade_mode
  },
  {
    "menu.enter_screen.PLAYING.fade_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_PLAYING].fade_delay
  },
  {
    "menu.enter_screen.PLAYING.post_delay",
    &menu.enter_screen[GFX_SPECIAL_ARG_PLAYING].post_delay
  },
  {
    "menu.leave_screen.TITLE.fade_mode",
    &menu.leave_screen[GFX_SPECIAL_ARG_TITLE].fade_mode
  },
  {
    "menu.leave_screen.TITLE.fade_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_TITLE].fade_delay
  },
  {
    "menu.leave_screen.TITLE.post_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_TITLE].post_delay
  },
  {
    "menu.leave_screen.TITLE.auto_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_TITLE].auto_delay
  },
  {
    "menu.leave_screen.TITLE.auto_delay_unit",
    &menu.leave_screen[GFX_SPECIAL_ARG_TITLE].auto_delay_unit
  },
  {
    "menu.leave_screen.SCORES.fade_mode",
    &menu.leave_screen[GFX_SPECIAL_ARG_SCORES].fade_mode
  },
  {
    "menu.leave_screen.SCORES.fade_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_SCORES].fade_delay
  },
  {
    "menu.leave_screen.SCORES.post_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_SCORES].post_delay
  },
  {
    "menu.leave_screen.EDITOR.fade_mode",
    &menu.leave_screen[GFX_SPECIAL_ARG_EDITOR].fade_mode
  },
  {
    "menu.leave_screen.EDITOR.fade_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_EDITOR].fade_delay
  },
  {
    "menu.leave_screen.EDITOR.post_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_EDITOR].post_delay
  },
  {
    "menu.leave_screen.INFO.fade_mode",
    &menu.leave_screen[GFX_SPECIAL_ARG_INFO].fade_mode
  },
  {
    "menu.leave_screen.INFO.fade_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_INFO].fade_delay
  },
  {
    "menu.leave_screen.INFO.post_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_INFO].post_delay
  },
  {
    "menu.leave_screen.PLAYING.fade_mode",
    &menu.leave_screen[GFX_SPECIAL_ARG_PLAYING].fade_mode
  },
  {
    "menu.leave_screen.PLAYING.fade_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_PLAYING].fade_delay
  },
  {
    "menu.leave_screen.PLAYING.post_delay",
    &menu.leave_screen[GFX_SPECIAL_ARG_PLAYING].post_delay
  },
  {
    "menu.next_screen.TITLE.fade_mode",
    &menu.next_screen[GFX_SPECIAL_ARG_TITLE].fade_mode
  },
  {
    "menu.next_screen.TITLE.fade_delay",
    &menu.next_screen[GFX_SPECIAL_ARG_TITLE].fade_delay
  },
  {
    "menu.next_screen.TITLE.post_delay",
    &menu.next_screen[GFX_SPECIAL_ARG_TITLE].post_delay
  },
  {
    "menu.next_screen.TITLE.auto_delay",
    &menu.next_screen[GFX_SPECIAL_ARG_TITLE].auto_delay
  },
  {
    "menu.next_screen.TITLE.auto_delay_unit",
    &menu.next_screen[GFX_SPECIAL_ARG_TITLE].auto_delay_unit
  },
  {
    "menu.next_screen.INFO.fade_mode",
    &menu.next_screen[GFX_SPECIAL_ARG_INFO].fade_mode
  },
  {
    "menu.next_screen.INFO.fade_delay",
    &menu.next_screen[GFX_SPECIAL_ARG_INFO].fade_delay
  },
  {
    "menu.next_screen.INFO.post_delay",
    &menu.next_screen[GFX_SPECIAL_ARG_INFO].post_delay
  },
  {
    "menu.draw_xoffset",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_DEFAULT]
  },
  {
    "menu.draw_yoffset",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_DEFAULT]
  },
  {
    "menu.draw_xoffset.MAIN",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_MAIN]
  },
  {
    "menu.draw_yoffset.MAIN",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_MAIN]
  },
  {
    "menu.draw_xoffset.NAMES",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_NAMES]
  },
  {
    "menu.draw_yoffset.NAMES",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_NAMES]
  },
  {
    "menu.draw_xoffset.LEVELS",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_LEVELS]
  },
  {
    "menu.draw_yoffset.LEVELS",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_LEVELS]
  },
  {
    "menu.draw_xoffset.LEVELNR",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_LEVELNR]
  },
  {
    "menu.draw_yoffset.LEVELNR",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_LEVELNR]
  },
  {
    "menu.draw_xoffset.SCORES",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_SCORES]
  },
  {
    "menu.draw_yoffset.SCORES",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_SCORES]
  },
  {
    "menu.draw_xoffset.EDITOR",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_EDITOR]
  },
  {
    "menu.draw_yoffset.EDITOR",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_EDITOR]
  },
  {
    "menu.draw_xoffset.INFO",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.draw_yoffset.INFO",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.draw_xoffset.INFO[TITLE]",
    &menu.draw_xoffset_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.draw_yoffset.INFO[TITLE]",
    &menu.draw_yoffset_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.draw_xoffset.INFO[ELEMENTS]",
    &menu.draw_xoffset_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.draw_yoffset.INFO[ELEMENTS]",
    &menu.draw_yoffset_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.draw_xoffset.INFO[MUSIC]",
    &menu.draw_xoffset_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.draw_yoffset.INFO[MUSIC]",
    &menu.draw_yoffset_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.draw_xoffset.INFO[CREDITS]",
    &menu.draw_xoffset_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.draw_yoffset.INFO[CREDITS]",
    &menu.draw_yoffset_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.draw_xoffset.INFO[PROGRAM]",
    &menu.draw_xoffset_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.draw_yoffset.INFO[PROGRAM]",
    &menu.draw_yoffset_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.draw_xoffset.INFO[VERSION]",
    &menu.draw_xoffset_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.draw_yoffset.INFO[VERSION]",
    &menu.draw_yoffset_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.draw_xoffset.INFO[LEVELSET]",
    &menu.draw_xoffset_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.draw_yoffset.INFO[LEVELSET]",
    &menu.draw_yoffset_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.draw_xoffset.SETUP",
    &menu.draw_xoffset[GFX_SPECIAL_ARG_SETUP]
  },
  {
    "menu.draw_yoffset.SETUP",
    &menu.draw_yoffset[GFX_SPECIAL_ARG_SETUP]
  },
  {
    "menu.draw_xoffset.SETUP[GAME]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_GAME]
  },
  {
    "menu.draw_yoffset.SETUP[GAME]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_GAME]
  },
  {
    "menu.draw_xoffset.SETUP[ENGINES]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_ENGINES]
  },
  {
    "menu.draw_yoffset.SETUP[ENGINES]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_ENGINES]
  },
  {
    "menu.draw_xoffset.SETUP[EDITOR]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_EDITOR]
  },
  {
    "menu.draw_yoffset.SETUP[EDITOR]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_EDITOR]
  },
  {
    "menu.draw_xoffset.SETUP[GRAPHICS]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_GRAPHICS]
  },
  {
    "menu.draw_yoffset.SETUP[GRAPHICS]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_GRAPHICS]
  },
  {
    "menu.draw_xoffset.SETUP[SOUND]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_SOUND]
  },
  {
    "menu.draw_yoffset.SETUP[SOUND]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_SOUND]
  },
  {
    "menu.draw_xoffset.SETUP[ARTWORK]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_ARTWORK]
  },
  {
    "menu.draw_yoffset.SETUP[ARTWORK]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_ARTWORK]
  },
  {
    "menu.draw_xoffset.SETUP[INPUT]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.draw_yoffset.SETUP[INPUT]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.draw_xoffset.SETUP[TOUCH]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_TOUCH]
  },
  {
    "menu.draw_yoffset.SETUP[TOUCH]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_TOUCH]
  },
  {
    "menu.draw_xoffset.SETUP[SHORTCUTS]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS]
  },
  {
    "menu.draw_yoffset.SETUP[SHORTCUTS]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS]
  },
  {
    "menu.draw_xoffset.SETUP[SHORTCUTS_1]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_1]
  },
  {
    "menu.draw_yoffset.SETUP[SHORTCUTS_1]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_1]
  },
  {
    "menu.draw_xoffset.SETUP[SHORTCUTS_2]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_2]
  },
  {
    "menu.draw_yoffset.SETUP[SHORTCUTS_2]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_2]
  },
  {
    "menu.draw_xoffset.SETUP[SHORTCUTS_3]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_3]
  },
  {
    "menu.draw_yoffset.SETUP[SHORTCUTS_3]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_3]
  },
  {
    "menu.draw_xoffset.SETUP[SHORTCUTS_4]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_4]
  },
  {
    "menu.draw_yoffset.SETUP[SHORTCUTS_4]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_4]
  },
  {
    "menu.draw_xoffset.SETUP[SHORTCUTS_5]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_5]
  },
  {
    "menu.draw_yoffset.SETUP[SHORTCUTS_5]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_SHORTCUTS_5]
  },
  {
    "menu.draw_xoffset.SETUP[CHOOSE_ARTWORK]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_CHOOSE_ARTWORK]
  },
  {
    "menu.draw_yoffset.SETUP[CHOOSE_ARTWORK]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_CHOOSE_ARTWORK]
  },
  {
    "menu.draw_xoffset.SETUP[CHOOSE_OTHER]",
    &menu.draw_xoffset_setup[GFX_SPECIAL_ARG_SETUP_CHOOSE_OTHER]
  },
  {
    "menu.draw_yoffset.SETUP[CHOOSE_OTHER]",
    &menu.draw_yoffset_setup[GFX_SPECIAL_ARG_SETUP_CHOOSE_OTHER]
  },
  {
    "menu.scrollbar_xoffset",
    &menu.scrollbar_xoffset
  },
  {
    "menu.list.SETUP[CHOOSE_OTHER].align",
    &menu.list_setup[GFX_SPECIAL_ARG_SETUP_CHOOSE_OTHER].align
  },
  {
    "menu.list.SETUP[CHOOSE_OTHER].valign",
    &menu.list_setup[GFX_SPECIAL_ARG_SETUP_CHOOSE_OTHER].valign
  },
  {
    "menu.list_size",
    &menu.list_size[GFX_SPECIAL_ARG_DEFAULT]
  },
  {
    "menu.list_size.NAMES",
    &menu.list_size[GFX_SPECIAL_ARG_NAMES]
  },
  {
    "menu.list_size.LEVELS",
    &menu.list_size[GFX_SPECIAL_ARG_LEVELS]
  },
  {
    "menu.list_size.LEVELNR",
    &menu.list_size[GFX_SPECIAL_ARG_LEVELNR]
  },
  {
    "menu.list_size.SCORES",
    &menu.list_size[GFX_SPECIAL_ARG_SCORES]
  },
  {
    "menu.list_size.INFO",
    &menu.list_size[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.list_size.INFO[ELEMENTS]",
    &menu.list_size_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.list_size.SETUP",
    &menu.list_size[GFX_SPECIAL_ARG_SETUP]
  },
  {
    "menu.left_spacing.INFO",
    &menu.left_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.left_spacing.INFO[TITLE]",
    &menu.left_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.left_spacing.INFO[ELEMENTS]",
    &menu.left_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.left_spacing.INFO[MUSIC]",
    &menu.left_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.left_spacing.INFO[CREDITS]",
    &menu.left_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.left_spacing.INFO[PROGRAM]",
    &menu.left_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.left_spacing.INFO[VERSION]",
    &menu.left_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.left_spacing.INFO[LEVELSET]",
    &menu.left_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.left_spacing.SETUP[INPUT]",
    &menu.left_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.right_spacing.INFO",
    &menu.right_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.right_spacing.INFO[TITLE]",
    &menu.right_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.right_spacing.INFO[ELEMENTS]",
    &menu.right_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.right_spacing.INFO[MUSIC]",
    &menu.right_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.right_spacing.INFO[CREDITS]",
    &menu.right_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.right_spacing.INFO[PROGRAM]",
    &menu.right_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.right_spacing.INFO[VERSION]",
    &menu.right_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.right_spacing.INFO[LEVELSET]",
    &menu.right_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.right_spacing.SETUP[INPUT]",
    &menu.right_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.top_spacing.INFO",
    &menu.top_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.top_spacing.INFO[TITLE]",
    &menu.top_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.top_spacing.INFO[ELEMENTS]",
    &menu.top_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.top_spacing.INFO[MUSIC]",
    &menu.top_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.top_spacing.INFO[CREDITS]",
    &menu.top_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.top_spacing.INFO[PROGRAM]",
    &menu.top_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.top_spacing.INFO[VERSION]",
    &menu.top_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.top_spacing.INFO[LEVELSET]",
    &menu.top_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.top_spacing.SETUP[INPUT]",
    &menu.top_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.bottom_spacing.INFO",
    &menu.bottom_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.bottom_spacing.INFO[TITLE]",
    &menu.bottom_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.bottom_spacing.INFO[ELEMENTS]",
    &menu.bottom_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.bottom_spacing.INFO[MUSIC]",
    &menu.bottom_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.bottom_spacing.INFO[CREDITS]",
    &menu.bottom_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.bottom_spacing.INFO[PROGRAM]",
    &menu.bottom_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.bottom_spacing.INFO[VERSION]",
    &menu.bottom_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.bottom_spacing.INFO[LEVELSET]",
    &menu.bottom_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.bottom_spacing.SETUP[INPUT]",
    &menu.bottom_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.paragraph_spacing.INFO",
    &menu.paragraph_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.paragraph_spacing.INFO[TITLE]",
    &menu.paragraph_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.paragraph_spacing.INFO[ELEMENTS]",
    &menu.paragraph_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.paragraph_spacing.INFO[MUSIC]",
    &menu.paragraph_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.paragraph_spacing.INFO[CREDITS]",
    &menu.paragraph_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.paragraph_spacing.INFO[PROGRAM]",
    &menu.paragraph_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.paragraph_spacing.INFO[VERSION]",
    &menu.paragraph_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.paragraph_spacing.INFO[LEVELSET]",
    &menu.paragraph_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.paragraph_spacing.SETUP[INPUT]",
    &menu.paragraph_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.headline1_spacing.INFO",
    &menu.headline1_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.headline1_spacing.INFO[TITLE]",
    &menu.headline1_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.headline1_spacing.INFO[ELEMENTS]",
    &menu.headline1_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.headline1_spacing.INFO[MUSIC]",
    &menu.headline1_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.headline1_spacing.INFO[CREDITS]",
    &menu.headline1_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.headline1_spacing.INFO[PROGRAM]",
    &menu.headline1_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.headline1_spacing.INFO[VERSION]",
    &menu.headline1_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.headline1_spacing.INFO[LEVELSET]",
    &menu.headline1_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.headline1_spacing.SETUP[INPUT]",
    &menu.headline1_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.headline2_spacing.INFO",
    &menu.headline2_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.headline2_spacing.INFO[TITLE]",
    &menu.headline2_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.headline2_spacing.INFO[ELEMENTS]",
    &menu.headline2_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.headline2_spacing.INFO[MUSIC]",
    &menu.headline2_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.headline2_spacing.INFO[CREDITS]",
    &menu.headline2_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.headline2_spacing.INFO[PROGRAM]",
    &menu.headline2_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.headline2_spacing.INFO[VERSION]",
    &menu.headline2_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.headline2_spacing.INFO[LEVELSET]",
    &menu.headline2_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.headline2_spacing.SETUP[INPUT]",
    &menu.headline2_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.line_spacing.INFO",
    &menu.line_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.line_spacing.INFO[TITLE]",
    &menu.line_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.line_spacing.INFO[ELEMENTS]",
    &menu.line_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.line_spacing.INFO[MUSIC]",
    &menu.line_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.line_spacing.INFO[CREDITS]",
    &menu.line_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.line_spacing.INFO[PROGRAM]",
    &menu.line_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.line_spacing.INFO[VERSION]",
    &menu.line_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.line_spacing.INFO[LEVELSET]",
    &menu.line_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.line_spacing.SETUP[INPUT]",
    &menu.line_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "menu.extra_spacing.INFO",
    &menu.extra_spacing[GFX_SPECIAL_ARG_INFO]
  },
  {
    "menu.extra_spacing.INFO[TITLE]",
    &menu.extra_spacing_info[GFX_SPECIAL_ARG_INFO_TITLE]
  },
  {
    "menu.extra_spacing.INFO[ELEMENTS]",
    &menu.extra_spacing_info[GFX_SPECIAL_ARG_INFO_ELEMENTS]
  },
  {
    "menu.extra_spacing.INFO[MUSIC]",
    &menu.extra_spacing_info[GFX_SPECIAL_ARG_INFO_MUSIC]
  },
  {
    "menu.extra_spacing.INFO[CREDITS]",
    &menu.extra_spacing_info[GFX_SPECIAL_ARG_INFO_CREDITS]
  },
  {
    "menu.extra_spacing.INFO[PROGRAM]",
    &menu.extra_spacing_info[GFX_SPECIAL_ARG_INFO_PROGRAM]
  },
  {
    "menu.extra_spacing.INFO[VERSION]",
    &menu.extra_spacing_info[GFX_SPECIAL_ARG_INFO_VERSION]
  },
  {
    "menu.extra_spacing.INFO[LEVELSET]",
    &menu.extra_spacing_info[GFX_SPECIAL_ARG_INFO_LEVELSET]
  },
  {
    "menu.extra_spacing.SETUP[INPUT]",
    &menu.extra_spacing_setup[GFX_SPECIAL_ARG_SETUP_INPUT]
  },
  {
    "main.button.name.x",
    &menu.main.button.name.x
  },
  {
    "main.button.name.y",
    &menu.main.button.name.y
  },
  {
    "main.button.levels.x",
    &menu.main.button.levels.x
  },
  {
    "main.button.levels.y",
    &menu.main.button.levels.y
  },
  {
    "main.button.scores.x",
    &menu.main.button.scores.x
  },
  {
    "main.button.scores.y",
    &menu.main.button.scores.y
  },
  {
    "main.button.editor.x",
    &menu.main.button.editor.x
  },
  {
    "main.button.editor.y",
    &menu.main.button.editor.y
  },
  {
    "main.button.info.x",
    &menu.main.button.info.x
  },
  {
    "main.button.info.y",
    &menu.main.button.info.y
  },
  {
    "main.button.game.x",
    &menu.main.button.game.x
  },
  {
    "main.button.game.y",
    &menu.main.button.game.y
  },
  {
    "main.button.setup.x",
    &menu.main.button.setup.x
  },
  {
    "main.button.setup.y",
    &menu.main.button.setup.y
  },
  {
    "main.button.quit.x",
    &menu.main.button.quit.x
  },
  {
    "main.button.quit.y",
    &menu.main.button.quit.y
  },
  {
    "main.button.first_level.x",
    &menu.main.button.first_level.x
  },
  {
    "main.button.first_level.y",
    &menu.main.button.first_level.y
  },
  {
    "main.button.last_level.x",
    &menu.main.button.last_level.x
  },
  {
    "main.button.last_level.y",
    &menu.main.button.last_level.y
  },
  {
    "main.button.level_number.x",
    &menu.main.button.level_number.x
  },
  {
    "main.button.level_number.y",
    &menu.main.button.level_number.y
  },
  {
    "main.button.prev_level.x",
    &menu.main.button.prev_level.x
  },
  {
    "main.button.prev_level.y",
    &menu.main.button.prev_level.y
  },
  {
    "main.button.next_level.x",
    &menu.main.button.next_level.x
  },
  {
    "main.button.next_level.y",
    &menu.main.button.next_level.y
  },
  {
    "main.button.insert_solution.x",
    &menu.main.button.insert_solution.x
  },
  {
    "main.button.insert_solution.y",
    &menu.main.button.insert_solution.y
  },
  {
    "main.button.play_solution.x",
    &menu.main.button.play_solution.x
  },
  {
    "main.button.play_solution.y",
    &menu.main.button.play_solution.y
  },
  {
    "main.button.switch_ecs_aga.x",
    &menu.main.button.switch_ecs_aga.x
  },
  {
    "main.button.switch_ecs_aga.y",
    &menu.main.button.switch_ecs_aga.y
  },
  {
    "main.text.name.x",
    &menu.main.text.name.x
  },
  {
    "main.text.name.y",
    &menu.main.text.name.y
  },
  {
    "main.text.name.width",
    &menu.main.text.name.width
  },
  {
    "main.text.name.height",
    &menu.main.text.name.height
  },
  {
    "main.text.name.align",
    &menu.main.text.name.align
  },
  {
    "main.text.name.valign",
    &menu.main.text.name.valign
  },
  {
    "main.text.name.font",
    &menu.main.text.name.font
  },
  {
    "main.text.levels.x",
    &menu.main.text.levels.x
  },
  {
    "main.text.levels.y",
    &menu.main.text.levels.y
  },
  {
    "main.text.levels.width",
    &menu.main.text.levels.width
  },
  {
    "main.text.levels.height",
    &menu.main.text.levels.height
  },
  {
    "main.text.levels.align",
    &menu.main.text.levels.align
  },
  {
    "main.text.levels.valign",
    &menu.main.text.levels.valign
  },
  {
    "main.text.levels.font",
    &menu.main.text.levels.font
  },
  {
    "main.text.scores.x",
    &menu.main.text.scores.x
  },
  {
    "main.text.scores.y",
    &menu.main.text.scores.y
  },
  {
    "main.text.scores.width",
    &menu.main.text.scores.width
  },
  {
    "main.text.scores.height",
    &menu.main.text.scores.height
  },
  {
    "main.text.scores.align",
    &menu.main.text.scores.align
  },
  {
    "main.text.scores.valign",
    &menu.main.text.scores.valign
  },
  {
    "main.text.scores.font",
    &menu.main.text.scores.font
  },
  {
    "main.text.editor.x",
    &menu.main.text.editor.x
  },
  {
    "main.text.editor.y",
    &menu.main.text.editor.y
  },
  {
    "main.text.editor.width",
    &menu.main.text.editor.width
  },
  {
    "main.text.editor.height",
    &menu.main.text.editor.height
  },
  {
    "main.text.editor.align",
    &menu.main.text.editor.align
  },
  {
    "main.text.editor.valign",
    &menu.main.text.editor.valign
  },
  {
    "main.text.editor.font",
    &menu.main.text.editor.font
  },
  {
    "main.text.info.x",
    &menu.main.text.info.x
  },
  {
    "main.text.info.y",
    &menu.main.text.info.y
  },
  {
    "main.text.info.width",
    &menu.main.text.info.width
  },
  {
    "main.text.info.height",
    &menu.main.text.info.height
  },
  {
    "main.text.info.align",
    &menu.main.text.info.align
  },
  {
    "main.text.info.valign",
    &menu.main.text.info.valign
  },
  {
    "main.text.info.font",
    &menu.main.text.info.font
  },
  {
    "main.text.game.x",
    &menu.main.text.game.x
  },
  {
    "main.text.game.y",
    &menu.main.text.game.y
  },
  {
    "main.text.game.width",
    &menu.main.text.game.width
  },
  {
    "main.text.game.height",
    &menu.main.text.game.height
  },
  {
    "main.text.game.align",
    &menu.main.text.game.align
  },
  {
    "main.text.game.valign",
    &menu.main.text.game.valign
  },
  {
    "main.text.game.font",
    &menu.main.text.game.font
  },
  {
    "main.text.setup.x",
    &menu.main.text.setup.x
  },
  {
    "main.text.setup.y",
    &menu.main.text.setup.y
  },
  {
    "main.text.setup.width",
    &menu.main.text.setup.width
  },
  {
    "main.text.setup.height",
    &menu.main.text.setup.height
  },
  {
    "main.text.setup.align",
    &menu.main.text.setup.align
  },
  {
    "main.text.setup.valign",
    &menu.main.text.setup.valign
  },
  {
    "main.text.setup.font",
    &menu.main.text.setup.font
  },
  {
    "main.text.quit.x",
    &menu.main.text.quit.x
  },
  {
    "main.text.quit.y",
    &menu.main.text.quit.y
  },
  {
    "main.text.quit.width",
    &menu.main.text.quit.width
  },
  {
    "main.text.quit.height",
    &menu.main.text.quit.height
  },
  {
    "main.text.quit.align",
    &menu.main.text.quit.align
  },
  {
    "main.text.quit.valign",
    &menu.main.text.quit.valign
  },
  {
    "main.text.quit.font",
    &menu.main.text.quit.font
  },
  {
    "main.text.first_level.x",
    &menu.main.text.first_level.x
  },
  {
    "main.text.first_level.y",
    &menu.main.text.first_level.y
  },
  {
    "main.text.first_level.align",
    &menu.main.text.first_level.align
  },
  {
    "main.text.first_level.valign",
    &menu.main.text.first_level.valign
  },
  {
    "main.text.first_level.digits",
    &menu.main.text.first_level.size
  },
  {
    "main.text.first_level.font",
    &menu.main.text.first_level.font
  },
  {
    "main.text.last_level.x",
    &menu.main.text.last_level.x
  },
  {
    "main.text.last_level.y",
    &menu.main.text.last_level.y
  },
  {
    "main.text.last_level.align",
    &menu.main.text.last_level.align
  },
  {
    "main.text.last_level.valign",
    &menu.main.text.last_level.valign
  },
  {
    "main.text.last_level.digits",
    &menu.main.text.last_level.size
  },
  {
    "main.text.last_level.font",
    &menu.main.text.last_level.font
  },
  {
    "main.text.level_number.x",
    &menu.main.text.level_number.x
  },
  {
    "main.text.level_number.y",
    &menu.main.text.level_number.y
  },
  {
    "main.text.level_number.align",
    &menu.main.text.level_number.align
  },
  {
    "main.text.level_number.valign",
    &menu.main.text.level_number.valign
  },
  {
    "main.text.level_number.digits",
    &menu.main.text.level_number.size
  },
  {
    "main.text.level_number.font",
    &menu.main.text.level_number.font
  },
  {
    "main.text.level_info_1.x",
    &menu.main.text.level_info_1.x
  },
  {
    "main.text.level_info_1.y",
    &menu.main.text.level_info_1.y
  },
  {
    "main.text.level_info_1.align",
    &menu.main.text.level_info_1.align
  },
  {
    "main.text.level_info_1.valign",
    &menu.main.text.level_info_1.valign
  },
  {
    "main.text.level_info_1.chars",
    &menu.main.text.level_info_1.size
  },
  {
    "main.text.level_info_1.font",
    &menu.main.text.level_info_1.font
  },
  {
    "main.text.level_info_2.x",
    &menu.main.text.level_info_2.x
  },
  {
    "main.text.level_info_2.y",
    &menu.main.text.level_info_2.y
  },
  {
    "main.text.level_info_2.align",
    &menu.main.text.level_info_2.align
  },
  {
    "main.text.level_info_2.valign",
    &menu.main.text.level_info_2.valign
  },
  {
    "main.text.level_info_2.chars",
    &menu.main.text.level_info_2.size
  },
  {
    "main.text.level_info_2.font",
    &menu.main.text.level_info_2.font
  },
  {
    "main.text.level_info_2.font_header",
    &menu.main.text.level_info_2.font_alt
  },
  {
    "main.text.level_name.x",
    &menu.main.text.level_name.x
  },
  {
    "main.text.level_name.y",
    &menu.main.text.level_name.y
  },
  {
    "main.text.level_name.align",
    &menu.main.text.level_name.align
  },
  {
    "main.text.level_name.valign",
    &menu.main.text.level_name.valign
  },
  {
    "main.text.level_name.chars",
    &menu.main.text.level_name.size
  },
  {
    "main.text.level_name.font",
    &menu.main.text.level_name.font
  },
  {
    "main.text.level_author.x",
    &menu.main.text.level_author.x
  },
  {
    "main.text.level_author.y",
    &menu.main.text.level_author.y
  },
  {
    "main.text.level_author.align",
    &menu.main.text.level_author.align
  },
  {
    "main.text.level_author.valign",
    &menu.main.text.level_author.valign
  },
  {
    "main.text.level_author.chars",
    &menu.main.text.level_author.size
  },
  {
    "main.text.level_author.font",
    &menu.main.text.level_author.font
  },
  {
    "main.text.level_year.x",
    &menu.main.text.level_year.x
  },
  {
    "main.text.level_year.y",
    &menu.main.text.level_year.y
  },
  {
    "main.text.level_year.align",
    &menu.main.text.level_year.align
  },
  {
    "main.text.level_year.valign",
    &menu.main.text.level_year.valign
  },
  {
    "main.text.level_year.digits",
    &menu.main.text.level_year.size
  },
  {
    "main.text.level_year.font",
    &menu.main.text.level_year.font
  },
  {
    "main.text.level_imported_from.x",
    &menu.main.text.level_imported_from.x
  },
  {
    "main.text.level_imported_from.y",
    &menu.main.text.level_imported_from.y
  },
  {
    "main.text.level_imported_from.align",
    &menu.main.text.level_imported_from.align
  },
  {
    "main.text.level_imported_from.valign",
    &menu.main.text.level_imported_from.valign
  },
  {
    "main.text.level_imported_from.chars",
    &menu.main.text.level_imported_from.size
  },
  {
    "main.text.level_imported_from.font",
    &menu.main.text.level_imported_from.font
  },
  {
    "main.text.level_imported_by.x",
    &menu.main.text.level_imported_by.x
  },
  {
    "main.text.level_imported_by.y",
    &menu.main.text.level_imported_by.y
  },
  {
    "main.text.level_imported_by.align",
    &menu.main.text.level_imported_by.align
  },
  {
    "main.text.level_imported_by.valign",
    &menu.main.text.level_imported_by.valign
  },
  {
    "main.text.level_imported_by.chars",
    &menu.main.text.level_imported_by.size
  },
  {
    "main.text.level_imported_by.font",
    &menu.main.text.level_imported_by.font
  },
  {
    "main.text.level_tested_by.x",
    &menu.main.text.level_tested_by.x
  },
  {
    "main.text.level_tested_by.y",
    &menu.main.text.level_tested_by.y
  },
  {
    "main.text.level_tested_by.align",
    &menu.main.text.level_tested_by.align
  },
  {
    "main.text.level_tested_by.valign",
    &menu.main.text.level_tested_by.valign
  },
  {
    "main.text.level_tested_by.chars",
    &menu.main.text.level_tested_by.size
  },
  {
    "main.text.level_tested_by.font",
    &menu.main.text.level_tested_by.font
  },
  {
    "main.text.title_1.x",
    &menu.main.text.title_1.x
  },
  {
    "main.text.title_1.y",
    &menu.main.text.title_1.y
  },
  {
    "main.text.title_1.align",
    &menu.main.text.title_1.align
  },
  {
    "main.text.title_1.valign",
    &menu.main.text.title_1.valign
  },
  {
    "main.text.title_1.font",
    &menu.main.text.title_1.font
  },
  {
    "main.text.title_2.x",
    &menu.main.text.title_2.x
  },
  {
    "main.text.title_2.y",
    &menu.main.text.title_2.y
  },
  {
    "main.text.title_2.align",
    &menu.main.text.title_2.align
  },
  {
    "main.text.title_2.valign",
    &menu.main.text.title_2.valign
  },
  {
    "main.text.title_2.font",
    &menu.main.text.title_2.font
  },
  {
    "main.text.title_3.x",
    &menu.main.text.title_3.x
  },
  {
    "main.text.title_3.y",
    &menu.main.text.title_3.y
  },
  {
    "main.text.title_3.align",
    &menu.main.text.title_3.align
  },
  {
    "main.text.title_3.valign",
    &menu.main.text.title_3.valign
  },
  {
    "main.text.title_3.font",
    &menu.main.text.title_3.font
  },
  {
    "main.input.name.x",
    &menu.main.input.name.x
  },
  {
    "main.input.name.y",
    &menu.main.input.name.y
  },
  {
    "main.input.name.align",
    &menu.main.input.name.align
  },
  {
    "main.input.name.valign",
    &menu.main.input.name.valign
  },
  {
    "main.input.name.font",
    &menu.main.input.name.font
  },
  {
    "main.network_players.x",
    &menu.main.network_players.x
  },
  {
    "main.network_players.y",
    &menu.main.network_players.y
  },
  {
    "main.network_players.align",
    &menu.main.network_players.align
  },
  {
    "main.network_players.valign",
    &menu.main.network_players.valign
  },
  {
    "main.network_players.font",
    &menu.main.network_players.font
  },
  {
    "main.network_players.tile_size",
    &menu.main.network_players.tile_size
  },
  {
    "main.network_players.border_size",
    &menu.main.network_players.border_size
  },
  {
    "main.preview_players.x",
    &menu.main.preview_players.x
  },
  {
    "main.preview_players.y",
    &menu.main.preview_players.y
  },
  {
    "main.preview_players.align",
    &menu.main.preview_players.align
  },
  {
    "main.preview_players.valign",
    &menu.main.preview_players.valign
  },
  {
    "main.preview_players.tile_size",
    &menu.main.preview_players.tile_size
  },
  {
    "main.preview_players.border_size",
    &menu.main.preview_players.border_size
  },
  {
    "main.preview_players.vertical",
    &menu.main.preview_players.vertical
  },
  {
    "main.preview_players.xoffset",
    &menu.main.preview_players.xoffset
  },
  {
    "main.preview_players.yoffset",
    &menu.main.preview_players.yoffset
  },
  {
    "setup.button.prev_player.x",
    &menu.setup.button.prev_player.x
  },
  {
    "setup.button.prev_player.y",
    &menu.setup.button.prev_player.y
  },
  {
    "setup.button.next_player.x",
    &menu.setup.button.next_player.x
  },
  {
    "setup.button.next_player.y",
    &menu.setup.button.next_player.y
  },
  {
    "setup.button.touch_back.x",
    &menu.setup.button.touch_back.x
  },
  {
    "setup.button.touch_back.y",
    &menu.setup.button.touch_back.y
  },
  {
    "setup.button.touch_next.x",
    &menu.setup.button.touch_next.x
  },
  {
    "setup.button.touch_next.y",
    &menu.setup.button.touch_next.y
  },
  {
    "setup.button.touch_back2.x",
    &menu.setup.button.touch_back2.x
  },
  {
    "setup.button.touch_back2.y",
    &menu.setup.button.touch_back2.y
  },
  {
    "setup.button.touch_next2.x",
    &menu.setup.button.touch_next2.x
  },
  {
    "setup.button.touch_next2.y",
    &menu.setup.button.touch_next2.y
  },
  {
    "preview.x",
    &preview.x
  },
  {
    "preview.y",
    &preview.y
  },
  {
    "preview.align",
    &preview.align
  },
  {
    "preview.valign",
    &preview.valign
  },
  {
    "preview.xsize",
    &preview.xsize
  },
  {
    "preview.ysize",
    &preview.ysize
  },
  {
    "preview.xoffset",
    &preview.xoffset
  },
  {
    "preview.yoffset",
    &preview.yoffset
  },
  {
    "preview.tile_size",
    &preview.tile_size
  },
  {
    "preview.step_offset",
    &preview.step_offset
  },
  {
    "preview.step_delay",
    &preview.step_delay
  },
  {
    "preview.anim_mode",
    &preview.anim_mode
  },
  {
    "door_1.part_1.x",
    &door_1.part_1.x
  },
  {
    "door_1.part_1.y",
    &door_1.part_1.y
  },
  {
    "door_1.part_1.step_xoffset",
    &door_1.part_1.step_xoffset
  },
  {
    "door_1.part_1.step_yoffset",
    &door_1.part_1.step_yoffset
  },
  {
    "door_1.part_1.step_delay",
    &door_1.part_1.step_delay
  },
  {
    "door_1.part_1.start_step",
    &door_1.part_1.start_step
  },
  {
    "door_1.part_1.start_step_opening",
    &door_1.part_1.start_step_opening
  },
  {
    "door_1.part_1.start_step_closing",
    &door_1.part_1.start_step_closing
  },
  {
    "door_1.part_1.draw_masked",
    &door_1.part_1.draw_masked
  },
  {
    "door_1.part_1.draw_order",
    &door_1.part_1.sort_priority
  },
  {
    "door_1.part_2.x",
    &door_1.part_2.x
  },
  {
    "door_1.part_2.y",
    &door_1.part_2.y
  },
  {
    "door_1.part_2.step_xoffset",
    &door_1.part_2.step_xoffset
  },
  {
    "door_1.part_2.step_yoffset",
    &door_1.part_2.step_yoffset
  },
  {
    "door_1.part_2.step_delay",
    &door_1.part_2.step_delay
  },
  {
    "door_1.part_2.start_step",
    &door_1.part_2.start_step
  },
  {
    "door_1.part_2.start_step_opening",
    &door_1.part_2.start_step_opening
  },
  {
    "door_1.part_2.start_step_closing",
    &door_1.part_2.start_step_closing
  },
  {
    "door_1.part_2.draw_masked",
    &door_1.part_2.draw_masked
  },
  {
    "door_1.part_2.draw_order",
    &door_1.part_2.sort_priority
  },
  {
    "door_1.part_3.x",
    &door_1.part_3.x
  },
  {
    "door_1.part_3.y",
    &door_1.part_3.y
  },
  {
    "door_1.part_3.step_xoffset",
    &door_1.part_3.step_xoffset
  },
  {
    "door_1.part_3.step_yoffset",
    &door_1.part_3.step_yoffset
  },
  {
    "door_1.part_3.step_delay",
    &door_1.part_3.step_delay
  },
  {
    "door_1.part_3.start_step",
    &door_1.part_3.start_step
  },
  {
    "door_1.part_3.start_step_opening",
    &door_1.part_3.start_step_opening
  },
  {
    "door_1.part_3.start_step_closing",
    &door_1.part_3.start_step_closing
  },
  {
    "door_1.part_3.draw_masked",
    &door_1.part_3.draw_masked
  },
  {
    "door_1.part_3.draw_order",
    &door_1.part_3.sort_priority
  },
  {
    "door_1.part_4.x",
    &door_1.part_4.x
  },
  {
    "door_1.part_4.y",
    &door_1.part_4.y
  },
  {
    "door_1.part_4.step_xoffset",
    &door_1.part_4.step_xoffset
  },
  {
    "door_1.part_4.step_yoffset",
    &door_1.part_4.step_yoffset
  },
  {
    "door_1.part_4.step_delay",
    &door_1.part_4.step_delay
  },
  {
    "door_1.part_4.start_step",
    &door_1.part_4.start_step
  },
  {
    "door_1.part_4.start_step_opening",
    &door_1.part_4.start_step_opening
  },
  {
    "door_1.part_4.start_step_closing",
    &door_1.part_4.start_step_closing
  },
  {
    "door_1.part_4.draw_masked",
    &door_1.part_4.draw_masked
  },
  {
    "door_1.part_4.draw_order",
    &door_1.part_4.sort_priority
  },
  {
    "door_1.part_5.x",
    &door_1.part_5.x
  },
  {
    "door_1.part_5.y",
    &door_1.part_5.y
  },
  {
    "door_1.part_5.step_xoffset",
    &door_1.part_5.step_xoffset
  },
  {
    "door_1.part_5.step_yoffset",
    &door_1.part_5.step_yoffset
  },
  {
    "door_1.part_5.step_delay",
    &door_1.part_5.step_delay
  },
  {
    "door_1.part_5.start_step",
    &door_1.part_5.start_step
  },
  {
    "door_1.part_5.start_step_opening",
    &door_1.part_5.start_step_opening
  },
  {
    "door_1.part_5.start_step_closing",
    &door_1.part_5.start_step_closing
  },
  {
    "door_1.part_5.draw_masked",
    &door_1.part_5.draw_masked
  },
  {
    "door_1.part_5.draw_order",
    &door_1.part_5.sort_priority
  },
  {
    "door_1.part_6.x",
    &door_1.part_6.x
  },
  {
    "door_1.part_6.y",
    &door_1.part_6.y
  },
  {
    "door_1.part_6.step_xoffset",
    &door_1.part_6.step_xoffset
  },
  {
    "door_1.part_6.step_yoffset",
    &door_1.part_6.step_yoffset
  },
  {
    "door_1.part_6.step_delay",
    &door_1.part_6.step_delay
  },
  {
    "door_1.part_6.start_step",
    &door_1.part_6.start_step
  },
  {
    "door_1.part_6.start_step_opening",
    &door_1.part_6.start_step_opening
  },
  {
    "door_1.part_6.start_step_closing",
    &door_1.part_6.start_step_closing
  },
  {
    "door_1.part_6.draw_masked",
    &door_1.part_6.draw_masked
  },
  {
    "door_1.part_6.draw_order",
    &door_1.part_6.sort_priority
  },
  {
    "door_1.part_7.x",
    &door_1.part_7.x
  },
  {
    "door_1.part_7.y",
    &door_1.part_7.y
  },
  {
    "door_1.part_7.step_xoffset",
    &door_1.part_7.step_xoffset
  },
  {
    "door_1.part_7.step_yoffset",
    &door_1.part_7.step_yoffset
  },
  {
    "door_1.part_7.step_delay",
    &door_1.part_7.step_delay
  },
  {
    "door_1.part_7.start_step",
    &door_1.part_7.start_step
  },
  {
    "door_1.part_7.start_step_opening",
    &door_1.part_7.start_step_opening
  },
  {
    "door_1.part_7.start_step_closing",
    &door_1.part_7.start_step_closing
  },
  {
    "door_1.part_7.draw_masked",
    &door_1.part_7.draw_masked
  },
  {
    "door_1.part_7.draw_order",
    &door_1.part_7.sort_priority
  },
  {
    "door_1.part_8.x",
    &door_1.part_8.x
  },
  {
    "door_1.part_8.y",
    &door_1.part_8.y
  },
  {
    "door_1.part_8.step_xoffset",
    &door_1.part_8.step_xoffset
  },
  {
    "door_1.part_8.step_yoffset",
    &door_1.part_8.step_yoffset
  },
  {
    "door_1.part_8.step_delay",
    &door_1.part_8.step_delay
  },
  {
    "door_1.part_8.start_step",
    &door_1.part_8.start_step
  },
  {
    "door_1.part_8.start_step_opening",
    &door_1.part_8.start_step_opening
  },
  {
    "door_1.part_8.start_step_closing",
    &door_1.part_8.start_step_closing
  },
  {
    "door_1.part_8.draw_masked",
    &door_1.part_8.draw_masked
  },
  {
    "door_1.part_8.draw_order",
    &door_1.part_8.sort_priority
  },
  {
    "door_2.part_1.x",
    &door_2.part_1.x
  },
  {
    "door_2.part_1.y",
    &door_2.part_1.y
  },
  {
    "door_2.part_1.step_xoffset",
    &door_2.part_1.step_xoffset
  },
  {
    "door_2.part_1.step_yoffset",
    &door_2.part_1.step_yoffset
  },
  {
    "door_2.part_1.step_delay",
    &door_2.part_1.step_delay
  },
  {
    "door_2.part_1.start_step",
    &door_2.part_1.start_step
  },
  {
    "door_2.part_1.start_step_opening",
    &door_2.part_1.start_step_opening
  },
  {
    "door_2.part_1.start_step_closing",
    &door_2.part_1.start_step_closing
  },
  {
    "door_2.part_1.draw_masked",
    &door_2.part_1.draw_masked
  },
  {
    "door_2.part_1.draw_order",
    &door_2.part_1.sort_priority
  },
  {
    "door_2.part_2.x",
    &door_2.part_2.x
  },
  {
    "door_2.part_2.y",
    &door_2.part_2.y
  },
  {
    "door_2.part_2.step_xoffset",
    &door_2.part_2.step_xoffset
  },
  {
    "door_2.part_2.step_yoffset",
    &door_2.part_2.step_yoffset
  },
  {
    "door_2.part_2.step_delay",
    &door_2.part_2.step_delay
  },
  {
    "door_2.part_2.start_step",
    &door_2.part_2.start_step
  },
  {
    "door_2.part_2.start_step_opening",
    &door_2.part_2.start_step_opening
  },
  {
    "door_2.part_2.start_step_closing",
    &door_2.part_2.start_step_closing
  },
  {
    "door_2.part_2.draw_masked",
    &door_2.part_2.draw_masked
  },
  {
    "door_2.part_2.draw_order",
    &door_2.part_2.sort_priority
  },
  {
    "door_2.part_3.x",
    &door_2.part_3.x
  },
  {
    "door_2.part_3.y",
    &door_2.part_3.y
  },
  {
    "door_2.part_3.step_xoffset",
    &door_2.part_3.step_xoffset
  },
  {
    "door_2.part_3.step_yoffset",
    &door_2.part_3.step_yoffset
  },
  {
    "door_2.part_3.step_delay",
    &door_2.part_3.step_delay
  },
  {
    "door_2.part_3.start_step",
    &door_2.part_3.start_step
  },
  {
    "door_2.part_3.start_step_opening",
    &door_2.part_3.start_step_opening
  },
  {
    "door_2.part_3.start_step_closing",
    &door_2.part_3.start_step_closing
  },
  {
    "door_2.part_3.draw_masked",
    &door_2.part_3.draw_masked
  },
  {
    "door_2.part_3.draw_order",
    &door_2.part_3.sort_priority
  },
  {
    "door_2.part_4.x",
    &door_2.part_4.x
  },
  {
    "door_2.part_4.y",
    &door_2.part_4.y
  },
  {
    "door_2.part_4.step_xoffset",
    &door_2.part_4.step_xoffset
  },
  {
    "door_2.part_4.step_yoffset",
    &door_2.part_4.step_yoffset
  },
  {
    "door_2.part_4.step_delay",
    &door_2.part_4.step_delay
  },
  {
    "door_2.part_4.start_step",
    &door_2.part_4.start_step
  },
  {
    "door_2.part_4.start_step_opening",
    &door_2.part_4.start_step_opening
  },
  {
    "door_2.part_4.start_step_closing",
    &door_2.part_4.start_step_closing
  },
  {
    "door_2.part_4.draw_masked",
    &door_2.part_4.draw_masked
  },
  {
    "door_2.part_4.draw_order",
    &door_2.part_4.sort_priority
  },
  {
    "door_2.part_5.x",
    &door_2.part_5.x
  },
  {
    "door_2.part_5.y",
    &door_2.part_5.y
  },
  {
    "door_2.part_5.step_xoffset",
    &door_2.part_5.step_xoffset
  },
  {
    "door_2.part_5.step_yoffset",
    &door_2.part_5.step_yoffset
  },
  {
    "door_2.part_5.step_delay",
    &door_2.part_5.step_delay
  },
  {
    "door_2.part_5.start_step",
    &door_2.part_5.start_step
  },
  {
    "door_2.part_5.start_step_opening",
    &door_2.part_5.start_step_opening
  },
  {
    "door_2.part_5.start_step_closing",
    &door_2.part_5.start_step_closing
  },
  {
    "door_2.part_5.draw_masked",
    &door_2.part_5.draw_masked
  },
  {
    "door_2.part_5.draw_order",
    &door_2.part_5.sort_priority
  },
  {
    "door_2.part_6.x",
    &door_2.part_6.x
  },
  {
    "door_2.part_6.y",
    &door_2.part_6.y
  },
  {
    "door_2.part_6.step_xoffset",
    &door_2.part_6.step_xoffset
  },
  {
    "door_2.part_6.step_yoffset",
    &door_2.part_6.step_yoffset
  },
  {
    "door_2.part_6.step_delay",
    &door_2.part_6.step_delay
  },
  {
    "door_2.part_6.start_step",
    &door_2.part_6.start_step
  },
  {
    "door_2.part_6.start_step_opening",
    &door_2.part_6.start_step_opening
  },
  {
    "door_2.part_6.start_step_closing",
    &door_2.part_6.start_step_closing
  },
  {
    "door_2.part_6.draw_masked",
    &door_2.part_6.draw_masked
  },
  {
    "door_2.part_6.draw_order",
    &door_2.part_6.sort_priority
  },
  {
    "door_2.part_7.x",
    &door_2.part_7.x
  },
  {
    "door_2.part_7.y",
    &door_2.part_7.y
  },
  {
    "door_2.part_7.step_xoffset",
    &door_2.part_7.step_xoffset
  },
  {
    "door_2.part_7.step_yoffset",
    &door_2.part_7.step_yoffset
  },
  {
    "door_2.part_7.step_delay",
    &door_2.part_7.step_delay
  },
  {
    "door_2.part_7.start_step",
    &door_2.part_7.start_step
  },
  {
    "door_2.part_7.start_step_opening",
    &door_2.part_7.start_step_opening
  },
  {
    "door_2.part_7.start_step_closing",
    &door_2.part_7.start_step_closing
  },
  {
    "door_2.part_7.draw_masked",
    &door_2.part_7.draw_masked
  },
  {
    "door_2.part_7.draw_order",
    &door_2.part_7.sort_priority
  },
  {
    "door_2.part_8.x",
    &door_2.part_8.x
  },
  {
    "door_2.part_8.y",
    &door_2.part_8.y
  },
  {
    "door_2.part_8.step_xoffset",
    &door_2.part_8.step_xoffset
  },
  {
    "door_2.part_8.step_yoffset",
    &door_2.part_8.step_yoffset
  },
  {
    "door_2.part_8.step_delay",
    &door_2.part_8.step_delay
  },
  {
    "door_2.part_8.start_step",
    &door_2.part_8.start_step
  },
  {
    "door_2.part_8.start_step_opening",
    &door_2.part_8.start_step_opening
  },
  {
    "door_2.part_8.start_step_closing",
    &door_2.part_8.start_step_closing
  },
  {
    "door_2.part_8.draw_masked",
    &door_2.part_8.draw_masked
  },
  {
    "door_2.part_8.draw_order",
    &door_2.part_8.sort_priority
  },
  {
    "door_1.panel.x",
    &door_1.panel.x
  },
  {
    "door_1.panel.y",
    &door_1.panel.y
  },
  {
    "door_1.panel.step_xoffset",
    &door_1.panel.step_xoffset
  },
  {
    "door_1.panel.step_yoffset",
    &door_1.panel.step_yoffset
  },
  {
    "door_1.panel.step_delay",
    &door_1.panel.step_delay
  },
  {
    "door_1.panel.start_step",
    &door_1.panel.start_step
  },
  {
    "door_1.panel.start_step_opening",
    &door_1.panel.start_step_opening
  },
  {
    "door_1.panel.start_step_closing",
    &door_1.panel.start_step_closing
  },
  {
    "door_1.panel.draw_masked",
    &door_1.panel.draw_masked
  },
  {
    "door_1.panel.draw_order",
    &door_1.panel.sort_priority
  },
  {
    "door_2.panel.x",
    &door_2.panel.x
  },
  {
    "door_2.panel.y",
    &door_2.panel.y
  },
  {
    "door_2.panel.step_xoffset",
    &door_2.panel.step_xoffset
  },
  {
    "door_2.panel.step_yoffset",
    &door_2.panel.step_yoffset
  },
  {
    "door_2.panel.step_delay",
    &door_2.panel.step_delay
  },
  {
    "door_2.panel.start_step",
    &door_2.panel.start_step
  },
  {
    "door_2.panel.start_step_opening",
    &door_2.panel.start_step_opening
  },
  {
    "door_2.panel.start_step_closing",
    &door_2.panel.start_step_closing
  },
  {
    "door_2.panel.draw_masked",
    &door_2.panel.draw_masked
  },
  {
    "door_2.panel.draw_order",
    &door_2.panel.sort_priority
  },
  {
    "door_1.width",
    &door_1.width
  },
  {
    "door_1.height",
    &door_1.height
  },
  {
    "door_1.step_offset",
    &door_1.step_offset
  },
  {
    "door_1.step_delay",
    &door_1.step_delay
  },
  {
    "door_1.post_delay",
    &door_1.post_delay
  },
  {
    "door_1.anim_mode",
    &door_1.anim_mode
  },
  {
    "door_2.width",
    &door_2.width
  },
  {
    "door_2.height",
    &door_2.height
  },
  {
    "door_2.step_offset",
    &door_2.step_offset
  },
  {
    "door_2.step_delay",
    &door_2.step_delay
  },
  {
    "door_2.post_delay",
    &door_2.post_delay
  },
  {
    "door_2.anim_mode",
    &door_2.anim_mode
  },
  {
    "game.panel.level_number.x",
    &game.panel.level_number.x
  },
  {
    "game.panel.level_number.y",
    &game.panel.level_number.y
  },
  {
    "game.panel.level_number.align",
    &game.panel.level_number.align
  },
  {
    "game.panel.level_number.valign",
    &game.panel.level_number.valign
  },
  {
    "game.panel.level_number.digits",
    &game.panel.level_number.size
  },
  {
    "game.panel.level_number.font",
    &game.panel.level_number.font
  },
  {
    "game.panel.level_number.font_narrow",
    &game.panel.level_number.font_alt
  },
  {
    "game.panel.level_number.draw_masked",
    &game.panel.level_number.draw_masked
  },
  {
    "game.panel.level_number.draw_order",
    &game.panel.level_number.sort_priority
  },
  {
    "game.panel.level_number.class",
    &game.panel.level_number.class
  },
  {
    "game.panel.level_number.style",
    &game.panel.level_number.style
  },
  {
    "game.panel.gems.x",
    &game.panel.gems.x
  },
  {
    "game.panel.gems.y",
    &game.panel.gems.y
  },
  {
    "game.panel.gems.align",
    &game.panel.gems.align
  },
  {
    "game.panel.gems.valign",
    &game.panel.gems.valign
  },
  {
    "game.panel.gems.digits",
    &game.panel.gems.size
  },
  {
    "game.panel.gems.font",
    &game.panel.gems.font
  },
  {
    "game.panel.gems.draw_masked",
    &game.panel.gems.draw_masked
  },
  {
    "game.panel.gems.draw_order",
    &game.panel.gems.sort_priority
  },
  {
    "game.panel.gems.class",
    &game.panel.gems.class
  },
  {
    "game.panel.gems.style",
    &game.panel.gems.style
  },
  {
    "game.panel.inventory_count.x",
    &game.panel.inventory_count.x
  },
  {
    "game.panel.inventory_count.y",
    &game.panel.inventory_count.y
  },
  {
    "game.panel.inventory_count.align",
    &game.panel.inventory_count.align
  },
  {
    "game.panel.inventory_count.valign",
    &game.panel.inventory_count.valign
  },
  {
    "game.panel.inventory_count.digits",
    &game.panel.inventory_count.size
  },
  {
    "game.panel.inventory_count.font",
    &game.panel.inventory_count.font
  },
  {
    "game.panel.inventory_count.draw_masked",
    &game.panel.inventory_count.draw_masked
  },
  {
    "game.panel.inventory_count.draw_order",
    &game.panel.inventory_count.sort_priority
  },
  {
    "game.panel.inventory_count.class",
    &game.panel.inventory_count.class
  },
  {
    "game.panel.inventory_count.style",
    &game.panel.inventory_count.style
  },
  {
    "game.panel.inventory_first_1.x",
    &game.panel.inventory_first[0].x
  },
  {
    "game.panel.inventory_first_1.y",
    &game.panel.inventory_first[0].y
  },
  {
    "game.panel.inventory_first_1.tile_size",
    &game.panel.inventory_first[0].size
  },
  {
    "game.panel.inventory_first_1.draw_masked",
    &game.panel.inventory_first[0].draw_masked
  },
  {
    "game.panel.inventory_first_1.draw_order",
    &game.panel.inventory_first[0].sort_priority
  },
  {
    "game.panel.inventory_first_1.class",
    &game.panel.inventory_first[0].class
  },
  {
    "game.panel.inventory_first_1.style",
    &game.panel.inventory_first[0].style
  },
  {
    "game.panel.inventory_first_2.x",
    &game.panel.inventory_first[1].x
  },
  {
    "game.panel.inventory_first_2.y",
    &game.panel.inventory_first[1].y
  },
  {
    "game.panel.inventory_first_2.tile_size",
    &game.panel.inventory_first[1].size
  },
  {
    "game.panel.inventory_first_2.draw_masked",
    &game.panel.inventory_first[1].draw_masked
  },
  {
    "game.panel.inventory_first_2.draw_order",
    &game.panel.inventory_first[1].sort_priority
  },
  {
    "game.panel.inventory_first_2.class",
    &game.panel.inventory_first[1].class
  },
  {
    "game.panel.inventory_first_2.style",
    &game.panel.inventory_first[1].style
  },
  {
    "game.panel.inventory_first_3.x",
    &game.panel.inventory_first[2].x
  },
  {
    "game.panel.inventory_first_3.y",
    &game.panel.inventory_first[2].y
  },
  {
    "game.panel.inventory_first_3.tile_size",
    &game.panel.inventory_first[2].size
  },
  {
    "game.panel.inventory_first_3.draw_masked",
    &game.panel.inventory_first[2].draw_masked
  },
  {
    "game.panel.inventory_first_3.draw_order",
    &game.panel.inventory_first[2].sort_priority
  },
  {
    "game.panel.inventory_first_3.class",
    &game.panel.inventory_first[2].class
  },
  {
    "game.panel.inventory_first_3.style",
    &game.panel.inventory_first[2].style
  },
  {
    "game.panel.inventory_first_4.x",
    &game.panel.inventory_first[3].x
  },
  {
    "game.panel.inventory_first_4.y",
    &game.panel.inventory_first[3].y
  },
  {
    "game.panel.inventory_first_4.tile_size",
    &game.panel.inventory_first[3].size
  },
  {
    "game.panel.inventory_first_4.draw_masked",
    &game.panel.inventory_first[3].draw_masked
  },
  {
    "game.panel.inventory_first_4.draw_order",
    &game.panel.inventory_first[3].sort_priority
  },
  {
    "game.panel.inventory_first_4.class",
    &game.panel.inventory_first[3].class
  },
  {
    "game.panel.inventory_first_4.style",
    &game.panel.inventory_first[3].style
  },
  {
    "game.panel.inventory_first_5.x",
    &game.panel.inventory_first[4].x
  },
  {
    "game.panel.inventory_first_5.y",
    &game.panel.inventory_first[4].y
  },
  {
    "game.panel.inventory_first_5.tile_size",
    &game.panel.inventory_first[4].size
  },
  {
    "game.panel.inventory_first_5.draw_masked",
    &game.panel.inventory_first[4].draw_masked
  },
  {
    "game.panel.inventory_first_5.draw_order",
    &game.panel.inventory_first[4].sort_priority
  },
  {
    "game.panel.inventory_first_5.class",
    &game.panel.inventory_first[4].class
  },
  {
    "game.panel.inventory_first_5.style",
    &game.panel.inventory_first[4].style
  },
  {
    "game.panel.inventory_first_6.x",
    &game.panel.inventory_first[5].x
  },
  {
    "game.panel.inventory_first_6.y",
    &game.panel.inventory_first[5].y
  },
  {
    "game.panel.inventory_first_6.tile_size",
    &game.panel.inventory_first[5].size
  },
  {
    "game.panel.inventory_first_6.draw_masked",
    &game.panel.inventory_first[5].draw_masked
  },
  {
    "game.panel.inventory_first_6.draw_order",
    &game.panel.inventory_first[5].sort_priority
  },
  {
    "game.panel.inventory_first_6.class",
    &game.panel.inventory_first[5].class
  },
  {
    "game.panel.inventory_first_6.style",
    &game.panel.inventory_first[5].style
  },
  {
    "game.panel.inventory_first_7.x",
    &game.panel.inventory_first[6].x
  },
  {
    "game.panel.inventory_first_7.y",
    &game.panel.inventory_first[6].y
  },
  {
    "game.panel.inventory_first_7.tile_size",
    &game.panel.inventory_first[6].size
  },
  {
    "game.panel.inventory_first_7.draw_masked",
    &game.panel.inventory_first[6].draw_masked
  },
  {
    "game.panel.inventory_first_7.draw_order",
    &game.panel.inventory_first[6].sort_priority
  },
  {
    "game.panel.inventory_first_7.class",
    &game.panel.inventory_first[6].class
  },
  {
    "game.panel.inventory_first_7.style",
    &game.panel.inventory_first[6].style
  },
  {
    "game.panel.inventory_first_8.x",
    &game.panel.inventory_first[7].x
  },
  {
    "game.panel.inventory_first_8.y",
    &game.panel.inventory_first[7].y
  },
  {
    "game.panel.inventory_first_8.tile_size",
    &game.panel.inventory_first[7].size
  },
  {
    "game.panel.inventory_first_8.draw_masked",
    &game.panel.inventory_first[7].draw_masked
  },
  {
    "game.panel.inventory_first_8.draw_order",
    &game.panel.inventory_first[7].sort_priority
  },
  {
    "game.panel.inventory_first_8.class",
    &game.panel.inventory_first[7].class
  },
  {
    "game.panel.inventory_first_8.style",
    &game.panel.inventory_first[7].style
  },
  {
    "game.panel.inventory_last_1.x",
    &game.panel.inventory_last[0].x
  },
  {
    "game.panel.inventory_last_1.y",
    &game.panel.inventory_last[0].y
  },
  {
    "game.panel.inventory_last_1.tile_size",
    &game.panel.inventory_last[0].size
  },
  {
    "game.panel.inventory_last_1.draw_masked",
    &game.panel.inventory_last[0].draw_masked
  },
  {
    "game.panel.inventory_last_1.draw_order",
    &game.panel.inventory_last[0].sort_priority
  },
  {
    "game.panel.inventory_last_1.class",
    &game.panel.inventory_last[0].class
  },
  {
    "game.panel.inventory_last_1.style",
    &game.panel.inventory_last[0].style
  },
  {
    "game.panel.inventory_last_2.x",
    &game.panel.inventory_last[1].x
  },
  {
    "game.panel.inventory_last_2.y",
    &game.panel.inventory_last[1].y
  },
  {
    "game.panel.inventory_last_2.tile_size",
    &game.panel.inventory_last[1].size
  },
  {
    "game.panel.inventory_last_2.draw_masked",
    &game.panel.inventory_last[1].draw_masked
  },
  {
    "game.panel.inventory_last_2.draw_order",
    &game.panel.inventory_last[1].sort_priority
  },
  {
    "game.panel.inventory_last_2.class",
    &game.panel.inventory_last[1].class
  },
  {
    "game.panel.inventory_last_2.style",
    &game.panel.inventory_last[1].style
  },
  {
    "game.panel.inventory_last_3.x",
    &game.panel.inventory_last[2].x
  },
  {
    "game.panel.inventory_last_3.y",
    &game.panel.inventory_last[2].y
  },
  {
    "game.panel.inventory_last_3.tile_size",
    &game.panel.inventory_last[2].size
  },
  {
    "game.panel.inventory_last_3.draw_masked",
    &game.panel.inventory_last[2].draw_masked
  },
  {
    "game.panel.inventory_last_3.draw_order",
    &game.panel.inventory_last[2].sort_priority
  },
  {
    "game.panel.inventory_last_3.class",
    &game.panel.inventory_last[2].class
  },
  {
    "game.panel.inventory_last_3.style",
    &game.panel.inventory_last[2].style
  },
  {
    "game.panel.inventory_last_4.x",
    &game.panel.inventory_last[3].x
  },
  {
    "game.panel.inventory_last_4.y",
    &game.panel.inventory_last[3].y
  },
  {
    "game.panel.inventory_last_4.tile_size",
    &game.panel.inventory_last[3].size
  },
  {
    "game.panel.inventory_last_4.draw_masked",
    &game.panel.inventory_last[3].draw_masked
  },
  {
    "game.panel.inventory_last_4.draw_order",
    &game.panel.inventory_last[3].sort_priority
  },
  {
    "game.panel.inventory_last_4.class",
    &game.panel.inventory_last[3].class
  },
  {
    "game.panel.inventory_last_4.style",
    &game.panel.inventory_last[3].style
  },
  {
    "game.panel.inventory_last_5.x",
    &game.panel.inventory_last[4].x
  },
  {
    "game.panel.inventory_last_5.y",
    &game.panel.inventory_last[4].y
  },
  {
    "game.panel.inventory_last_5.tile_size",
    &game.panel.inventory_last[4].size
  },
  {
    "game.panel.inventory_last_5.draw_masked",
    &game.panel.inventory_last[4].draw_masked
  },
  {
    "game.panel.inventory_last_5.draw_order",
    &game.panel.inventory_last[4].sort_priority
  },
  {
    "game.panel.inventory_last_5.class",
    &game.panel.inventory_last[4].class
  },
  {
    "game.panel.inventory_last_5.style",
    &game.panel.inventory_last[4].style
  },
  {
    "game.panel.inventory_last_6.x",
    &game.panel.inventory_last[5].x
  },
  {
    "game.panel.inventory_last_6.y",
    &game.panel.inventory_last[5].y
  },
  {
    "game.panel.inventory_last_6.tile_size",
    &game.panel.inventory_last[5].size
  },
  {
    "game.panel.inventory_last_6.draw_masked",
    &game.panel.inventory_last[5].draw_masked
  },
  {
    "game.panel.inventory_last_6.draw_order",
    &game.panel.inventory_last[5].sort_priority
  },
  {
    "game.panel.inventory_last_6.class",
    &game.panel.inventory_last[5].class
  },
  {
    "game.panel.inventory_last_6.style",
    &game.panel.inventory_last[5].style
  },
  {
    "game.panel.inventory_last_7.x",
    &game.panel.inventory_last[6].x
  },
  {
    "game.panel.inventory_last_7.y",
    &game.panel.inventory_last[6].y
  },
  {
    "game.panel.inventory_last_7.tile_size",
    &game.panel.inventory_last[6].size
  },
  {
    "game.panel.inventory_last_7.draw_masked",
    &game.panel.inventory_last[6].draw_masked
  },
  {
    "game.panel.inventory_last_7.draw_order",
    &game.panel.inventory_last[6].sort_priority
  },
  {
    "game.panel.inventory_last_7.class",
    &game.panel.inventory_last[6].class
  },
  {
    "game.panel.inventory_last_7.style",
    &game.panel.inventory_last[6].style
  },
  {
    "game.panel.inventory_last_8.x",
    &game.panel.inventory_last[7].x
  },
  {
    "game.panel.inventory_last_8.y",
    &game.panel.inventory_last[7].y
  },
  {
    "game.panel.inventory_last_8.tile_size",
    &game.panel.inventory_last[7].size
  },
  {
    "game.panel.inventory_last_8.draw_masked",
    &game.panel.inventory_last[7].draw_masked
  },
  {
    "game.panel.inventory_last_8.draw_order",
    &game.panel.inventory_last[7].sort_priority
  },
  {
    "game.panel.inventory_last_8.class",
    &game.panel.inventory_last[7].class
  },
  {
    "game.panel.inventory_last_8.style",
    &game.panel.inventory_last[7].style
  },
  {
    "game.panel.key_1.x",
    &game.panel.key[0].x
  },
  {
    "game.panel.key_1.y",
    &game.panel.key[0].y
  },
  {
    "game.panel.key_1.tile_size",
    &game.panel.key[0].size
  },
  {
    "game.panel.key_1.draw_masked",
    &game.panel.key[0].draw_masked
  },
  {
    "game.panel.key_1.draw_order",
    &game.panel.key[0].sort_priority
  },
  {
    "game.panel.key_1.class",
    &game.panel.key[0].class
  },
  {
    "game.panel.key_1.style",
    &game.panel.key[0].style
  },
  {
    "game.panel.key_2.x",
    &game.panel.key[1].x
  },
  {
    "game.panel.key_2.y",
    &game.panel.key[1].y
  },
  {
    "game.panel.key_2.tile_size",
    &game.panel.key[1].size
  },
  {
    "game.panel.key_2.draw_masked",
    &game.panel.key[1].draw_masked
  },
  {
    "game.panel.key_2.draw_order",
    &game.panel.key[1].sort_priority
  },
  {
    "game.panel.key_2.class",
    &game.panel.key[1].class
  },
  {
    "game.panel.key_2.style",
    &game.panel.key[1].style
  },
  {
    "game.panel.key_3.x",
    &game.panel.key[2].x
  },
  {
    "game.panel.key_3.y",
    &game.panel.key[2].y
  },
  {
    "game.panel.key_3.tile_size",
    &game.panel.key[2].size
  },
  {
    "game.panel.key_3.draw_masked",
    &game.panel.key[2].draw_masked
  },
  {
    "game.panel.key_3.draw_order",
    &game.panel.key[2].sort_priority
  },
  {
    "game.panel.key_3.class",
    &game.panel.key[2].class
  },
  {
    "game.panel.key_3.style",
    &game.panel.key[2].style
  },
  {
    "game.panel.key_4.x",
    &game.panel.key[3].x
  },
  {
    "game.panel.key_4.y",
    &game.panel.key[3].y
  },
  {
    "game.panel.key_4.tile_size",
    &game.panel.key[3].size
  },
  {
    "game.panel.key_4.draw_masked",
    &game.panel.key[3].draw_masked
  },
  {
    "game.panel.key_4.draw_order",
    &game.panel.key[3].sort_priority
  },
  {
    "game.panel.key_4.class",
    &game.panel.key[3].class
  },
  {
    "game.panel.key_4.style",
    &game.panel.key[3].style
  },
  {
    "game.panel.key_5.x",
    &game.panel.key[4].x
  },
  {
    "game.panel.key_5.y",
    &game.panel.key[4].y
  },
  {
    "game.panel.key_5.tile_size",
    &game.panel.key[4].size
  },
  {
    "game.panel.key_5.draw_masked",
    &game.panel.key[4].draw_masked
  },
  {
    "game.panel.key_5.draw_order",
    &game.panel.key[4].sort_priority
  },
  {
    "game.panel.key_5.class",
    &game.panel.key[4].class
  },
  {
    "game.panel.key_5.style",
    &game.panel.key[4].style
  },
  {
    "game.panel.key_6.x",
    &game.panel.key[5].x
  },
  {
    "game.panel.key_6.y",
    &game.panel.key[5].y
  },
  {
    "game.panel.key_6.tile_size",
    &game.panel.key[5].size
  },
  {
    "game.panel.key_6.draw_masked",
    &game.panel.key[5].draw_masked
  },
  {
    "game.panel.key_6.draw_order",
    &game.panel.key[5].sort_priority
  },
  {
    "game.panel.key_6.class",
    &game.panel.key[5].class
  },
  {
    "game.panel.key_6.style",
    &game.panel.key[5].style
  },
  {
    "game.panel.key_7.x",
    &game.panel.key[6].x
  },
  {
    "game.panel.key_7.y",
    &game.panel.key[6].y
  },
  {
    "game.panel.key_7.tile_size",
    &game.panel.key[6].size
  },
  {
    "game.panel.key_7.draw_masked",
    &game.panel.key[6].draw_masked
  },
  {
    "game.panel.key_7.draw_order",
    &game.panel.key[6].sort_priority
  },
  {
    "game.panel.key_7.class",
    &game.panel.key[6].class
  },
  {
    "game.panel.key_7.style",
    &game.panel.key[6].style
  },
  {
    "game.panel.key_8.x",
    &game.panel.key[7].x
  },
  {
    "game.panel.key_8.y",
    &game.panel.key[7].y
  },
  {
    "game.panel.key_8.tile_size",
    &game.panel.key[7].size
  },
  {
    "game.panel.key_8.draw_masked",
    &game.panel.key[7].draw_masked
  },
  {
    "game.panel.key_8.draw_order",
    &game.panel.key[7].sort_priority
  },
  {
    "game.panel.key_8.class",
    &game.panel.key[7].class
  },
  {
    "game.panel.key_8.style",
    &game.panel.key[7].style
  },
  {
    "game.panel.key_white.x",
    &game.panel.key_white.x
  },
  {
    "game.panel.key_white.y",
    &game.panel.key_white.y
  },
  {
    "game.panel.key_white.tile_size",
    &game.panel.key_white.size
  },
  {
    "game.panel.key_white.draw_masked",
    &game.panel.key_white.draw_masked
  },
  {
    "game.panel.key_white.draw_order",
    &game.panel.key_white.sort_priority
  },
  {
    "game.panel.key_white.class",
    &game.panel.key_white.class
  },
  {
    "game.panel.key_white.style",
    &game.panel.key_white.style
  },
  {
    "game.panel.key_white_count.x",
    &game.panel.key_white_count.x
  },
  {
    "game.panel.key_white_count.y",
    &game.panel.key_white_count.y
  },
  {
    "game.panel.key_white_count.align",
    &game.panel.key_white_count.align
  },
  {
    "game.panel.key_white_count.valign",
    &game.panel.key_white_count.valign
  },
  {
    "game.panel.key_white_count.digits",
    &game.panel.key_white_count.size
  },
  {
    "game.panel.key_white_count.font",
    &game.panel.key_white_count.font
  },
  {
    "game.panel.key_white_count.draw_masked",
    &game.panel.key_white_count.draw_masked
  },
  {
    "game.panel.key_white_count.draw_order",
    &game.panel.key_white_count.sort_priority
  },
  {
    "game.panel.key_white_count.class",
    &game.panel.key_white_count.class
  },
  {
    "game.panel.key_white_count.style",
    &game.panel.key_white_count.style
  },
  {
    "game.panel.score.x",
    &game.panel.score.x
  },
  {
    "game.panel.score.y",
    &game.panel.score.y
  },
  {
    "game.panel.score.align",
    &game.panel.score.align
  },
  {
    "game.panel.score.valign",
    &game.panel.score.valign
  },
  {
    "game.panel.score.digits",
    &game.panel.score.size
  },
  {
    "game.panel.score.font",
    &game.panel.score.font
  },
  {
    "game.panel.score.draw_masked",
    &game.panel.score.draw_masked
  },
  {
    "game.panel.score.draw_order",
    &game.panel.score.sort_priority
  },
  {
    "game.panel.score.class",
    &game.panel.score.class
  },
  {
    "game.panel.score.style",
    &game.panel.score.style
  },
  {
    "game.panel.highscore.x",
    &game.panel.highscore.x
  },
  {
    "game.panel.highscore.y",
    &game.panel.highscore.y
  },
  {
    "game.panel.highscore.align",
    &game.panel.highscore.align
  },
  {
    "game.panel.highscore.valign",
    &game.panel.highscore.valign
  },
  {
    "game.panel.highscore.digits",
    &game.panel.highscore.size
  },
  {
    "game.panel.highscore.font",
    &game.panel.highscore.font
  },
  {
    "game.panel.highscore.draw_masked",
    &game.panel.highscore.draw_masked
  },
  {
    "game.panel.highscore.draw_order",
    &game.panel.highscore.sort_priority
  },
  {
    "game.panel.highscore.class",
    &game.panel.highscore.class
  },
  {
    "game.panel.highscore.style",
    &game.panel.highscore.style
  },
  {
    "game.panel.time.x",
    &game.panel.time.x
  },
  {
    "game.panel.time.y",
    &game.panel.time.y
  },
  {
    "game.panel.time.align",
    &game.panel.time.align
  },
  {
    "game.panel.time.valign",
    &game.panel.time.valign
  },
  {
    "game.panel.time.digits",
    &game.panel.time.size
  },
  {
    "game.panel.time.font",
    &game.panel.time.font
  },
  {
    "game.panel.time.font_narrow",
    &game.panel.time.font_alt
  },
  {
    "game.panel.time.draw_masked",
    &game.panel.time.draw_masked
  },
  {
    "game.panel.time.draw_order",
    &game.panel.time.sort_priority
  },
  {
    "game.panel.time.class",
    &game.panel.time.class
  },
  {
    "game.panel.time.style",
    &game.panel.time.style
  },
  {
    "game.panel.time_hh.x",
    &game.panel.time_hh.x
  },
  {
    "game.panel.time_hh.y",
    &game.panel.time_hh.y
  },
  {
    "game.panel.time_hh.align",
    &game.panel.time_hh.align
  },
  {
    "game.panel.time_hh.valign",
    &game.panel.time_hh.valign
  },
  {
    "game.panel.time_hh.digits",
    &game.panel.time_hh.size
  },
  {
    "game.panel.time_hh.font",
    &game.panel.time_hh.font
  },
  {
    "game.panel.time_hh.draw_masked",
    &game.panel.time_hh.draw_masked
  },
  {
    "game.panel.time_hh.draw_order",
    &game.panel.time_hh.sort_priority
  },
  {
    "game.panel.time_hh.class",
    &game.panel.time_hh.class
  },
  {
    "game.panel.time_hh.style",
    &game.panel.time_hh.style
  },
  {
    "game.panel.time_mm.x",
    &game.panel.time_mm.x
  },
  {
    "game.panel.time_mm.y",
    &game.panel.time_mm.y
  },
  {
    "game.panel.time_mm.align",
    &game.panel.time_mm.align
  },
  {
    "game.panel.time_mm.valign",
    &game.panel.time_mm.valign
  },
  {
    "game.panel.time_mm.digits",
    &game.panel.time_mm.size
  },
  {
    "game.panel.time_mm.font",
    &game.panel.time_mm.font
  },
  {
    "game.panel.time_mm.draw_masked",
    &game.panel.time_mm.draw_masked
  },
  {
    "game.panel.time_mm.draw_order",
    &game.panel.time_mm.sort_priority
  },
  {
    "game.panel.time_mm.class",
    &game.panel.time_mm.class
  },
  {
    "game.panel.time_mm.style",
    &game.panel.time_mm.style
  },
  {
    "game.panel.time_ss.x",
    &game.panel.time_ss.x
  },
  {
    "game.panel.time_ss.y",
    &game.panel.time_ss.y
  },
  {
    "game.panel.time_ss.align",
    &game.panel.time_ss.align
  },
  {
    "game.panel.time_ss.valign",
    &game.panel.time_ss.valign
  },
  {
    "game.panel.time_ss.digits",
    &game.panel.time_ss.size
  },
  {
    "game.panel.time_ss.font",
    &game.panel.time_ss.font
  },
  {
    "game.panel.time_ss.draw_masked",
    &game.panel.time_ss.draw_masked
  },
  {
    "game.panel.time_ss.draw_order",
    &game.panel.time_ss.sort_priority
  },
  {
    "game.panel.time_ss.class",
    &game.panel.time_ss.class
  },
  {
    "game.panel.time_ss.style",
    &game.panel.time_ss.style
  },
  {
    "game.panel.time_anim.x",
    &game.panel.time_anim.x
  },
  {
    "game.panel.time_anim.y",
    &game.panel.time_anim.y
  },
  {
    "game.panel.time_anim.direction",
    &game.panel.time_anim.direction
  },
  {
    "game.panel.time_anim.class",
    &game.panel.time_anim.class
  },
  {
    "game.panel.time_anim.style",
    &game.panel.time_anim.style
  },
  {
    "game.panel.health.x",
    &game.panel.health.x
  },
  {
    "game.panel.health.y",
    &game.panel.health.y
  },
  {
    "game.panel.health.align",
    &game.panel.health.align
  },
  {
    "game.panel.health.valign",
    &game.panel.health.valign
  },
  {
    "game.panel.health.digits",
    &game.panel.health.size
  },
  {
    "game.panel.health.font",
    &game.panel.health.font
  },
  {
    "game.panel.health.font_narrow",
    &game.panel.health.font_alt
  },
  {
    "game.panel.health.draw_masked",
    &game.panel.health.draw_masked
  },
  {
    "game.panel.health.draw_order",
    &game.panel.health.sort_priority
  },
  {
    "game.panel.health.class",
    &game.panel.health.class
  },
  {
    "game.panel.health.style",
    &game.panel.health.style
  },
  {
    "game.panel.health_anim.x",
    &game.panel.health_anim.x
  },
  {
    "game.panel.health_anim.y",
    &game.panel.health_anim.y
  },
  {
    "game.panel.health_anim.direction",
    &game.panel.health_anim.direction
  },
  {
    "game.panel.health_anim.class",
    &game.panel.health_anim.class
  },
  {
    "game.panel.health_anim.style",
    &game.panel.health_anim.style
  },
  {
    "game.panel.frame.x",
    &game.panel.frame.x
  },
  {
    "game.panel.frame.y",
    &game.panel.frame.y
  },
  {
    "game.panel.frame.align",
    &game.panel.frame.align
  },
  {
    "game.panel.frame.valign",
    &game.panel.frame.valign
  },
  {
    "game.panel.frame.digits",
    &game.panel.frame.size
  },
  {
    "game.panel.frame.font",
    &game.panel.frame.font
  },
  {
    "game.panel.frame.draw_masked",
    &game.panel.frame.draw_masked
  },
  {
    "game.panel.frame.draw_order",
    &game.panel.frame.sort_priority
  },
  {
    "game.panel.frame.class",
    &game.panel.frame.class
  },
  {
    "game.panel.frame.style",
    &game.panel.frame.style
  },
  {
    "game.panel.shield_normal.x",
    &game.panel.shield_normal.x
  },
  {
    "game.panel.shield_normal.y",
    &game.panel.shield_normal.y
  },
  {
    "game.panel.shield_normal.tile_size",
    &game.panel.shield_normal.size
  },
  {
    "game.panel.shield_normal.draw_masked",
    &game.panel.shield_normal.draw_masked
  },
  {
    "game.panel.shield_normal.draw_order",
    &game.panel.shield_normal.sort_priority
  },
  {
    "game.panel.shield_normal_time.x",
    &game.panel.shield_normal_time.x
  },
  {
    "game.panel.shield_normal_time.y",
    &game.panel.shield_normal_time.y
  },
  {
    "game.panel.shield_normal_time.align",
    &game.panel.shield_normal_time.align
  },
  {
    "game.panel.shield_normal_time.valign",
    &game.panel.shield_normal_time.valign
  },
  {
    "game.panel.shield_normal_time.digits",
    &game.panel.shield_normal_time.size
  },
  {
    "game.panel.shield_normal_time.font",
    &game.panel.shield_normal_time.font
  },
  {
    "game.panel.shield_normal_time.draw_masked",
    &game.panel.shield_normal_time.draw_masked
  },
  {
    "game.panel.shield_normal_time.draw_order",
    &game.panel.shield_normal_time.sort_priority
  },
  {
    "game.panel.shield_normal_time.class",
    &game.panel.shield_normal_time.class
  },
  {
    "game.panel.shield_normal_time.style",
    &game.panel.shield_normal_time.style
  },
  {
    "game.panel.shield_deadly.x",
    &game.panel.shield_deadly.x
  },
  {
    "game.panel.shield_deadly.y",
    &game.panel.shield_deadly.y
  },
  {
    "game.panel.shield_deadly.tile_size",
    &game.panel.shield_deadly.size
  },
  {
    "game.panel.shield_deadly.draw_masked",
    &game.panel.shield_deadly.draw_masked
  },
  {
    "game.panel.shield_deadly.draw_order",
    &game.panel.shield_deadly.sort_priority
  },
  {
    "game.panel.shield_deadly_time.x",
    &game.panel.shield_deadly_time.x
  },
  {
    "game.panel.shield_deadly_time.y",
    &game.panel.shield_deadly_time.y
  },
  {
    "game.panel.shield_deadly_time.align",
    &game.panel.shield_deadly_time.align
  },
  {
    "game.panel.shield_deadly_time.valign",
    &game.panel.shield_deadly_time.valign
  },
  {
    "game.panel.shield_deadly_time.digits",
    &game.panel.shield_deadly_time.size
  },
  {
    "game.panel.shield_deadly_time.font",
    &game.panel.shield_deadly_time.font
  },
  {
    "game.panel.shield_deadly_time.draw_masked",
    &game.panel.shield_deadly_time.draw_masked
  },
  {
    "game.panel.shield_deadly_time.draw_order",
    &game.panel.shield_deadly_time.sort_priority
  },
  {
    "game.panel.shield_deadly_time.class",
    &game.panel.shield_deadly_time.class
  },
  {
    "game.panel.shield_deadly_time.style",
    &game.panel.shield_deadly_time.style
  },
  {
    "game.panel.exit.x",
    &game.panel.exit.x
  },
  {
    "game.panel.exit.y",
    &game.panel.exit.y
  },
  {
    "game.panel.exit.tile_size",
    &game.panel.exit.size
  },
  {
    "game.panel.exit.draw_masked",
    &game.panel.exit.draw_masked
  },
  {
    "game.panel.exit.draw_order",
    &game.panel.exit.sort_priority
  },
  {
    "game.panel.exit.class",
    &game.panel.exit.class
  },
  {
    "game.panel.exit.style",
    &game.panel.exit.style
  },
  {
    "game.panel.emc_magic_ball.x",
    &game.panel.emc_magic_ball.x
  },
  {
    "game.panel.emc_magic_ball.y",
    &game.panel.emc_magic_ball.y
  },
  {
    "game.panel.emc_magic_ball.tile_size",
    &game.panel.emc_magic_ball.size
  },
  {
    "game.panel.emc_magic_ball.draw_masked",
    &game.panel.emc_magic_ball.draw_masked
  },
  {
    "game.panel.emc_magic_ball.draw_order",
    &game.panel.emc_magic_ball.sort_priority
  },
  {
    "game.panel.emc_magic_ball_switch.x",
    &game.panel.emc_magic_ball_switch.x
  },
  {
    "game.panel.emc_magic_ball_switch.y",
    &game.panel.emc_magic_ball_switch.y
  },
  {
    "game.panel.emc_magic_ball_switch.tile_size",
    &game.panel.emc_magic_ball_switch.size
  },
  {
    "game.panel.emc_magic_ball_switch.draw_masked",
    &game.panel.emc_magic_ball_switch.draw_masked
  },
  {
    "game.panel.emc_magic_ball_switch.draw_order",
    &game.panel.emc_magic_ball_switch.sort_priority
  },
  {
    "game.panel.emc_magic_ball_switch.class",
    &game.panel.emc_magic_ball_switch.class
  },
  {
    "game.panel.emc_magic_ball_switch.style",
    &game.panel.emc_magic_ball_switch.style
  },
  {
    "game.panel.light_switch.x",
    &game.panel.light_switch.x
  },
  {
    "game.panel.light_switch.y",
    &game.panel.light_switch.y
  },
  {
    "game.panel.light_switch.tile_size",
    &game.panel.light_switch.size
  },
  {
    "game.panel.light_switch.draw_masked",
    &game.panel.light_switch.draw_masked
  },
  {
    "game.panel.light_switch.draw_order",
    &game.panel.light_switch.sort_priority
  },
  {
    "game.panel.light_switch_time.x",
    &game.panel.light_switch_time.x
  },
  {
    "game.panel.light_switch_time.y",
    &game.panel.light_switch_time.y
  },
  {
    "game.panel.light_switch_time.align",
    &game.panel.light_switch_time.align
  },
  {
    "game.panel.light_switch_time.valign",
    &game.panel.light_switch_time.valign
  },
  {
    "game.panel.light_switch_time.digits",
    &game.panel.light_switch_time.size
  },
  {
    "game.panel.light_switch_time.font",
    &game.panel.light_switch_time.font
  },
  {
    "game.panel.light_switch_time.draw_masked",
    &game.panel.light_switch_time.draw_masked
  },
  {
    "game.panel.light_switch_time.draw_order",
    &game.panel.light_switch_time.sort_priority
  },
  {
    "game.panel.light_switch_time.class",
    &game.panel.light_switch_time.class
  },
  {
    "game.panel.light_switch_time.style",
    &game.panel.light_switch_time.style
  },
  {
    "game.panel.timegate_switch.x",
    &game.panel.timegate_switch.x
  },
  {
    "game.panel.timegate_switch.y",
    &game.panel.timegate_switch.y
  },
  {
    "game.panel.timegate_switch.tile_size",
    &game.panel.timegate_switch.size
  },
  {
    "game.panel.timegate_switch.draw_masked",
    &game.panel.timegate_switch.draw_masked
  },
  {
    "game.panel.timegate_switch.draw_order",
    &game.panel.timegate_switch.sort_priority
  },
  {
    "game.panel.timegate_switch_time.x",
    &game.panel.timegate_switch_time.x
  },
  {
    "game.panel.timegate_switch_time.y",
    &game.panel.timegate_switch_time.y
  },
  {
    "game.panel.timegate_switch_time.align",
    &game.panel.timegate_switch_time.align
  },
  {
    "game.panel.timegate_switch_time.valign",
    &game.panel.timegate_switch_time.valign
  },
  {
    "game.panel.timegate_switch_time.digits",
    &game.panel.timegate_switch_time.size
  },
  {
    "game.panel.timegate_switch_time.font",
    &game.panel.timegate_switch_time.font
  },
  {
    "game.panel.timegate_switch_time.draw_masked",
    &game.panel.timegate_switch_time.draw_masked
  },
  {
    "game.panel.timegate_switch_time.draw_order",
    &game.panel.timegate_switch_time.sort_priority
  },
  {
    "game.panel.timegate_switch_time.class",
    &game.panel.timegate_switch_time.class
  },
  {
    "game.panel.timegate_switch_time.style",
    &game.panel.timegate_switch_time.style
  },
  {
    "game.panel.switchgate_switch.x",
    &game.panel.switchgate_switch.x
  },
  {
    "game.panel.switchgate_switch.y",
    &game.panel.switchgate_switch.y
  },
  {
    "game.panel.switchgate_switch.tile_size",
    &game.panel.switchgate_switch.size
  },
  {
    "game.panel.switchgate_switch.draw_masked",
    &game.panel.switchgate_switch.draw_masked
  },
  {
    "game.panel.switchgate_switch.draw_order",
    &game.panel.switchgate_switch.sort_priority
  },
  {
    "game.panel.switchgate_switch.class",
    &game.panel.switchgate_switch.class
  },
  {
    "game.panel.switchgate_switch.style",
    &game.panel.switchgate_switch.style
  },
  {
    "game.panel.emc_lenses.x",
    &game.panel.emc_lenses.x
  },
  {
    "game.panel.emc_lenses.y",
    &game.panel.emc_lenses.y
  },
  {
    "game.panel.emc_lenses.tile_size",
    &game.panel.emc_lenses.size
  },
  {
    "game.panel.emc_lenses.draw_masked",
    &game.panel.emc_lenses.draw_masked
  },
  {
    "game.panel.emc_lenses.draw_order",
    &game.panel.emc_lenses.sort_priority
  },
  {
    "game.panel.emc_lenses.class",
    &game.panel.emc_lenses.class
  },
  {
    "game.panel.emc_lenses.style",
    &game.panel.emc_lenses.style
  },
  {
    "game.panel.emc_lenses_time.x",
    &game.panel.emc_lenses_time.x
  },
  {
    "game.panel.emc_lenses_time.y",
    &game.panel.emc_lenses_time.y
  },
  {
    "game.panel.emc_lenses_time.align",
    &game.panel.emc_lenses_time.align
  },
  {
    "game.panel.emc_lenses_time.valign",
    &game.panel.emc_lenses_time.valign
  },
  {
    "game.panel.emc_lenses_time.digits",
    &game.panel.emc_lenses_time.size
  },
  {
    "game.panel.emc_lenses_time.font",
    &game.panel.emc_lenses_time.font
  },
  {
    "game.panel.emc_lenses_time.draw_masked",
    &game.panel.emc_lenses_time.draw_masked
  },
  {
    "game.panel.emc_lenses_time.draw_order",
    &game.panel.emc_lenses_time.sort_priority
  },
  {
    "game.panel.emc_lenses_time.class",
    &game.panel.emc_lenses_time.class
  },
  {
    "game.panel.emc_lenses_time.style",
    &game.panel.emc_lenses_time.style
  },
  {
    "game.panel.emc_magnifier.x",
    &game.panel.emc_magnifier.x
  },
  {
    "game.panel.emc_magnifier.y",
    &game.panel.emc_magnifier.y
  },
  {
    "game.panel.emc_magnifier.tile_size",
    &game.panel.emc_magnifier.size
  },
  {
    "game.panel.emc_magnifier.draw_masked",
    &game.panel.emc_magnifier.draw_masked
  },
  {
    "game.panel.emc_magnifier.draw_order",
    &game.panel.emc_magnifier.sort_priority
  },
  {
    "game.panel.emc_magnifier.class",
    &game.panel.emc_magnifier.class
  },
  {
    "game.panel.emc_magnifier.style",
    &game.panel.emc_magnifier.style
  },
  {
    "game.panel.emc_magnifier_time.x",
    &game.panel.emc_magnifier_time.x
  },
  {
    "game.panel.emc_magnifier_time.y",
    &game.panel.emc_magnifier_time.y
  },
  {
    "game.panel.emc_magnifier_time.align",
    &game.panel.emc_magnifier_time.align
  },
  {
    "game.panel.emc_magnifier_time.valign",
    &game.panel.emc_magnifier_time.valign
  },
  {
    "game.panel.emc_magnifier_time.digits",
    &game.panel.emc_magnifier_time.size
  },
  {
    "game.panel.emc_magnifier_time.font",
    &game.panel.emc_magnifier_time.font
  },
  {
    "game.panel.emc_magnifier_time.draw_masked",
    &game.panel.emc_magnifier_time.draw_masked
  },
  {
    "game.panel.emc_magnifier_time.draw_order",
    &game.panel.emc_magnifier_time.sort_priority
  },
  {
    "game.panel.emc_magnifier_time.class",
    &game.panel.emc_magnifier_time.class
  },
  {
    "game.panel.emc_magnifier_time.style",
    &game.panel.emc_magnifier_time.style
  },
  {
    "game.panel.balloon_switch.x",
    &game.panel.balloon_switch.x
  },
  {
    "game.panel.balloon_switch.y",
    &game.panel.balloon_switch.y
  },
  {
    "game.panel.balloon_switch.tile_size",
    &game.panel.balloon_switch.size
  },
  {
    "game.panel.balloon_switch.draw_masked",
    &game.panel.balloon_switch.draw_masked
  },
  {
    "game.panel.balloon_switch.draw_order",
    &game.panel.balloon_switch.sort_priority
  },
  {
    "game.panel.balloon_switch.class",
    &game.panel.balloon_switch.class
  },
  {
    "game.panel.balloon_switch.style",
    &game.panel.balloon_switch.style
  },
  {
    "game.panel.dynabomb_number.x",
    &game.panel.dynabomb_number.x
  },
  {
    "game.panel.dynabomb_number.y",
    &game.panel.dynabomb_number.y
  },
  {
    "game.panel.dynabomb_number.align",
    &game.panel.dynabomb_number.align
  },
  {
    "game.panel.dynabomb_number.valign",
    &game.panel.dynabomb_number.valign
  },
  {
    "game.panel.dynabomb_number.digits",
    &game.panel.dynabomb_number.size
  },
  {
    "game.panel.dynabomb_number.font",
    &game.panel.dynabomb_number.font
  },
  {
    "game.panel.dynabomb_number.draw_masked",
    &game.panel.dynabomb_number.draw_masked
  },
  {
    "game.panel.dynabomb_number.draw_order",
    &game.panel.dynabomb_number.sort_priority
  },
  {
    "game.panel.dynabomb_number.class",
    &game.panel.dynabomb_number.class
  },
  {
    "game.panel.dynabomb_number.style",
    &game.panel.dynabomb_number.style
  },
  {
    "game.panel.dynabomb_size.x",
    &game.panel.dynabomb_size.x
  },
  {
    "game.panel.dynabomb_size.y",
    &game.panel.dynabomb_size.y
  },
  {
    "game.panel.dynabomb_size.align",
    &game.panel.dynabomb_size.align
  },
  {
    "game.panel.dynabomb_size.valign",
    &game.panel.dynabomb_size.valign
  },
  {
    "game.panel.dynabomb_size.digits",
    &game.panel.dynabomb_size.size
  },
  {
    "game.panel.dynabomb_size.font",
    &game.panel.dynabomb_size.font
  },
  {
    "game.panel.dynabomb_size.draw_masked",
    &game.panel.dynabomb_size.draw_masked
  },
  {
    "game.panel.dynabomb_size.draw_order",
    &game.panel.dynabomb_size.sort_priority
  },
  {
    "game.panel.dynabomb_size.class",
    &game.panel.dynabomb_size.class
  },
  {
    "game.panel.dynabomb_size.style",
    &game.panel.dynabomb_size.style
  },
  {
    "game.panel.dynabomb_power.x",
    &game.panel.dynabomb_power.x
  },
  {
    "game.panel.dynabomb_power.y",
    &game.panel.dynabomb_power.y
  },
  {
    "game.panel.dynabomb_power.tile_size",
    &game.panel.dynabomb_power.size
  },
  {
    "game.panel.dynabomb_power.draw_masked",
    &game.panel.dynabomb_power.draw_masked
  },
  {
    "game.panel.dynabomb_power.draw_order",
    &game.panel.dynabomb_power.sort_priority
  },
  {
    "game.panel.dynabomb_power.class",
    &game.panel.dynabomb_power.class
  },
  {
    "game.panel.dynabomb_power.style",
    &game.panel.dynabomb_power.style
  },
  {
    "game.panel.penguins.x",
    &game.panel.penguins.x
  },
  {
    "game.panel.penguins.y",
    &game.panel.penguins.y
  },
  {
    "game.panel.penguins.align",
    &game.panel.penguins.align
  },
  {
    "game.panel.penguins.valign",
    &game.panel.penguins.valign
  },
  {
    "game.panel.penguins.digits",
    &game.panel.penguins.size
  },
  {
    "game.panel.penguins.font",
    &game.panel.penguins.font
  },
  {
    "game.panel.penguins.draw_masked",
    &game.panel.penguins.draw_masked
  },
  {
    "game.panel.penguins.draw_order",
    &game.panel.penguins.sort_priority
  },
  {
    "game.panel.penguins.class",
    &game.panel.penguins.class
  },
  {
    "game.panel.penguins.style",
    &game.panel.penguins.style
  },
  {
    "game.panel.sokoban_objects.x",
    &game.panel.sokoban_objects.x
  },
  {
    "game.panel.sokoban_objects.y",
    &game.panel.sokoban_objects.y
  },
  {
    "game.panel.sokoban_objects.align",
    &game.panel.sokoban_objects.align
  },
  {
    "game.panel.sokoban_objects.valign",
    &game.panel.sokoban_objects.valign
  },
  {
    "game.panel.sokoban_objects.digits",
    &game.panel.sokoban_objects.size
  },
  {
    "game.panel.sokoban_objects.font",
    &game.panel.sokoban_objects.font
  },
  {
    "game.panel.sokoban_objects.draw_masked",
    &game.panel.sokoban_objects.draw_masked
  },
  {
    "game.panel.sokoban_objects.draw_order",
    &game.panel.sokoban_objects.sort_priority
  },
  {
    "game.panel.sokoban_objects.class",
    &game.panel.sokoban_objects.class
  },
  {
    "game.panel.sokoban_objects.style",
    &game.panel.sokoban_objects.style
  },
  {
    "game.panel.sokoban_fields.x",
    &game.panel.sokoban_fields.x
  },
  {
    "game.panel.sokoban_fields.y",
    &game.panel.sokoban_fields.y
  },
  {
    "game.panel.sokoban_fields.align",
    &game.panel.sokoban_fields.align
  },
  {
    "game.panel.sokoban_fields.valign",
    &game.panel.sokoban_fields.valign
  },
  {
    "game.panel.sokoban_fields.digits",
    &game.panel.sokoban_fields.size
  },
  {
    "game.panel.sokoban_fields.font",
    &game.panel.sokoban_fields.font
  },
  {
    "game.panel.sokoban_fields.draw_masked",
    &game.panel.sokoban_fields.draw_masked
  },
  {
    "game.panel.sokoban_fields.draw_order",
    &game.panel.sokoban_fields.sort_priority
  },
  {
    "game.panel.sokoban_fields.class",
    &game.panel.sokoban_fields.class
  },
  {
    "game.panel.sokoban_fields.style",
    &game.panel.sokoban_fields.style
  },
  {
    "game.panel.robot_wheel.x",
    &game.panel.robot_wheel.x
  },
  {
    "game.panel.robot_wheel.y",
    &game.panel.robot_wheel.y
  },
  {
    "game.panel.robot_wheel.tile_size",
    &game.panel.robot_wheel.size
  },
  {
    "game.panel.robot_wheel.draw_masked",
    &game.panel.robot_wheel.draw_masked
  },
  {
    "game.panel.robot_wheel.draw_order",
    &game.panel.robot_wheel.sort_priority
  },
  {
    "game.panel.robot_wheel.class",
    &game.panel.robot_wheel.class
  },
  {
    "game.panel.robot_wheel.style",
    &game.panel.robot_wheel.style
  },
  {
    "game.panel.conveyor_belt_1.x",
    &game.panel.conveyor_belt[0].x
  },
  {
    "game.panel.conveyor_belt_1.y",
    &game.panel.conveyor_belt[0].y
  },
  {
    "game.panel.conveyor_belt_1.tile_size",
    &game.panel.conveyor_belt[0].size
  },
  {
    "game.panel.conveyor_belt_1.draw_masked",
    &game.panel.conveyor_belt[0].draw_masked
  },
  {
    "game.panel.conveyor_belt_1.draw_order",
    &game.panel.conveyor_belt[0].sort_priority
  },
  {
    "game.panel.conveyor_belt_1.class",
    &game.panel.conveyor_belt[0].class
  },
  {
    "game.panel.conveyor_belt_1.style",
    &game.panel.conveyor_belt[0].style
  },
  {
    "game.panel.conveyor_belt_1_switch.x",
    &game.panel.conveyor_belt_switch[0].x
  },
  {
    "game.panel.conveyor_belt_1_switch.y",
    &game.panel.conveyor_belt_switch[0].y
  },
  {
    "game.panel.conveyor_belt_1_switch.tile_size",
    &game.panel.conveyor_belt_switch[0].size
  },
  {
    "game.panel.conveyor_belt_1_switch.draw_masked",
    &game.panel.conveyor_belt_switch[0].draw_masked
  },
  {
    "game.panel.conveyor_belt_1_switch.draw_order",
    &game.panel.conveyor_belt_switch[0].sort_priority
  },
  {
    "game.panel.conveyor_belt_1_switch.class",
    &game.panel.conveyor_belt_switch[0].class
  },
  {
    "game.panel.conveyor_belt_1_switch.style",
    &game.panel.conveyor_belt_switch[0].style
  },
  {
    "game.panel.conveyor_belt_2.x",
    &game.panel.conveyor_belt[1].x
  },
  {
    "game.panel.conveyor_belt_2.y",
    &game.panel.conveyor_belt[1].y
  },
  {
    "game.panel.conveyor_belt_2.tile_size",
    &game.panel.conveyor_belt[1].size
  },
  {
    "game.panel.conveyor_belt_2.draw_masked",
    &game.panel.conveyor_belt[1].draw_masked
  },
  {
    "game.panel.conveyor_belt_2.draw_order",
    &game.panel.conveyor_belt[1].sort_priority
  },
  {
    "game.panel.conveyor_belt_2.class",
    &game.panel.conveyor_belt[1].class
  },
  {
    "game.panel.conveyor_belt_2.style",
    &game.panel.conveyor_belt[1].style
  },
  {
    "game.panel.conveyor_belt_2_switch.x",
    &game.panel.conveyor_belt_switch[1].x
  },
  {
    "game.panel.conveyor_belt_2_switch.y",
    &game.panel.conveyor_belt_switch[1].y
  },
  {
    "game.panel.conveyor_belt_2_switch.tile_size",
    &game.panel.conveyor_belt_switch[1].size
  },
  {
    "game.panel.conveyor_belt_2_switch.draw_masked",
    &game.panel.conveyor_belt_switch[1].draw_masked
  },
  {
    "game.panel.conveyor_belt_2_switch.draw_order",
    &game.panel.conveyor_belt_switch[1].sort_priority
  },
  {
    "game.panel.conveyor_belt_2_switch.class",
    &game.panel.conveyor_belt_switch[1].class
  },
  {
    "game.panel.conveyor_belt_2_switch.style",
    &game.panel.conveyor_belt_switch[1].style
  },
  {
    "game.panel.conveyor_belt_3.x",
    &game.panel.conveyor_belt[2].x
  },
  {
    "game.panel.conveyor_belt_3.y",
    &game.panel.conveyor_belt[2].y
  },
  {
    "game.panel.conveyor_belt_3.tile_size",
    &game.panel.conveyor_belt[2].size
  },
  {
    "game.panel.conveyor_belt_3.draw_masked",
    &game.panel.conveyor_belt[2].draw_masked
  },
  {
    "game.panel.conveyor_belt_3.draw_order",
    &game.panel.conveyor_belt[2].sort_priority
  },
  {
    "game.panel.conveyor_belt_3.class",
    &game.panel.conveyor_belt[2].class
  },
  {
    "game.panel.conveyor_belt_3.style",
    &game.panel.conveyor_belt[2].style
  },
  {
    "game.panel.conveyor_belt_3_switch.x",
    &game.panel.conveyor_belt_switch[2].x
  },
  {
    "game.panel.conveyor_belt_3_switch.y",
    &game.panel.conveyor_belt_switch[2].y
  },
  {
    "game.panel.conveyor_belt_3_switch.tile_size",
    &game.panel.conveyor_belt_switch[2].size
  },
  {
    "game.panel.conveyor_belt_3_switch.draw_masked",
    &game.panel.conveyor_belt_switch[2].draw_masked
  },
  {
    "game.panel.conveyor_belt_3_switch.draw_order",
    &game.panel.conveyor_belt_switch[2].sort_priority
  },
  {
    "game.panel.conveyor_belt_3_switch.class",
    &game.panel.conveyor_belt_switch[2].class
  },
  {
    "game.panel.conveyor_belt_3_switch.style",
    &game.panel.conveyor_belt_switch[2].style
  },
  {
    "game.panel.conveyor_belt_4.x",
    &game.panel.conveyor_belt[3].x
  },
  {
    "game.panel.conveyor_belt_4.y",
    &game.panel.conveyor_belt[3].y
  },
  {
    "game.panel.conveyor_belt_4.tile_size",
    &game.panel.conveyor_belt[3].size
  },
  {
    "game.panel.conveyor_belt_4.draw_masked",
    &game.panel.conveyor_belt[3].draw_masked
  },
  {
    "game.panel.conveyor_belt_4.draw_order",
    &game.panel.conveyor_belt[3].sort_priority
  },
  {
    "game.panel.conveyor_belt_4.class",
    &game.panel.conveyor_belt[3].class
  },
  {
    "game.panel.conveyor_belt_4.style",
    &game.panel.conveyor_belt[3].style
  },
  {
    "game.panel.conveyor_belt_4_switch.x",
    &game.panel.conveyor_belt_switch[3].x
  },
  {
    "game.panel.conveyor_belt_4_switch.y",
    &game.panel.conveyor_belt_switch[3].y
  },
  {
    "game.panel.conveyor_belt_4_switch.tile_size",
    &game.panel.conveyor_belt_switch[3].size
  },
  {
    "game.panel.conveyor_belt_4_switch.draw_masked",
    &game.panel.conveyor_belt_switch[3].draw_masked
  },
  {
    "game.panel.conveyor_belt_4_switch.draw_order",
    &game.panel.conveyor_belt_switch[3].sort_priority
  },
  {
    "game.panel.conveyor_belt_4_switch.class",
    &game.panel.conveyor_belt_switch[3].class
  },
  {
    "game.panel.conveyor_belt_4_switch.style",
    &game.panel.conveyor_belt_switch[3].style
  },
  {
    "game.panel.magic_wall.x",
    &game.panel.magic_wall.x
  },
  {
    "game.panel.magic_wall.y",
    &game.panel.magic_wall.y
  },
  {
    "game.panel.magic_wall.tile_size",
    &game.panel.magic_wall.size
  },
  {
    "game.panel.magic_wall.draw_masked",
    &game.panel.magic_wall.draw_masked
  },
  {
    "game.panel.magic_wall.draw_order",
    &game.panel.magic_wall.sort_priority
  },
  {
    "game.panel.magic_wall.class",
    &game.panel.magic_wall.class
  },
  {
    "game.panel.magic_wall.style",
    &game.panel.magic_wall.style
  },
  {
    "game.panel.magic_wall_time.x",
    &game.panel.magic_wall_time.x
  },
  {
    "game.panel.magic_wall_time.y",
    &game.panel.magic_wall_time.y
  },
  {
    "game.panel.magic_wall_time.align",
    &game.panel.magic_wall_time.align
  },
  {
    "game.panel.magic_wall_time.valign",
    &game.panel.magic_wall_time.valign
  },
  {
    "game.panel.magic_wall_time.digits",
    &game.panel.magic_wall_time.size
  },
  {
    "game.panel.magic_wall_time.font",
    &game.panel.magic_wall_time.font
  },
  {
    "game.panel.magic_wall_time.draw_masked",
    &game.panel.magic_wall_time.draw_masked
  },
  {
    "game.panel.magic_wall_time.draw_order",
    &game.panel.magic_wall_time.sort_priority
  },
  {
    "game.panel.magic_wall_time.class",
    &game.panel.magic_wall_time.class
  },
  {
    "game.panel.magic_wall_time.style",
    &game.panel.magic_wall_time.style
  },
  {
    "game.panel.gravity_state.x",
    &game.panel.gravity_state.x
  },
  {
    "game.panel.gravity_state.y",
    &game.panel.gravity_state.y
  },
  {
    "game.panel.gravity_state.align",
    &game.panel.gravity_state.align
  },
  {
    "game.panel.gravity_state.valign",
    &game.panel.gravity_state.valign
  },
  {
    "game.panel.gravity_state.chars",
    &game.panel.gravity_state.size
  },
  {
    "game.panel.gravity_state.font",
    &game.panel.gravity_state.font
  },
  {
    "game.panel.gravity_state.font_active",
    &game.panel.gravity_state.font_alt
  },
  {
    "game.panel.gravity_state.draw_masked",
    &game.panel.gravity_state.draw_masked
  },
  {
    "game.panel.gravity_state.draw_order",
    &game.panel.gravity_state.sort_priority
  },
  {
    "game.panel.gravity_state.class",
    &game.panel.gravity_state.class
  },
  {
    "game.panel.gravity_state.style",
    &game.panel.gravity_state.style
  },
  {
    "game.panel.graphic_1.x",
    &game.panel.graphic[0].x
  },
  {
    "game.panel.graphic_1.y",
    &game.panel.graphic[0].y
  },
  {
    "game.panel.graphic_1.draw_masked",
    &game.panel.graphic[0].draw_masked
  },
  {
    "game.panel.graphic_1.draw_order",
    &game.panel.graphic[0].sort_priority
  },
  {
    "game.panel.graphic_1.class",
    &game.panel.graphic[0].class
  },
  {
    "game.panel.graphic_1.style",
    &game.panel.graphic[0].style
  },
  {
    "game.panel.graphic_2.x",
    &game.panel.graphic[1].x
  },
  {
    "game.panel.graphic_2.y",
    &game.panel.graphic[1].y
  },
  {
    "game.panel.graphic_2.draw_masked",
    &game.panel.graphic[1].draw_masked
  },
  {
    "game.panel.graphic_2.draw_order",
    &game.panel.graphic[1].sort_priority
  },
  {
    "game.panel.graphic_2.class",
    &game.panel.graphic[1].class
  },
  {
    "game.panel.graphic_2.style",
    &game.panel.graphic[1].style
  },
  {
    "game.panel.graphic_3.x",
    &game.panel.graphic[2].x
  },
  {
    "game.panel.graphic_3.y",
    &game.panel.graphic[2].y
  },
  {
    "game.panel.graphic_3.draw_masked",
    &game.panel.graphic[2].draw_masked
  },
  {
    "game.panel.graphic_3.draw_order",
    &game.panel.graphic[2].sort_priority
  },
  {
    "game.panel.graphic_3.class",
    &game.panel.graphic[2].class
  },
  {
    "game.panel.graphic_3.style",
    &game.panel.graphic[2].style
  },
  {
    "game.panel.graphic_4.x",
    &game.panel.graphic[3].x
  },
  {
    "game.panel.graphic_4.y",
    &game.panel.graphic[3].y
  },
  {
    "game.panel.graphic_4.draw_masked",
    &game.panel.graphic[3].draw_masked
  },
  {
    "game.panel.graphic_4.draw_order",
    &game.panel.graphic[3].sort_priority
  },
  {
    "game.panel.graphic_4.class",
    &game.panel.graphic[3].class
  },
  {
    "game.panel.graphic_4.style",
    &game.panel.graphic[3].style
  },
  {
    "game.panel.graphic_5.x",
    &game.panel.graphic[4].x
  },
  {
    "game.panel.graphic_5.y",
    &game.panel.graphic[4].y
  },
  {
    "game.panel.graphic_5.draw_masked",
    &game.panel.graphic[4].draw_masked
  },
  {
    "game.panel.graphic_5.draw_order",
    &game.panel.graphic[4].sort_priority
  },
  {
    "game.panel.graphic_5.class",
    &game.panel.graphic[4].class
  },
  {
    "game.panel.graphic_5.style",
    &game.panel.graphic[4].style
  },
  {
    "game.panel.graphic_6.x",
    &game.panel.graphic[5].x
  },
  {
    "game.panel.graphic_6.y",
    &game.panel.graphic[5].y
  },
  {
    "game.panel.graphic_6.draw_masked",
    &game.panel.graphic[5].draw_masked
  },
  {
    "game.panel.graphic_6.draw_order",
    &game.panel.graphic[5].sort_priority
  },
  {
    "game.panel.graphic_6.class",
    &game.panel.graphic[5].class
  },
  {
    "game.panel.graphic_6.style",
    &game.panel.graphic[5].style
  },
  {
    "game.panel.graphic_7.x",
    &game.panel.graphic[6].x
  },
  {
    "game.panel.graphic_7.y",
    &game.panel.graphic[6].y
  },
  {
    "game.panel.graphic_7.draw_masked",
    &game.panel.graphic[6].draw_masked
  },
  {
    "game.panel.graphic_7.draw_order",
    &game.panel.graphic[6].sort_priority
  },
  {
    "game.panel.graphic_7.class",
    &game.panel.graphic[6].class
  },
  {
    "game.panel.graphic_7.style",
    &game.panel.graphic[6].style
  },
  {
    "game.panel.graphic_8.x",
    &game.panel.graphic[7].x
  },
  {
    "game.panel.graphic_8.y",
    &game.panel.graphic[7].y
  },
  {
    "game.panel.graphic_8.draw_masked",
    &game.panel.graphic[7].draw_masked
  },
  {
    "game.panel.graphic_8.draw_order",
    &game.panel.graphic[7].sort_priority
  },
  {
    "game.panel.graphic_8.class",
    &game.panel.graphic[7].class
  },
  {
    "game.panel.graphic_8.style",
    &game.panel.graphic[7].style
  },
  {
    "game.panel.element_1.x",
    &game.panel.element[0].x
  },
  {
    "game.panel.element_1.y",
    &game.panel.element[0].y
  },
  {
    "game.panel.element_1.tile_size",
    &game.panel.element[0].size
  },
  {
    "game.panel.element_1.element",
    &game.panel.element[0].id
  },
  {
    "game.panel.element_1.draw_masked",
    &game.panel.element[0].draw_masked
  },
  {
    "game.panel.element_1.draw_order",
    &game.panel.element[0].sort_priority
  },
  {
    "game.panel.element_1.class",
    &game.panel.element[0].class
  },
  {
    "game.panel.element_1.style",
    &game.panel.element[0].style
  },
  {
    "game.panel.element_1_count.x",
    &game.panel.element_count[0].x
  },
  {
    "game.panel.element_1_count.y",
    &game.panel.element_count[0].y
  },
  {
    "game.panel.element_1_count.align",
    &game.panel.element_count[0].align
  },
  {
    "game.panel.element_1_count.valign",
    &game.panel.element_count[0].valign
  },
  {
    "game.panel.element_1_count.digits",
    &game.panel.element_count[0].size
  },
  {
    "game.panel.element_1_count.font",
    &game.panel.element_count[0].font
  },
  {
    "game.panel.element_1_count.element",
    &game.panel.element_count[0].id
  },
  {
    "game.panel.element_1_count.draw_masked",
    &game.panel.element_count[0].draw_masked
  },
  {
    "game.panel.element_1_count.draw_order",
    &game.panel.element_count[0].sort_priority
  },
  {
    "game.panel.element_1_count.class",
    &game.panel.element_count[0].class
  },
  {
    "game.panel.element_1_count.style",
    &game.panel.element_count[0].style
  },
  {
    "game.panel.element_2.x",
    &game.panel.element[1].x
  },
  {
    "game.panel.element_2.y",
    &game.panel.element[1].y
  },
  {
    "game.panel.element_2.tile_size",
    &game.panel.element[1].size
  },
  {
    "game.panel.element_2.element",
    &game.panel.element[1].id
  },
  {
    "game.panel.element_2.draw_masked",
    &game.panel.element[1].draw_masked
  },
  {
    "game.panel.element_2.draw_order",
    &game.panel.element[1].sort_priority
  },
  {
    "game.panel.element_2.class",
    &game.panel.element[1].class
  },
  {
    "game.panel.element_2.style",
    &game.panel.element[1].style
  },
  {
    "game.panel.element_2_count.x",
    &game.panel.element_count[1].x
  },
  {
    "game.panel.element_2_count.y",
    &game.panel.element_count[1].y
  },
  {
    "game.panel.element_2_count.align",
    &game.panel.element_count[1].align
  },
  {
    "game.panel.element_2_count.valign",
    &game.panel.element_count[1].valign
  },
  {
    "game.panel.element_2_count.digits",
    &game.panel.element_count[1].size
  },
  {
    "game.panel.element_2_count.font",
    &game.panel.element_count[1].font
  },
  {
    "game.panel.element_2_count.element",
    &game.panel.element_count[1].id
  },
  {
    "game.panel.element_2_count.draw_masked",
    &game.panel.element_count[1].draw_masked
  },
  {
    "game.panel.element_2_count.draw_order",
    &game.panel.element_count[1].sort_priority
  },
  {
    "game.panel.element_2_count.class",
    &game.panel.element_count[1].class
  },
  {
    "game.panel.element_2_count.style",
    &game.panel.element_count[1].style
  },
  {
    "game.panel.element_3.x",
    &game.panel.element[2].x
  },
  {
    "game.panel.element_3.y",
    &game.panel.element[2].y
  },
  {
    "game.panel.element_3.tile_size",
    &game.panel.element[2].size
  },
  {
    "game.panel.element_3.element",
    &game.panel.element[2].id
  },
  {
    "game.panel.element_3.draw_masked",
    &game.panel.element[2].draw_masked
  },
  {
    "game.panel.element_3.draw_order",
    &game.panel.element[2].sort_priority
  },
  {
    "game.panel.element_3.class",
    &game.panel.element[2].class
  },
  {
    "game.panel.element_3.style",
    &game.panel.element[2].style
  },
  {
    "game.panel.element_3_count.x",
    &game.panel.element_count[2].x
  },
  {
    "game.panel.element_3_count.y",
    &game.panel.element_count[2].y
  },
  {
    "game.panel.element_3_count.align",
    &game.panel.element_count[2].align
  },
  {
    "game.panel.element_3_count.valign",
    &game.panel.element_count[2].valign
  },
  {
    "game.panel.element_3_count.digits",
    &game.panel.element_count[2].size
  },
  {
    "game.panel.element_3_count.font",
    &game.panel.element_count[2].font
  },
  {
    "game.panel.element_3_count.element",
    &game.panel.element_count[2].id
  },
  {
    "game.panel.element_3_count.draw_masked",
    &game.panel.element_count[2].draw_masked
  },
  {
    "game.panel.element_3_count.draw_order",
    &game.panel.element_count[2].sort_priority
  },
  {
    "game.panel.element_3_count.class",
    &game.panel.element_count[2].class
  },
  {
    "game.panel.element_3_count.style",
    &game.panel.element_count[2].style
  },
  {
    "game.panel.element_4.x",
    &game.panel.element[3].x
  },
  {
    "game.panel.element_4.y",
    &game.panel.element[3].y
  },
  {
    "game.panel.element_4.tile_size",
    &game.panel.element[3].size
  },
  {
    "game.panel.element_4.element",
    &game.panel.element[3].id
  },
  {
    "game.panel.element_4.draw_masked",
    &game.panel.element[3].draw_masked
  },
  {
    "game.panel.element_4.draw_order",
    &game.panel.element[3].sort_priority
  },
  {
    "game.panel.element_4.class",
    &game.panel.element[3].class
  },
  {
    "game.panel.element_4.style",
    &game.panel.element[3].style
  },
  {
    "game.panel.element_4_count.x",
    &game.panel.element_count[3].x
  },
  {
    "game.panel.element_4_count.y",
    &game.panel.element_count[3].y
  },
  {
    "game.panel.element_4_count.align",
    &game.panel.element_count[3].align
  },
  {
    "game.panel.element_4_count.valign",
    &game.panel.element_count[3].valign
  },
  {
    "game.panel.element_4_count.digits",
    &game.panel.element_count[3].size
  },
  {
    "game.panel.element_4_count.font",
    &game.panel.element_count[3].font
  },
  {
    "game.panel.element_4_count.element",
    &game.panel.element_count[3].id
  },
  {
    "game.panel.element_4_count.draw_masked",
    &game.panel.element_count[3].draw_masked
  },
  {
    "game.panel.element_4_count.draw_order",
    &game.panel.element_count[3].sort_priority
  },
  {
    "game.panel.element_4_count.class",
    &game.panel.element_count[3].class
  },
  {
    "game.panel.element_4_count.style",
    &game.panel.element_count[3].style
  },
  {
    "game.panel.element_5.x",
    &game.panel.element[4].x
  },
  {
    "game.panel.element_5.y",
    &game.panel.element[4].y
  },
  {
    "game.panel.element_5.tile_size",
    &game.panel.element[4].size
  },
  {
    "game.panel.element_5.element",
    &game.panel.element[4].id
  },
  {
    "game.panel.element_5.draw_masked",
    &game.panel.element[4].draw_masked
  },
  {
    "game.panel.element_5.draw_order",
    &game.panel.element[4].sort_priority
  },
  {
    "game.panel.element_5.class",
    &game.panel.element[4].class
  },
  {
    "game.panel.element_5.style",
    &game.panel.element[4].style
  },
  {
    "game.panel.element_5_count.x",
    &game.panel.element_count[4].x
  },
  {
    "game.panel.element_5_count.y",
    &game.panel.element_count[4].y
  },
  {
    "game.panel.element_5_count.align",
    &game.panel.element_count[4].align
  },
  {
    "game.panel.element_5_count.valign",
    &game.panel.element_count[4].valign
  },
  {
    "game.panel.element_5_count.digits",
    &game.panel.element_count[4].size
  },
  {
    "game.panel.element_5_count.font",
    &game.panel.element_count[4].font
  },
  {
    "game.panel.element_5_count.element",
    &game.panel.element_count[4].id
  },
  {
    "game.panel.element_5_count.draw_masked",
    &game.panel.element_count[4].draw_masked
  },
  {
    "game.panel.element_5_count.draw_order",
    &game.panel.element_count[4].sort_priority
  },
  {
    "game.panel.element_5_count.class",
    &game.panel.element_count[4].class
  },
  {
    "game.panel.element_5_count.style",
    &game.panel.element_count[4].style
  },
  {
    "game.panel.element_6.x",
    &game.panel.element[5].x
  },
  {
    "game.panel.element_6.y",
    &game.panel.element[5].y
  },
  {
    "game.panel.element_6.tile_size",
    &game.panel.element[5].size
  },
  {
    "game.panel.element_6.element",
    &game.panel.element[5].id
  },
  {
    "game.panel.element_6.draw_masked",
    &game.panel.element[5].draw_masked
  },
  {
    "game.panel.element_6.draw_order",
    &game.panel.element[5].sort_priority
  },
  {
    "game.panel.element_6.class",
    &game.panel.element[5].class
  },
  {
    "game.panel.element_6.style",
    &game.panel.element[5].style
  },
  {
    "game.panel.element_6_count.x",
    &game.panel.element_count[5].x
  },
  {
    "game.panel.element_6_count.y",
    &game.panel.element_count[5].y
  },
  {
    "game.panel.element_6_count.align",
    &game.panel.element_count[5].align
  },
  {
    "game.panel.element_6_count.valign",
    &game.panel.element_count[5].valign
  },
  {
    "game.panel.element_6_count.digits",
    &game.panel.element_count[5].size
  },
  {
    "game.panel.element_6_count.font",
    &game.panel.element_count[5].font
  },
  {
    "game.panel.element_6_count.element",
    &game.panel.element_count[5].id
  },
  {
    "game.panel.element_6_count.draw_masked",
    &game.panel.element_count[5].draw_masked
  },
  {
    "game.panel.element_6_count.draw_order",
    &game.panel.element_count[5].sort_priority
  },
  {
    "game.panel.element_6_count.class",
    &game.panel.element_count[5].class
  },
  {
    "game.panel.element_6_count.style",
    &game.panel.element_count[5].style
  },
  {
    "game.panel.element_7.x",
    &game.panel.element[6].x
  },
  {
    "game.panel.element_7.y",
    &game.panel.element[6].y
  },
  {
    "game.panel.element_7.tile_size",
    &game.panel.element[6].size
  },
  {
    "game.panel.element_7.element",
    &game.panel.element[6].id
  },
  {
    "game.panel.element_7.draw_masked",
    &game.panel.element[6].draw_masked
  },
  {
    "game.panel.element_7.draw_order",
    &game.panel.element[6].sort_priority
  },
  {
    "game.panel.element_7.class",
    &game.panel.element[6].class
  },
  {
    "game.panel.element_7.style",
    &game.panel.element[6].style
  },
  {
    "game.panel.element_7_count.x",
    &game.panel.element_count[6].x
  },
  {
    "game.panel.element_7_count.y",
    &game.panel.element_count[6].y
  },
  {
    "game.panel.element_7_count.align",
    &game.panel.element_count[6].align
  },
  {
    "game.panel.element_7_count.valign",
    &game.panel.element_count[6].valign
  },
  {
    "game.panel.element_7_count.digits",
    &game.panel.element_count[6].size
  },
  {
    "game.panel.element_7_count.font",
    &game.panel.element_count[6].font
  },
  {
    "game.panel.element_7_count.element",
    &game.panel.element_count[6].id
  },
  {
    "game.panel.element_7_count.draw_masked",
    &game.panel.element_count[6].draw_masked
  },
  {
    "game.panel.element_7_count.draw_order",
    &game.panel.element_count[6].sort_priority
  },
  {
    "game.panel.element_7_count.class",
    &game.panel.element_count[6].class
  },
  {
    "game.panel.element_7_count.style",
    &game.panel.element_count[6].style
  },
  {
    "game.panel.element_8.x",
    &game.panel.element[7].x
  },
  {
    "game.panel.element_8.y",
    &game.panel.element[7].y
  },
  {
    "game.panel.element_8.tile_size",
    &game.panel.element[7].size
  },
  {
    "game.panel.element_8.element",
    &game.panel.element[7].id
  },
  {
    "game.panel.element_8.draw_masked",
    &game.panel.element[7].draw_masked
  },
  {
    "game.panel.element_8.draw_order",
    &game.panel.element[7].sort_priority
  },
  {
    "game.panel.element_8.class",
    &game.panel.element[7].class
  },
  {
    "game.panel.element_8.style",
    &game.panel.element[7].style
  },
  {
    "game.panel.element_8_count.x",
    &game.panel.element_count[7].x
  },
  {
    "game.panel.element_8_count.y",
    &game.panel.element_count[7].y
  },
  {
    "game.panel.element_8_count.align",
    &game.panel.element_count[7].align
  },
  {
    "game.panel.element_8_count.valign",
    &game.panel.element_count[7].valign
  },
  {
    "game.panel.element_8_count.digits",
    &game.panel.element_count[7].size
  },
  {
    "game.panel.element_8_count.font",
    &game.panel.element_count[7].font
  },
  {
    "game.panel.element_8_count.element",
    &game.panel.element_count[7].id
  },
  {
    "game.panel.element_8_count.draw_masked",
    &game.panel.element_count[7].draw_masked
  },
  {
    "game.panel.element_8_count.draw_order",
    &game.panel.element_count[7].sort_priority
  },
  {
    "game.panel.element_8_count.class",
    &game.panel.element_count[7].class
  },
  {
    "game.panel.element_8_count.style",
    &game.panel.element_count[7].style
  },
  {
    "game.panel.ce_score_1.x",
    &game.panel.ce_score[0].x
  },
  {
    "game.panel.ce_score_1.y",
    &game.panel.ce_score[0].y
  },
  {
    "game.panel.ce_score_1.align",
    &game.panel.ce_score[0].align
  },
  {
    "game.panel.ce_score_1.valign",
    &game.panel.ce_score[0].valign
  },
  {
    "game.panel.ce_score_1.digits",
    &game.panel.ce_score[0].size
  },
  {
    "game.panel.ce_score_1.font",
    &game.panel.ce_score[0].font
  },
  {
    "game.panel.ce_score_1.element",
    &game.panel.ce_score[0].id
  },
  {
    "game.panel.ce_score_1.draw_masked",
    &game.panel.ce_score[0].draw_masked
  },
  {
    "game.panel.ce_score_1.draw_order",
    &game.panel.ce_score[0].sort_priority
  },
  {
    "game.panel.ce_score_1.class",
    &game.panel.ce_score[0].class
  },
  {
    "game.panel.ce_score_1.style",
    &game.panel.ce_score[0].style
  },
  {
    "game.panel.ce_score_1_element.x",
    &game.panel.ce_score_element[0].x
  },
  {
    "game.panel.ce_score_1_element.y",
    &game.panel.ce_score_element[0].y
  },
  {
    "game.panel.ce_score_1_element.tile_size",
    &game.panel.ce_score_element[0].size
  },
  {
    "game.panel.ce_score_1_element.element",
    &game.panel.ce_score_element[0].id
  },
  {
    "game.panel.ce_score_1_element.draw_masked",
    &game.panel.ce_score_element[0].draw_masked
  },
  {
    "game.panel.ce_score_1_element.draw_order",
    &game.panel.ce_score_element[0].sort_priority
  },
  {
    "game.panel.ce_score_1_element.class",
    &game.panel.ce_score_element[0].class
  },
  {
    "game.panel.ce_score_1_element.style",
    &game.panel.ce_score_element[0].style
  },
  {
    "game.panel.ce_score_2.x",
    &game.panel.ce_score[1].x
  },
  {
    "game.panel.ce_score_2.y",
    &game.panel.ce_score[1].y
  },
  {
    "game.panel.ce_score_2.align",
    &game.panel.ce_score[1].align
  },
  {
    "game.panel.ce_score_2.valign",
    &game.panel.ce_score[1].valign
  },
  {
    "game.panel.ce_score_2.digits",
    &game.panel.ce_score[1].size
  },
  {
    "game.panel.ce_score_2.font",
    &game.panel.ce_score[1].font
  },
  {
    "game.panel.ce_score_2.element",
    &game.panel.ce_score[1].id
  },
  {
    "game.panel.ce_score_2.draw_masked",
    &game.panel.ce_score[1].draw_masked
  },
  {
    "game.panel.ce_score_2.draw_order",
    &game.panel.ce_score[1].sort_priority
  },
  {
    "game.panel.ce_score_2.class",
    &game.panel.ce_score[1].class
  },
  {
    "game.panel.ce_score_2.style",
    &game.panel.ce_score[1].style
  },
  {
    "game.panel.ce_score_2_element.x",
    &game.panel.ce_score_element[1].x
  },
  {
    "game.panel.ce_score_2_element.y",
    &game.panel.ce_score_element[1].y
  },
  {
    "game.panel.ce_score_2_element.tile_size",
    &game.panel.ce_score_element[1].size
  },
  {
    "game.panel.ce_score_2_element.element",
    &game.panel.ce_score_element[1].id
  },
  {
    "game.panel.ce_score_2_element.draw_masked",
    &game.panel.ce_score_element[1].draw_masked
  },
  {
    "game.panel.ce_score_2_element.draw_order",
    &game.panel.ce_score_element[1].sort_priority
  },
  {
    "game.panel.ce_score_2_element.class",
    &game.panel.ce_score_element[1].class
  },
  {
    "game.panel.ce_score_2_element.style",
    &game.panel.ce_score_element[1].style
  },
  {
    "game.panel.ce_score_3.x",
    &game.panel.ce_score[2].x
  },
  {
    "game.panel.ce_score_3.y",
    &game.panel.ce_score[2].y
  },
  {
    "game.panel.ce_score_3.align",
    &game.panel.ce_score[2].align
  },
  {
    "game.panel.ce_score_3.valign",
    &game.panel.ce_score[2].valign
  },
  {
    "game.panel.ce_score_3.digits",
    &game.panel.ce_score[2].size
  },
  {
    "game.panel.ce_score_3.font",
    &game.panel.ce_score[2].font
  },
  {
    "game.panel.ce_score_3.element",
    &game.panel.ce_score[2].id
  },
  {
    "game.panel.ce_score_3.draw_masked",
    &game.panel.ce_score[2].draw_masked
  },
  {
    "game.panel.ce_score_3.draw_order",
    &game.panel.ce_score[2].sort_priority
  },
  {
    "game.panel.ce_score_3.class",
    &game.panel.ce_score[2].class
  },
  {
    "game.panel.ce_score_3.style",
    &game.panel.ce_score[2].style
  },
  {
    "game.panel.ce_score_3_element.x",
    &game.panel.ce_score_element[2].x
  },
  {
    "game.panel.ce_score_3_element.y",
    &game.panel.ce_score_element[2].y
  },
  {
    "game.panel.ce_score_3_element.tile_size",
    &game.panel.ce_score_element[2].size
  },
  {
    "game.panel.ce_score_3_element.element",
    &game.panel.ce_score_element[2].id
  },
  {
    "game.panel.ce_score_3_element.draw_masked",
    &game.panel.ce_score_element[2].draw_masked
  },
  {
    "game.panel.ce_score_3_element.draw_order",
    &game.panel.ce_score_element[2].sort_priority
  },
  {
    "game.panel.ce_score_3_element.class",
    &game.panel.ce_score_element[2].class
  },
  {
    "game.panel.ce_score_3_element.style",
    &game.panel.ce_score_element[2].style
  },
  {
    "game.panel.ce_score_4.x",
    &game.panel.ce_score[3].x
  },
  {
    "game.panel.ce_score_4.y",
    &game.panel.ce_score[3].y
  },
  {
    "game.panel.ce_score_4.align",
    &game.panel.ce_score[3].align
  },
  {
    "game.panel.ce_score_4.valign",
    &game.panel.ce_score[3].valign
  },
  {
    "game.panel.ce_score_4.digits",
    &game.panel.ce_score[3].size
  },
  {
    "game.panel.ce_score_4.font",
    &game.panel.ce_score[3].font
  },
  {
    "game.panel.ce_score_4.element",
    &game.panel.ce_score[3].id
  },
  {
    "game.panel.ce_score_4.draw_masked",
    &game.panel.ce_score[3].draw_masked
  },
  {
    "game.panel.ce_score_4.draw_order",
    &game.panel.ce_score[3].sort_priority
  },
  {
    "game.panel.ce_score_4.class",
    &game.panel.ce_score[3].class
  },
  {
    "game.panel.ce_score_4.style",
    &game.panel.ce_score[3].style
  },
  {
    "game.panel.ce_score_4_element.x",
    &game.panel.ce_score_element[3].x
  },
  {
    "game.panel.ce_score_4_element.y",
    &game.panel.ce_score_element[3].y
  },
  {
    "game.panel.ce_score_4_element.tile_size",
    &game.panel.ce_score_element[3].size
  },
  {
    "game.panel.ce_score_4_element.element",
    &game.panel.ce_score_element[3].id
  },
  {
    "game.panel.ce_score_4_element.draw_masked",
    &game.panel.ce_score_element[3].draw_masked
  },
  {
    "game.panel.ce_score_4_element.draw_order",
    &game.panel.ce_score_element[3].sort_priority
  },
  {
    "game.panel.ce_score_4_element.class",
    &game.panel.ce_score_element[3].class
  },
  {
    "game.panel.ce_score_4_element.style",
    &game.panel.ce_score_element[3].style
  },
  {
    "game.panel.ce_score_5.x",
    &game.panel.ce_score[4].x
  },
  {
    "game.panel.ce_score_5.y",
    &game.panel.ce_score[4].y
  },
  {
    "game.panel.ce_score_5.align",
    &game.panel.ce_score[4].align
  },
  {
    "game.panel.ce_score_5.valign",
    &game.panel.ce_score[4].valign
  },
  {
    "game.panel.ce_score_5.digits",
    &game.panel.ce_score[4].size
  },
  {
    "game.panel.ce_score_5.font",
    &game.panel.ce_score[4].font
  },
  {
    "game.panel.ce_score_5.element",
    &game.panel.ce_score[4].id
  },
  {
    "game.panel.ce_score_5.draw_masked",
    &game.panel.ce_score[4].draw_masked
  },
  {
    "game.panel.ce_score_5.draw_order",
    &game.panel.ce_score[4].sort_priority
  },
  {
    "game.panel.ce_score_5.class",
    &game.panel.ce_score[4].class
  },
  {
    "game.panel.ce_score_5.style",
    &game.panel.ce_score[4].style
  },
  {
    "game.panel.ce_score_5_element.x",
    &game.panel.ce_score_element[4].x
  },
  {
    "game.panel.ce_score_5_element.y",
    &game.panel.ce_score_element[4].y
  },
  {
    "game.panel.ce_score_5_element.tile_size",
    &game.panel.ce_score_element[4].size
  },
  {
    "game.panel.ce_score_5_element.element",
    &game.panel.ce_score_element[4].id
  },
  {
    "game.panel.ce_score_5_element.draw_masked",
    &game.panel.ce_score_element[4].draw_masked
  },
  {
    "game.panel.ce_score_5_element.draw_order",
    &game.panel.ce_score_element[4].sort_priority
  },
  {
    "game.panel.ce_score_5_element.class",
    &game.panel.ce_score_element[4].class
  },
  {
    "game.panel.ce_score_5_element.style",
    &game.panel.ce_score_element[4].style
  },
  {
    "game.panel.ce_score_6.x",
    &game.panel.ce_score[5].x
  },
  {
    "game.panel.ce_score_6.y",
    &game.panel.ce_score[5].y
  },
  {
    "game.panel.ce_score_6.align",
    &game.panel.ce_score[5].align
  },
  {
    "game.panel.ce_score_6.valign",
    &game.panel.ce_score[5].valign
  },
  {
    "game.panel.ce_score_6.digits",
    &game.panel.ce_score[5].size
  },
  {
    "game.panel.ce_score_6.font",
    &game.panel.ce_score[5].font
  },
  {
    "game.panel.ce_score_6.element",
    &game.panel.ce_score[5].id
  },
  {
    "game.panel.ce_score_6.draw_masked",
    &game.panel.ce_score[5].draw_masked
  },
  {
    "game.panel.ce_score_6.draw_order",
    &game.panel.ce_score[5].sort_priority
  },
  {
    "game.panel.ce_score_6.class",
    &game.panel.ce_score[5].class
  },
  {
    "game.panel.ce_score_6.style",
    &game.panel.ce_score[5].style
  },
  {
    "game.panel.ce_score_6_element.x",
    &game.panel.ce_score_element[5].x
  },
  {
    "game.panel.ce_score_6_element.y",
    &game.panel.ce_score_element[5].y
  },
  {
    "game.panel.ce_score_6_element.tile_size",
    &game.panel.ce_score_element[5].size
  },
  {
    "game.panel.ce_score_6_element.element",
    &game.panel.ce_score_element[5].id
  },
  {
    "game.panel.ce_score_6_element.draw_masked",
    &game.panel.ce_score_element[5].draw_masked
  },
  {
    "game.panel.ce_score_6_element.draw_order",
    &game.panel.ce_score_element[5].sort_priority
  },
  {
    "game.panel.ce_score_6_element.class",
    &game.panel.ce_score_element[5].class
  },
  {
    "game.panel.ce_score_6_element.style",
    &game.panel.ce_score_element[5].style
  },
  {
    "game.panel.ce_score_7.x",
    &game.panel.ce_score[6].x
  },
  {
    "game.panel.ce_score_7.y",
    &game.panel.ce_score[6].y
  },
  {
    "game.panel.ce_score_7.align",
    &game.panel.ce_score[6].align
  },
  {
    "game.panel.ce_score_7.valign",
    &game.panel.ce_score[6].valign
  },
  {
    "game.panel.ce_score_7.digits",
    &game.panel.ce_score[6].size
  },
  {
    "game.panel.ce_score_7.font",
    &game.panel.ce_score[6].font
  },
  {
    "game.panel.ce_score_7.element",
    &game.panel.ce_score[6].id
  },
  {
    "game.panel.ce_score_7.draw_masked",
    &game.panel.ce_score[6].draw_masked
  },
  {
    "game.panel.ce_score_7.draw_order",
    &game.panel.ce_score[6].sort_priority
  },
  {
    "game.panel.ce_score_7.class",
    &game.panel.ce_score[6].class
  },
  {
    "game.panel.ce_score_7.style",
    &game.panel.ce_score[6].style
  },
  {
    "game.panel.ce_score_7_element.x",
    &game.panel.ce_score_element[6].x
  },
  {
    "game.panel.ce_score_7_element.y",
    &game.panel.ce_score_element[6].y
  },
  {
    "game.panel.ce_score_7_element.tile_size",
    &game.panel.ce_score_element[6].size
  },
  {
    "game.panel.ce_score_7_element.element",
    &game.panel.ce_score_element[6].id
  },
  {
    "game.panel.ce_score_7_element.draw_masked",
    &game.panel.ce_score_element[6].draw_masked
  },
  {
    "game.panel.ce_score_7_element.draw_order",
    &game.panel.ce_score_element[6].sort_priority
  },
  {
    "game.panel.ce_score_7_element.class",
    &game.panel.ce_score_element[6].class
  },
  {
    "game.panel.ce_score_7_element.style",
    &game.panel.ce_score_element[6].style
  },
  {
    "game.panel.ce_score_8.x",
    &game.panel.ce_score[7].x
  },
  {
    "game.panel.ce_score_8.y",
    &game.panel.ce_score[7].y
  },
  {
    "game.panel.ce_score_8.align",
    &game.panel.ce_score[7].align
  },
  {
    "game.panel.ce_score_8.valign",
    &game.panel.ce_score[7].valign
  },
  {
    "game.panel.ce_score_8.digits",
    &game.panel.ce_score[7].size
  },
  {
    "game.panel.ce_score_8.font",
    &game.panel.ce_score[7].font
  },
  {
    "game.panel.ce_score_8.element",
    &game.panel.ce_score[7].id
  },
  {
    "game.panel.ce_score_8.draw_masked",
    &game.panel.ce_score[7].draw_masked
  },
  {
    "game.panel.ce_score_8.draw_order",
    &game.panel.ce_score[7].sort_priority
  },
  {
    "game.panel.ce_score_8.class",
    &game.panel.ce_score[7].class
  },
  {
    "game.panel.ce_score_8.style",
    &game.panel.ce_score[7].style
  },
  {
    "game.panel.ce_score_8_element.x",
    &game.panel.ce_score_element[7].x
  },
  {
    "game.panel.ce_score_8_element.y",
    &game.panel.ce_score_element[7].y
  },
  {
    "game.panel.ce_score_8_element.tile_size",
    &game.panel.ce_score_element[7].size
  },
  {
    "game.panel.ce_score_8_element.element",
    &game.panel.ce_score_element[7].id
  },
  {
    "game.panel.ce_score_8_element.draw_masked",
    &game.panel.ce_score_element[7].draw_masked
  },
  {
    "game.panel.ce_score_8_element.draw_order",
    &game.panel.ce_score_element[7].sort_priority
  },
  {
    "game.panel.ce_score_8_element.class",
    &game.panel.ce_score_element[7].class
  },
  {
    "game.panel.ce_score_8_element.style",
    &game.panel.ce_score_element[7].style
  },
  {
    "game.panel.player_name.x",
    &game.panel.player_name.x
  },
  {
    "game.panel.player_name.y",
    &game.panel.player_name.y
  },
  {
    "game.panel.player_name.align",
    &game.panel.player_name.align
  },
  {
    "game.panel.player_name.valign",
    &game.panel.player_name.valign
  },
  {
    "game.panel.player_name.chars",
    &game.panel.player_name.size
  },
  {
    "game.panel.player_name.font",
    &game.panel.player_name.font
  },
  {
    "game.panel.player_name.draw_masked",
    &game.panel.player_name.draw_masked
  },
  {
    "game.panel.player_name.draw_order",
    &game.panel.player_name.sort_priority
  },
  {
    "game.panel.player_name.class",
    &game.panel.player_name.class
  },
  {
    "game.panel.player_name.style",
    &game.panel.player_name.style
  },
  {
    "game.panel.level_name.x",
    &game.panel.level_name.x
  },
  {
    "game.panel.level_name.y",
    &game.panel.level_name.y
  },
  {
    "game.panel.level_name.align",
    &game.panel.level_name.align
  },
  {
    "game.panel.level_name.valign",
    &game.panel.level_name.valign
  },
  {
    "game.panel.level_name.chars",
    &game.panel.level_name.size
  },
  {
    "game.panel.level_name.font",
    &game.panel.level_name.font
  },
  {
    "game.panel.level_name.draw_masked",
    &game.panel.level_name.draw_masked
  },
  {
    "game.panel.level_name.draw_order",
    &game.panel.level_name.sort_priority
  },
  {
    "game.panel.level_name.class",
    &game.panel.level_name.class
  },
  {
    "game.panel.level_name.style",
    &game.panel.level_name.style
  },
  {
    "game.panel.level_author.x",
    &game.panel.level_author.x
  },
  {
    "game.panel.level_author.y",
    &game.panel.level_author.y
  },
  {
    "game.panel.level_author.align",
    &game.panel.level_author.align
  },
  {
    "game.panel.level_author.valign",
    &game.panel.level_author.valign
  },
  {
    "game.panel.level_author.chars",
    &game.panel.level_author.size
  },
  {
    "game.panel.level_author.font",
    &game.panel.level_author.font
  },
  {
    "game.panel.level_author.draw_masked",
    &game.panel.level_author.draw_masked
  },
  {
    "game.panel.level_author.draw_order",
    &game.panel.level_author.sort_priority
  },
  {
    "game.panel.level_author.class",
    &game.panel.level_author.class
  },
  {
    "game.panel.level_author.style",
    &game.panel.level_author.style
  },
  {
    "game.button.stop.x",
    &game.button.stop.x
  },
  {
    "game.button.stop.y",
    &game.button.stop.y
  },
  {
    "game.button.pause.x",
    &game.button.pause.x
  },
  {
    "game.button.pause.y",
    &game.button.pause.y
  },
  {
    "game.button.play.x",
    &game.button.play.x
  },
  {
    "game.button.play.y",
    &game.button.play.y
  },
  {
    "game.button.undo.x",
    &game.button.undo.x
  },
  {
    "game.button.undo.y",
    &game.button.undo.y
  },
  {
    "game.button.redo.x",
    &game.button.redo.x
  },
  {
    "game.button.redo.y",
    &game.button.redo.y
  },
  {
    "game.button.save.x",
    &game.button.save.x
  },
  {
    "game.button.save.y",
    &game.button.save.y
  },
  {
    "game.button.pause2.x",
    &game.button.pause2.x
  },
  {
    "game.button.pause2.y",
    &game.button.pause2.y
  },
  {
    "game.button.load.x",
    &game.button.load.x
  },
  {
    "game.button.load.y",
    &game.button.load.y
  },
  {
    "game.button.sound_music.x",
    &game.button.sound_music.x
  },
  {
    "game.button.sound_music.y",
    &game.button.sound_music.y
  },
  {
    "game.button.sound_loops.x",
    &game.button.sound_loops.x
  },
  {
    "game.button.sound_loops.y",
    &game.button.sound_loops.y
  },
  {
    "game.button.sound_simple.x",
    &game.button.sound_simple.x
  },
  {
    "game.button.sound_simple.y",
    &game.button.sound_simple.y
  },
  {
    "game.button.panel_stop.x",
    &game.button.panel_stop.x
  },
  {
    "game.button.panel_stop.y",
    &game.button.panel_stop.y
  },
  {
    "game.button.panel_pause.x",
    &game.button.panel_pause.x
  },
  {
    "game.button.panel_pause.y",
    &game.button.panel_pause.y
  },
  {
    "game.button.panel_play.x",
    &game.button.panel_play.x
  },
  {
    "game.button.panel_play.y",
    &game.button.panel_play.y
  },
  {
    "game.button.panel_sound_music.x",
    &game.button.panel_sound_music.x
  },
  {
    "game.button.panel_sound_music.y",
    &game.button.panel_sound_music.y
  },
  {
    "game.button.panel_sound_loops.x",
    &game.button.panel_sound_loops.x
  },
  {
    "game.button.panel_sound_loops.y",
    &game.button.panel_sound_loops.y
  },
  {
    "game.button.panel_sound_simple.x",
    &game.button.panel_sound_simple.x
  },
  {
    "game.button.panel_sound_simple.y",
    &game.button.panel_sound_simple.y
  },
  {
    "game.button.touch_stop.x",
    &game.button.touch_stop.x
  },
  {
    "game.button.touch_stop.y",
    &game.button.touch_stop.y
  },
  {
    "game.button.touch_pause.x",
    &game.button.touch_pause.x
  },
  {
    "game.button.touch_pause.y",
    &game.button.touch_pause.y
  },
  {
    "tape.button.eject.x",
    &tape.button.eject.x
  },
  {
    "tape.button.eject.y",
    &tape.button.eject.y
  },
  {
    "tape.button.stop.x",
    &tape.button.stop.x
  },
  {
    "tape.button.stop.y",
    &tape.button.stop.y
  },
  {
    "tape.button.pause.x",
    &tape.button.pause.x
  },
  {
    "tape.button.pause.y",
    &tape.button.pause.y
  },
  {
    "tape.button.record.x",
    &tape.button.record.x
  },
  {
    "tape.button.record.y",
    &tape.button.record.y
  },
  {
    "tape.button.play.x",
    &tape.button.play.x
  },
  {
    "tape.button.play.y",
    &tape.button.play.y
  },
  {
    "tape.button.insert_solution.x",
    &tape.button.insert_solution.x
  },
  {
    "tape.button.insert_solution.y",
    &tape.button.insert_solution.y
  },
  {
    "tape.button.play_solution.x",
    &tape.button.play_solution.x
  },
  {
    "tape.button.play_solution.y",
    &tape.button.play_solution.y
  },
  {
    "tape.symbol.eject.x",
    &tape.symbol.eject.x
  },
  {
    "tape.symbol.eject.y",
    &tape.symbol.eject.y
  },
  {
    "tape.symbol.stop.x",
    &tape.symbol.stop.x
  },
  {
    "tape.symbol.stop.y",
    &tape.symbol.stop.y
  },
  {
    "tape.symbol.pause.x",
    &tape.symbol.pause.x
  },
  {
    "tape.symbol.pause.y",
    &tape.symbol.pause.y
  },
  {
    "tape.symbol.record.x",
    &tape.symbol.record.x
  },
  {
    "tape.symbol.record.y",
    &tape.symbol.record.y
  },
  {
    "tape.symbol.play.x",
    &tape.symbol.play.x
  },
  {
    "tape.symbol.play.y",
    &tape.symbol.play.y
  },
  {
    "tape.symbol.fast_forward.x",
    &tape.symbol.fast_forward.x
  },
  {
    "tape.symbol.fast_forward.y",
    &tape.symbol.fast_forward.y
  },
  {
    "tape.symbol.warp_forward.x",
    &tape.symbol.warp_forward.x
  },
  {
    "tape.symbol.warp_forward.y",
    &tape.symbol.warp_forward.y
  },
  {
    "tape.symbol.warp_forward_blind.x",
    &tape.symbol.warp_forward_blind.x
  },
  {
    "tape.symbol.warp_forward_blind.y",
    &tape.symbol.warp_forward_blind.y
  },
  {
    "tape.symbol.pause_before_end.x",
    &tape.symbol.pause_before_end.x
  },
  {
    "tape.symbol.pause_before_end.y",
    &tape.symbol.pause_before_end.y
  },
  {
    "tape.symbol.single_step.x",
    &tape.symbol.single_step.x
  },
  {
    "tape.symbol.single_step.y",
    &tape.symbol.single_step.y
  },
  {
    "tape.label.eject.x",
    &tape.label.eject.x
  },
  {
    "tape.label.eject.y",
    &tape.label.eject.y
  },
  {
    "tape.label.stop.x",
    &tape.label.stop.x
  },
  {
    "tape.label.stop.y",
    &tape.label.stop.y
  },
  {
    "tape.label.pause.x",
    &tape.label.pause.x
  },
  {
    "tape.label.pause.y",
    &tape.label.pause.y
  },
  {
    "tape.label.record.x",
    &tape.label.record.x
  },
  {
    "tape.label.record.y",
    &tape.label.record.y
  },
  {
    "tape.label.play.x",
    &tape.label.play.x
  },
  {
    "tape.label.play.y",
    &tape.label.play.y
  },
  {
    "tape.label.fast_forward.x",
    &tape.label.fast_forward.x
  },
  {
    "tape.label.fast_forward.y",
    &tape.label.fast_forward.y
  },
  {
    "tape.label.warp_forward.x",
    &tape.label.warp_forward.x
  },
  {
    "tape.label.warp_forward.y",
    &tape.label.warp_forward.y
  },
  {
    "tape.label.warp_forward_blind.x",
    &tape.label.warp_forward_blind.x
  },
  {
    "tape.label.warp_forward_blind.y",
    &tape.label.warp_forward_blind.y
  },
  {
    "tape.label.pause_before_end.x",
    &tape.label.pause_before_end.x
  },
  {
    "tape.label.pause_before_end.y",
    &tape.label.pause_before_end.y
  },
  {
    "tape.label.single_step.x",
    &tape.label.single_step.x
  },
  {
    "tape.label.single_step.y",
    &tape.label.single_step.y
  },
  {
    "tape.label.date.x",
    &tape.label.date.x
  },
  {
    "tape.label.date.y",
    &tape.label.date.y
  },
  {
    "tape.label.time.x",
    &tape.label.time.x
  },
  {
    "tape.label.time.y",
    &tape.label.time.y
  },
  {
    "tape.text.date.x",
    &tape.text.date.x
  },
  {
    "tape.text.date.y",
    &tape.text.date.y
  },
  {
    "tape.text.date.align",
    &tape.text.date.align
  },
  {
    "tape.text.date.valign",
    &tape.text.date.valign
  },
  {
    "tape.text.date.digits",
    &tape.text.date.size
  },
  {
    "tape.text.date.xoffset",
    &tape.text.date.xoffset
  },
  {
    "tape.text.date.2nd_xoffset",
    &tape.text.date.xoffset2
  },
  {
    "tape.text.date.font",
    &tape.text.date.font
  },
  {
    "tape.text.date.draw_masked",
    &tape.text.date.draw_masked
  },
  {
    "tape.text.date_yyyy.x",
    &tape.text.date_yyyy.x
  },
  {
    "tape.text.date_yyyy.y",
    &tape.text.date_yyyy.y
  },
  {
    "tape.text.date_yyyy.align",
    &tape.text.date_yyyy.align
  },
  {
    "tape.text.date_yyyy.valign",
    &tape.text.date_yyyy.valign
  },
  {
    "tape.text.date_yyyy.digits",
    &tape.text.date_yyyy.size
  },
  {
    "tape.text.date_yyyy.font",
    &tape.text.date_yyyy.font
  },
  {
    "tape.text.date_yyyy.draw_masked",
    &tape.text.date_yyyy.draw_masked
  },
  {
    "tape.text.date_yy.x",
    &tape.text.date_yy.x
  },
  {
    "tape.text.date_yy.y",
    &tape.text.date_yy.y
  },
  {
    "tape.text.date_yy.align",
    &tape.text.date_yy.align
  },
  {
    "tape.text.date_yy.valign",
    &tape.text.date_yy.valign
  },
  {
    "tape.text.date_yy.digits",
    &tape.text.date_yy.size
  },
  {
    "tape.text.date_yy.font",
    &tape.text.date_yy.font
  },
  {
    "tape.text.date_yy.draw_masked",
    &tape.text.date_yy.draw_masked
  },
  {
    "tape.text.date_mon.x",
    &tape.text.date_mon.x
  },
  {
    "tape.text.date_mon.y",
    &tape.text.date_mon.y
  },
  {
    "tape.text.date_mon.align",
    &tape.text.date_mon.align
  },
  {
    "tape.text.date_mon.valign",
    &tape.text.date_mon.valign
  },
  {
    "tape.text.date_mon.chars",
    &tape.text.date_mon.size
  },
  {
    "tape.text.date_mon.font",
    &tape.text.date_mon.font
  },
  {
    "tape.text.date_mon.draw_masked",
    &tape.text.date_mon.draw_masked
  },
  {
    "tape.text.date_mm.x",
    &tape.text.date_mm.x
  },
  {
    "tape.text.date_mm.y",
    &tape.text.date_mm.y
  },
  {
    "tape.text.date_mm.align",
    &tape.text.date_mm.align
  },
  {
    "tape.text.date_mm.valign",
    &tape.text.date_mm.valign
  },
  {
    "tape.text.date_mm.digits",
    &tape.text.date_mm.size
  },
  {
    "tape.text.date_mm.font",
    &tape.text.date_mm.font
  },
  {
    "tape.text.date_mm.draw_masked",
    &tape.text.date_mm.draw_masked
  },
  {
    "tape.text.date_dd.x",
    &tape.text.date_dd.x
  },
  {
    "tape.text.date_dd.y",
    &tape.text.date_dd.y
  },
  {
    "tape.text.date_dd.align",
    &tape.text.date_dd.align
  },
  {
    "tape.text.date_dd.valign",
    &tape.text.date_dd.valign
  },
  {
    "tape.text.date_dd.digits",
    &tape.text.date_dd.size
  },
  {
    "tape.text.date_dd.font",
    &tape.text.date_dd.font
  },
  {
    "tape.text.date_dd.draw_masked",
    &tape.text.date_dd.draw_masked
  },
  {
    "tape.text.time.x",
    &tape.text.time.x
  },
  {
    "tape.text.time.y",
    &tape.text.time.y
  },
  {
    "tape.text.time.align",
    &tape.text.time.align
  },
  {
    "tape.text.time.valign",
    &tape.text.time.valign
  },
  {
    "tape.text.time.digits",
    &tape.text.time.size
  },
  {
    "tape.text.time.xoffset",
    &tape.text.time.xoffset
  },
  {
    "tape.text.time.font",
    &tape.text.time.font
  },
  {
    "tape.text.time.draw_masked",
    &tape.text.time.draw_masked
  },
  {
    "tape.text.time_hh.x",
    &tape.text.time_hh.x
  },
  {
    "tape.text.time_hh.y",
    &tape.text.time_hh.y
  },
  {
    "tape.text.time_hh.align",
    &tape.text.time_hh.align
  },
  {
    "tape.text.time_hh.valign",
    &tape.text.time_hh.valign
  },
  {
    "tape.text.time_hh.digits",
    &tape.text.time_hh.size
  },
  {
    "tape.text.time_hh.font",
    &tape.text.time_hh.font
  },
  {
    "tape.text.time_hh.draw_masked",
    &tape.text.time_hh.draw_masked
  },
  {
    "tape.text.time_mm.x",
    &tape.text.time_mm.x
  },
  {
    "tape.text.time_mm.y",
    &tape.text.time_mm.y
  },
  {
    "tape.text.time_mm.align",
    &tape.text.time_mm.align
  },
  {
    "tape.text.time_mm.valign",
    &tape.text.time_mm.valign
  },
  {
    "tape.text.time_mm.digits",
    &tape.text.time_mm.size
  },
  {
    "tape.text.time_mm.font",
    &tape.text.time_mm.font
  },
  {
    "tape.text.time_mm.draw_masked",
    &tape.text.time_mm.draw_masked
  },
  {
    "tape.text.time_ss.x",
    &tape.text.time_ss.x
  },
  {
    "tape.text.time_ss.y",
    &tape.text.time_ss.y
  },
  {
    "tape.text.time_ss.align",
    &tape.text.time_ss.align
  },
  {
    "tape.text.time_ss.valign",
    &tape.text.time_ss.valign
  },
  {
    "tape.text.time_ss.digits",
    &tape.text.time_ss.size
  },
  {
    "tape.text.time_ss.font",
    &tape.text.time_ss.font
  },
  {
    "tape.text.time_ss.draw_masked",
    &tape.text.time_ss.draw_masked
  },
  {
    "tape.text.frame.x",
    &tape.text.frame.x
  },
  {
    "tape.text.frame.y",
    &tape.text.frame.y
  },
  {
    "tape.text.frame.align",
    &tape.text.frame.align
  },
  {
    "tape.text.frame.valign",
    &tape.text.frame.valign
  },
  {
    "tape.text.frame.digits",
    &tape.text.frame.size
  },
  {
    "tape.text.frame.font",
    &tape.text.frame.font
  },
  {
    "tape.text.frame.draw_masked",
    &tape.text.frame.draw_masked
  },
  {
    "tape.show_game_buttons",
    &tape.show_game_buttons
  },
  {
    "editor.button.prev_level.x",
    &editor.button.prev_level.x
  },
  {
    "editor.button.prev_level.y",
    &editor.button.prev_level.y
  },
  {
    "editor.button.next_level.x",
    &editor.button.next_level.x
  },
  {
    "editor.button.next_level.y",
    &editor.button.next_level.y
  },
  {
    "editor.button.properties.x",
    &editor.button.properties.x
  },
  {
    "editor.button.properties.y",
    &editor.button.properties.y
  },
  {
    "editor.button.element_left.x",
    &editor.button.element_left.x
  },
  {
    "editor.button.element_left.y",
    &editor.button.element_left.y
  },
  {
    "editor.button.element_left.tile_size",
    &editor.button.element_left.tile_size
  },
  {
    "editor.button.element_middle.x",
    &editor.button.element_middle.x
  },
  {
    "editor.button.element_middle.y",
    &editor.button.element_middle.y
  },
  {
    "editor.button.element_middle.tile_size",
    &editor.button.element_middle.tile_size
  },
  {
    "editor.button.element_right.x",
    &editor.button.element_right.x
  },
  {
    "editor.button.element_right.y",
    &editor.button.element_right.y
  },
  {
    "editor.button.element_right.tile_size",
    &editor.button.element_right.tile_size
  },
  {
    "editor.button.palette.x",
    &editor.button.palette.x
  },
  {
    "editor.button.palette.y",
    &editor.button.palette.y
  },
  {
    "editor.button.draw_single.x",
    &editor.button.draw_single.x
  },
  {
    "editor.button.draw_single.y",
    &editor.button.draw_single.y
  },
  {
    "editor.button.draw_connected.x",
    &editor.button.draw_connected.x
  },
  {
    "editor.button.draw_connected.y",
    &editor.button.draw_connected.y
  },
  {
    "editor.button.draw_line.x",
    &editor.button.draw_line.x
  },
  {
    "editor.button.draw_line.y",
    &editor.button.draw_line.y
  },
  {
    "editor.button.draw_arc.x",
    &editor.button.draw_arc.x
  },
  {
    "editor.button.draw_arc.y",
    &editor.button.draw_arc.y
  },
  {
    "editor.button.draw_rectangle.x",
    &editor.button.draw_rectangle.x
  },
  {
    "editor.button.draw_rectangle.y",
    &editor.button.draw_rectangle.y
  },
  {
    "editor.button.draw_filled_box.x",
    &editor.button.draw_filled_box.x
  },
  {
    "editor.button.draw_filled_box.y",
    &editor.button.draw_filled_box.y
  },
  {
    "editor.button.rotate_up.x",
    &editor.button.rotate_up.x
  },
  {
    "editor.button.rotate_up.y",
    &editor.button.rotate_up.y
  },
  {
    "editor.button.draw_text.x",
    &editor.button.draw_text.x
  },
  {
    "editor.button.draw_text.y",
    &editor.button.draw_text.y
  },
  {
    "editor.button.flood_fill.x",
    &editor.button.flood_fill.x
  },
  {
    "editor.button.flood_fill.y",
    &editor.button.flood_fill.y
  },
  {
    "editor.button.rotate_left.x",
    &editor.button.rotate_left.x
  },
  {
    "editor.button.rotate_left.y",
    &editor.button.rotate_left.y
  },
  {
    "editor.button.zoom_level.x",
    &editor.button.zoom_level.x
  },
  {
    "editor.button.zoom_level.y",
    &editor.button.zoom_level.y
  },
  {
    "editor.button.rotate_right.x",
    &editor.button.rotate_right.x
  },
  {
    "editor.button.rotate_right.y",
    &editor.button.rotate_right.y
  },
  {
    "editor.button.draw_random.x",
    &editor.button.draw_random.x
  },
  {
    "editor.button.draw_random.y",
    &editor.button.draw_random.y
  },
  {
    "editor.button.grab_brush.x",
    &editor.button.grab_brush.x
  },
  {
    "editor.button.grab_brush.y",
    &editor.button.grab_brush.y
  },
  {
    "editor.button.rotate_down.x",
    &editor.button.rotate_down.x
  },
  {
    "editor.button.rotate_down.y",
    &editor.button.rotate_down.y
  },
  {
    "editor.button.pick_element.x",
    &editor.button.pick_element.x
  },
  {
    "editor.button.pick_element.y",
    &editor.button.pick_element.y
  },
  {
    "editor.button.ce_copy_from.x",
    &editor.button.ce_copy_from.x
  },
  {
    "editor.button.ce_copy_from.y",
    &editor.button.ce_copy_from.y
  },
  {
    "editor.button.ce_copy_to.x",
    &editor.button.ce_copy_to.x
  },
  {
    "editor.button.ce_copy_to.y",
    &editor.button.ce_copy_to.y
  },
  {
    "editor.button.ce_swap.x",
    &editor.button.ce_swap.x
  },
  {
    "editor.button.ce_swap.y",
    &editor.button.ce_swap.y
  },
  {
    "editor.button.ce_copy.x",
    &editor.button.ce_copy.x
  },
  {
    "editor.button.ce_copy.y",
    &editor.button.ce_copy.y
  },
  {
    "editor.button.ce_paste.x",
    &editor.button.ce_paste.x
  },
  {
    "editor.button.ce_paste.y",
    &editor.button.ce_paste.y
  },
  {
    "editor.button.undo.x",
    &editor.button.undo.x
  },
  {
    "editor.button.undo.y",
    &editor.button.undo.y
  },
  {
    "editor.button.conf.x",
    &editor.button.conf.x
  },
  {
    "editor.button.conf.y",
    &editor.button.conf.y
  },
  {
    "editor.button.save.x",
    &editor.button.save.x
  },
  {
    "editor.button.save.y",
    &editor.button.save.y
  },
  {
    "editor.button.clear.x",
    &editor.button.clear.x
  },
  {
    "editor.button.clear.y",
    &editor.button.clear.y
  },
  {
    "editor.button.test.x",
    &editor.button.test.x
  },
  {
    "editor.button.test.y",
    &editor.button.test.y
  },
  {
    "editor.button.exit.x",
    &editor.button.exit.x
  },
  {
    "editor.button.exit.y",
    &editor.button.exit.y
  },
  {
    "editor.input.level_number.x",
    &editor.input.level_number.x
  },
  {
    "editor.input.level_number.y",
    &editor.input.level_number.y
  },
  {
    "editor.palette.x",
    &editor.palette.x
  },
  {
    "editor.palette.y",
    &editor.palette.y
  },
  {
    "editor.palette.cols",
    &editor.palette.cols
  },
  {
    "editor.palette.rows",
    &editor.palette.rows
  },
  {
    "editor.palette.tile_size",
    &editor.palette.tile_size
  },
  {
    "editor.palette.show_as_separate_screen",
    &editor.palette.show_as_separate_screen
  },
  {
    "editor.palette.show_on_element_buttons",
    &editor.palette.show_on_element_buttons
  },
  {
    "editor.palette.element_left.x",
    &editor.palette.element_left.x
  },
  {
    "editor.palette.element_left.y",
    &editor.palette.element_left.y
  },
  {
    "editor.palette.element_left.tile_size",
    &editor.palette.element_left.tile_size
  },
  {
    "editor.palette.element_middle.x",
    &editor.palette.element_middle.x
  },
  {
    "editor.palette.element_middle.y",
    &editor.palette.element_middle.y
  },
  {
    "editor.palette.element_middle.tile_size",
    &editor.palette.element_middle.tile_size
  },
  {
    "editor.palette.element_right.x",
    &editor.palette.element_right.x
  },
  {
    "editor.palette.element_right.y",
    &editor.palette.element_right.y
  },
  {
    "editor.palette.element_right.tile_size",
    &editor.palette.element_right.tile_size
  },
  {
    "editor.drawingarea.tile_size",
    &editor.drawingarea.tile_size
  },
  {
    "editor.settings.headline.x",
    &editor.settings.headline.x
  },
  {
    "editor.settings.headline.y",
    &editor.settings.headline.y
  },
  {
    "editor.settings.headline.align",
    &editor.settings.headline.align
  },
  {
    "editor.settings.element_graphic.x",
    &editor.settings.element_graphic.x
  },
  {
    "editor.settings.element_graphic.y",
    &editor.settings.element_graphic.y
  },
  {
    "editor.settings.element_name.x",
    &editor.settings.element_name.x
  },
  {
    "editor.settings.element_name.y",
    &editor.settings.element_name.y
  },
  {
    "editor.settings.tabs.x",
    &editor.settings.tabs.x
  },
  {
    "editor.settings.tabs.y",
    &editor.settings.tabs.y
  },
  {
    "editor.settings.tabs.2nd_yoffset",
    &editor.settings.tabs.yoffset2
  },
  {
    "editor.settings.tabs.draw_xoffset",
    &editor.settings.tabs.draw_xoffset
  },
  {
    "editor.settings.tabs.draw_yoffset",
    &editor.settings.tabs.draw_yoffset
  },
  {
    "editor.settings.tooltip.x",
    &editor.settings.tooltip.x
  },
  {
    "editor.settings.tooltip.y",
    &editor.settings.tooltip.y
  },
  {
    "editor.gadget.normal_spacing",
    &editor.gadget.normal_spacing
  },
  {
    "editor.gadget.small_spacing",
    &editor.gadget.small_spacing
  },
  {
    "editor.gadget.tiny_spacing",
    &editor.gadget.tiny_spacing
  },
  {
    "editor.gadget.line_spacing",
    &editor.gadget.line_spacing
  },
  {
    "editor.gadget.text_spacing",
    &editor.gadget.text_spacing
  },
  {
    "editor.gadget.separator_line.height",
    &editor.gadget.separator_line.height
  },
  {
    "request.button.yes.x",
    &request.button.yes.x
  },
  {
    "request.button.yes.y",
    &request.button.yes.y
  },
  {
    "request.button.no.x",
    &request.button.no.x
  },
  {
    "request.button.no.y",
    &request.button.no.y
  },
  {
    "request.button.confirm.x",
    &request.button.confirm.x
  },
  {
    "request.button.confirm.y",
    &request.button.confirm.y
  },
  {
    "request.button.player_1.x",
    &request.button.player_1.x
  },
  {
    "request.button.player_1.y",
    &request.button.player_1.y
  },
  {
    "request.button.player_1.draw_player",
    &request.button.player_1.draw_player
  },
  {
    "request.button.player_1.tile_size",
    &request.button.player_1.size
  },
  {
    "request.button.player_2.x",
    &request.button.player_2.x
  },
  {
    "request.button.player_2.y",
    &request.button.player_2.y
  },
  {
    "request.button.player_2.draw_player",
    &request.button.player_2.draw_player
  },
  {
    "request.button.player_2.tile_size",
    &request.button.player_2.size
  },
  {
    "request.button.player_3.x",
    &request.button.player_3.x
  },
  {
    "request.button.player_3.y",
    &request.button.player_3.y
  },
  {
    "request.button.player_3.draw_player",
    &request.button.player_3.draw_player
  },
  {
    "request.button.player_3.tile_size",
    &request.button.player_3.size
  },
  {
    "request.button.player_4.x",
    &request.button.player_4.x
  },
  {
    "request.button.player_4.y",
    &request.button.player_4.y
  },
  {
    "request.button.player_4.draw_player",
    &request.button.player_4.draw_player
  },
  {
    "request.button.player_4.tile_size",
    &request.button.player_4.size
  },
  {
    "request.button.touch_yes.x",
    &request.button.touch_yes.x
  },
  {
    "request.button.touch_yes.y",
    &request.button.touch_yes.y
  },
  {
    "request.button.touch_no.x",
    &request.button.touch_no.x
  },
  {
    "request.button.touch_no.y",
    &request.button.touch_no.y
  },
  {
    "request.button.touch_confirm.x",
    &request.button.touch_confirm.x
  },
  {
    "request.button.touch_confirm.y",
    &request.button.touch_confirm.y
  },
  {
    "request.x",
    &request.x
  },
  {
    "request.y",
    &request.y
  },
  {
    "request.width",
    &request.width
  },
  {
    "request.height",
    &request.height
  },
  {
    "request.border_size",
    &request.border_size
  },
  {
    "request.line_spacing",
    &request.line_spacing
  },
  {
    "request.step_offset",
    &request.step_offset
  },
  {
    "request.step_delay",
    &request.step_delay
  },
  {
    "request.anim_mode",
    &request.anim_mode
  },
  {
    "request.align",
    &request.align
  },
  {
    "request.valign",
    &request.valign
  },
  {
    "request.draw_order",
    &request.sort_priority
  },
  {
    "request.autowrap",
    &request.autowrap
  },
  {
    "request.centered",
    &request.centered
  },
  {
    "request.wrap_single_words",
    &request.wrap_single_words
  },
  {
    "global.use_envelope_request",
    &global.use_envelope_request
  },
  {
    "game.graphics_engine_version",
    &game.graphics_engine_version
  },
  {
    "game.forced_scroll_delay_value",
    &game.forced_scroll_delay_value
  },
  {
    "game.use_native_emc_graphics_engine",
    &game.use_native_emc_graphics_engine
  },
  {
    "game.use_native_sp_graphics_engine",
    &game.use_native_sp_graphics_engine
  },
  {
    "game.use_masked_pushing",
    &game.use_masked_pushing
  },
  {
    "game.tile_size",
    &game.tile_size
  },
  {
    "[player].boring_delay_fixed",
    &game.player_boring_delay_fixed
  },
  {
    "[player].boring_delay_random",
    &game.player_boring_delay_random
  },
  {
    "[player].sleeping_delay_fixed",
    &game.player_sleeping_delay_fixed
  },
  {
    "[player].sleeping_delay_random",
    &game.player_sleeping_delay_random
  },
  {
    "viewport.window.width",
    &viewport.window[GFX_SPECIAL_ARG_DEFAULT].width
  },
  {
    "viewport.window.height",
    &viewport.window[GFX_SPECIAL_ARG_DEFAULT].height
  },
  {
    "viewport.window.min_width",
    &viewport.window[GFX_SPECIAL_ARG_DEFAULT].min_width
  },
  {
    "viewport.window.min_height",
    &viewport.window[GFX_SPECIAL_ARG_DEFAULT].min_height
  },
  {
    "viewport.window.max_width",
    &viewport.window[GFX_SPECIAL_ARG_DEFAULT].max_width
  },
  {
    "viewport.window.max_height",
    &viewport.window[GFX_SPECIAL_ARG_DEFAULT].max_height
  },
  {
    "viewport.window.TITLE.width",
    &viewport.window[GFX_SPECIAL_ARG_TITLE].width
  },
  {
    "viewport.window.TITLE.height",
    &viewport.window[GFX_SPECIAL_ARG_TITLE].height
  },
  {
    "viewport.playfield.x",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].x
  },
  {
    "viewport.playfield.y",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].y
  },
  {
    "viewport.playfield.width",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].width
  },
  {
    "viewport.playfield.height",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].height
  },
  {
    "viewport.playfield.min_width",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].min_width
  },
  {
    "viewport.playfield.min_height",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].min_height
  },
  {
    "viewport.playfield.max_width",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].max_width
  },
  {
    "viewport.playfield.max_height",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].max_height
  },
  {
    "viewport.playfield.margin_left",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].margin_left
  },
  {
    "viewport.playfield.margin_right",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].margin_right
  },
  {
    "viewport.playfield.margin_top",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].margin_top
  },
  {
    "viewport.playfield.margin_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].margin_bottom
  },
  {
    "viewport.playfield.border_left",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].border_left
  },
  {
    "viewport.playfield.border_right",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].border_right
  },
  {
    "viewport.playfield.border_top",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].border_top
  },
  {
    "viewport.playfield.border_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].border_bottom
  },
  {
    "viewport.playfield.border_size",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].border_size
  },
  {
    "viewport.playfield.align_size",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].align_size
  },
  {
    "viewport.playfield.align",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].align
  },
  {
    "viewport.playfield.valign",
    &viewport.playfield[GFX_SPECIAL_ARG_DEFAULT].valign
  },
  {
    "viewport.playfield.MAIN.x",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].x
  },
  {
    "viewport.playfield.MAIN.y",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].y
  },
  {
    "viewport.playfield.MAIN.width",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].width
  },
  {
    "viewport.playfield.MAIN.height",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].height
  },
  {
    "viewport.playfield.MAIN.min_width",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].min_width
  },
  {
    "viewport.playfield.MAIN.min_height",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].min_height
  },
  {
    "viewport.playfield.MAIN.max_width",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].max_width
  },
  {
    "viewport.playfield.MAIN.max_height",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].max_height
  },
  {
    "viewport.playfield.MAIN.margin_left",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].margin_left
  },
  {
    "viewport.playfield.MAIN.margin_right",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].margin_right
  },
  {
    "viewport.playfield.MAIN.margin_top",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].margin_top
  },
  {
    "viewport.playfield.MAIN.margin_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].margin_bottom
  },
  {
    "viewport.playfield.MAIN.border_left",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].border_left
  },
  {
    "viewport.playfield.MAIN.border_right",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].border_right
  },
  {
    "viewport.playfield.MAIN.border_top",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].border_top
  },
  {
    "viewport.playfield.MAIN.border_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].border_bottom
  },
  {
    "viewport.playfield.MAIN.border_size",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].border_size
  },
  {
    "viewport.playfield.MAIN.align_size",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].align_size
  },
  {
    "viewport.playfield.MAIN.align",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].align
  },
  {
    "viewport.playfield.MAIN.valign",
    &viewport.playfield[GFX_SPECIAL_ARG_MAIN].valign
  },
  {
    "viewport.playfield.SCORES.x",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].x
  },
  {
    "viewport.playfield.SCORES.y",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].y
  },
  {
    "viewport.playfield.SCORES.width",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].width
  },
  {
    "viewport.playfield.SCORES.height",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].height
  },
  {
    "viewport.playfield.SCORES.min_width",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].min_width
  },
  {
    "viewport.playfield.SCORES.min_height",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].min_height
  },
  {
    "viewport.playfield.SCORES.max_width",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].max_width
  },
  {
    "viewport.playfield.SCORES.max_height",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].max_height
  },
  {
    "viewport.playfield.SCORES.margin_left",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].margin_left
  },
  {
    "viewport.playfield.SCORES.margin_right",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].margin_right
  },
  {
    "viewport.playfield.SCORES.margin_top",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].margin_top
  },
  {
    "viewport.playfield.SCORES.margin_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].margin_bottom
  },
  {
    "viewport.playfield.SCORES.border_left",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].border_left
  },
  {
    "viewport.playfield.SCORES.border_right",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].border_right
  },
  {
    "viewport.playfield.SCORES.border_top",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].border_top
  },
  {
    "viewport.playfield.SCORES.border_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].border_bottom
  },
  {
    "viewport.playfield.SCORES.border_size",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].border_size
  },
  {
    "viewport.playfield.SCORES.align_size",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].align_size
  },
  {
    "viewport.playfield.SCORES.align",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].align
  },
  {
    "viewport.playfield.SCORES.valign",
    &viewport.playfield[GFX_SPECIAL_ARG_SCORES].valign
  },
  {
    "viewport.playfield.EDITOR.x",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].x
  },
  {
    "viewport.playfield.EDITOR.y",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].y
  },
  {
    "viewport.playfield.EDITOR.width",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].width
  },
  {
    "viewport.playfield.EDITOR.height",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].height
  },
  {
    "viewport.playfield.EDITOR.min_width",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].min_width
  },
  {
    "viewport.playfield.EDITOR.min_height",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].min_height
  },
  {
    "viewport.playfield.EDITOR.max_width",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].max_width
  },
  {
    "viewport.playfield.EDITOR.max_height",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].max_height
  },
  {
    "viewport.playfield.EDITOR.margin_left",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].margin_left
  },
  {
    "viewport.playfield.EDITOR.margin_right",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].margin_right
  },
  {
    "viewport.playfield.EDITOR.margin_top",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].margin_top
  },
  {
    "viewport.playfield.EDITOR.margin_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].margin_bottom
  },
  {
    "viewport.playfield.EDITOR.border_left",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].border_left
  },
  {
    "viewport.playfield.EDITOR.border_right",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].border_right
  },
  {
    "viewport.playfield.EDITOR.border_top",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].border_top
  },
  {
    "viewport.playfield.EDITOR.border_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].border_bottom
  },
  {
    "viewport.playfield.EDITOR.border_size",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].border_size
  },
  {
    "viewport.playfield.EDITOR.align_size",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].align_size
  },
  {
    "viewport.playfield.EDITOR.align",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].align
  },
  {
    "viewport.playfield.EDITOR.valign",
    &viewport.playfield[GFX_SPECIAL_ARG_EDITOR].valign
  },
  {
    "viewport.playfield.PLAYING.x",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].x
  },
  {
    "viewport.playfield.PLAYING.y",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].y
  },
  {
    "viewport.playfield.PLAYING.width",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].width
  },
  {
    "viewport.playfield.PLAYING.height",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].height
  },
  {
    "viewport.playfield.PLAYING.min_width",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].min_width
  },
  {
    "viewport.playfield.PLAYING.min_height",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].min_height
  },
  {
    "viewport.playfield.PLAYING.max_width",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].max_width
  },
  {
    "viewport.playfield.PLAYING.max_height",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].max_height
  },
  {
    "viewport.playfield.PLAYING.margin_left",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].margin_left
  },
  {
    "viewport.playfield.PLAYING.margin_right",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].margin_right
  },
  {
    "viewport.playfield.PLAYING.margin_top",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].margin_top
  },
  {
    "viewport.playfield.PLAYING.margin_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].margin_bottom
  },
  {
    "viewport.playfield.PLAYING.border_left",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].border_left
  },
  {
    "viewport.playfield.PLAYING.border_right",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].border_right
  },
  {
    "viewport.playfield.PLAYING.border_top",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].border_top
  },
  {
    "viewport.playfield.PLAYING.border_bottom",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].border_bottom
  },
  {
    "viewport.playfield.PLAYING.border_size",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].border_size
  },
  {
    "viewport.playfield.PLAYING.align_size",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].align_size
  },
  {
    "viewport.playfield.PLAYING.align",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].align
  },
  {
    "viewport.playfield.PLAYING.valign",
    &viewport.playfield[GFX_SPECIAL_ARG_PLAYING].valign
  },
  {
    "viewport.door_1.x",
    &viewport.door_1[GFX_SPECIAL_ARG_DEFAULT].x
  },
  {
    "viewport.door_1.y",
    &viewport.door_1[GFX_SPECIAL_ARG_DEFAULT].y
  },
  {
    "viewport.door_1.width",
    &viewport.door_1[GFX_SPECIAL_ARG_DEFAULT].width
  },
  {
    "viewport.door_1.height",
    &viewport.door_1[GFX_SPECIAL_ARG_DEFAULT].height
  },
  {
    "viewport.door_1.border_size",
    &viewport.door_1[GFX_SPECIAL_ARG_DEFAULT].border_size
  },
  {
    "viewport.door_1.align",
    &viewport.door_1[GFX_SPECIAL_ARG_DEFAULT].align
  },
  {
    "viewport.door_1.valign",
    &viewport.door_1[GFX_SPECIAL_ARG_DEFAULT].valign
  },
  {
    "viewport.door_1.MAIN.x",
    &viewport.door_1[GFX_SPECIAL_ARG_MAIN].x
  },
  {
    "viewport.door_1.MAIN.y",
    &viewport.door_1[GFX_SPECIAL_ARG_MAIN].y
  },
  {
    "viewport.door_1.MAIN.width",
    &viewport.door_1[GFX_SPECIAL_ARG_MAIN].width
  },
  {
    "viewport.door_1.MAIN.height",
    &viewport.door_1[GFX_SPECIAL_ARG_MAIN].height
  },
  {
    "viewport.door_1.MAIN.border_size",
    &viewport.door_1[GFX_SPECIAL_ARG_MAIN].border_size
  },
  {
    "viewport.door_1.MAIN.align",
    &viewport.door_1[GFX_SPECIAL_ARG_MAIN].align
  },
  {
    "viewport.door_1.MAIN.valign",
    &viewport.door_1[GFX_SPECIAL_ARG_MAIN].valign
  },
  {
    "viewport.door_1.SCORES.x",
    &viewport.door_1[GFX_SPECIAL_ARG_SCORES].x
  },
  {
    "viewport.door_1.SCORES.y",
    &viewport.door_1[GFX_SPECIAL_ARG_SCORES].y
  },
  {
    "viewport.door_1.SCORES.width",
    &viewport.door_1[GFX_SPECIAL_ARG_SCORES].width
  },
  {
    "viewport.door_1.SCORES.height",
    &viewport.door_1[GFX_SPECIAL_ARG_SCORES].height
  },
  {
    "viewport.door_1.SCORES.border_size",
    &viewport.door_1[GFX_SPECIAL_ARG_SCORES].border_size
  },
  {
    "viewport.door_1.SCORES.align",
    &viewport.door_1[GFX_SPECIAL_ARG_SCORES].align
  },
  {
    "viewport.door_1.SCORES.valign",
    &viewport.door_1[GFX_SPECIAL_ARG_SCORES].valign
  },
  {
    "viewport.door_1.EDITOR.x",
    &viewport.door_1[GFX_SPECIAL_ARG_EDITOR].x
  },
  {
    "viewport.door_1.EDITOR.y",
    &viewport.door_1[GFX_SPECIAL_ARG_EDITOR].y
  },
  {
    "viewport.door_1.EDITOR.width",
    &viewport.door_1[GFX_SPECIAL_ARG_EDITOR].width
  },
  {
    "viewport.door_1.EDITOR.height",
    &viewport.door_1[GFX_SPECIAL_ARG_EDITOR].height
  },
  {
    "viewport.door_1.EDITOR.border_size",
    &viewport.door_1[GFX_SPECIAL_ARG_EDITOR].border_size
  },
  {
    "viewport.door_1.EDITOR.align",
    &viewport.door_1[GFX_SPECIAL_ARG_EDITOR].align
  },
  {
    "viewport.door_1.EDITOR.valign",
    &viewport.door_1[GFX_SPECIAL_ARG_EDITOR].valign
  },
  {
    "viewport.door_1.PLAYING.x",
    &viewport.door_1[GFX_SPECIAL_ARG_PLAYING].x
  },
  {
    "viewport.door_1.PLAYING.y",
    &viewport.door_1[GFX_SPECIAL_ARG_PLAYING].y
  },
  {
    "viewport.door_1.PLAYING.width",
    &viewport.door_1[GFX_SPECIAL_ARG_PLAYING].width
  },
  {
    "viewport.door_1.PLAYING.height",
    &viewport.door_1[GFX_SPECIAL_ARG_PLAYING].height
  },
  {
    "viewport.door_1.PLAYING.border_size",
    &viewport.door_1[GFX_SPECIAL_ARG_PLAYING].border_size
  },
  {
    "viewport.door_1.PLAYING.align",
    &viewport.door_1[GFX_SPECIAL_ARG_PLAYING].align
  },
  {
    "viewport.door_1.PLAYING.valign",
    &viewport.door_1[GFX_SPECIAL_ARG_PLAYING].valign
  },
  {
    "viewport.door_2.x",
    &viewport.door_2[GFX_SPECIAL_ARG_DEFAULT].x
  },
  {
    "viewport.door_2.y",
    &viewport.door_2[GFX_SPECIAL_ARG_DEFAULT].y
  },
  {
    "viewport.door_2.width",
    &viewport.door_2[GFX_SPECIAL_ARG_DEFAULT].width
  },
  {
    "viewport.door_2.height",
    &viewport.door_2[GFX_SPECIAL_ARG_DEFAULT].height
  },
  {
    "viewport.door_2.border_size",
    &viewport.door_2[GFX_SPECIAL_ARG_DEFAULT].border_size
  },
  {
    "viewport.door_2.align",
    &viewport.door_2[GFX_SPECIAL_ARG_DEFAULT].align
  },
  {
    "viewport.door_2.valign",
    &viewport.door_2[GFX_SPECIAL_ARG_DEFAULT].valign
  },
  {
    "viewport.door_2.MAIN.x",
    &viewport.door_2[GFX_SPECIAL_ARG_MAIN].x
  },
  {
    "viewport.door_2.MAIN.y",
    &viewport.door_2[GFX_SPECIAL_ARG_MAIN].y
  },
  {
    "viewport.door_2.MAIN.width",
    &viewport.door_2[GFX_SPECIAL_ARG_MAIN].width
  },
  {
    "viewport.door_2.MAIN.height",
    &viewport.door_2[GFX_SPECIAL_ARG_MAIN].height
  },
  {
    "viewport.door_2.MAIN.border_size",
    &viewport.door_2[GFX_SPECIAL_ARG_MAIN].border_size
  },
  {
    "viewport.door_2.MAIN.align",
    &viewport.door_2[GFX_SPECIAL_ARG_MAIN].align
  },
  {
    "viewport.door_2.MAIN.valign",
    &viewport.door_2[GFX_SPECIAL_ARG_MAIN].valign
  },
  {
    "viewport.door_2.SCORES.x",
    &viewport.door_2[GFX_SPECIAL_ARG_SCORES].x
  },
  {
    "viewport.door_2.SCORES.y",
    &viewport.door_2[GFX_SPECIAL_ARG_SCORES].y
  },
  {
    "viewport.door_2.SCORES.width",
    &viewport.door_2[GFX_SPECIAL_ARG_SCORES].width
  },
  {
    "viewport.door_2.SCORES.height",
    &viewport.door_2[GFX_SPECIAL_ARG_SCORES].height
  },
  {
    "viewport.door_2.SCORES.border_size",
    &viewport.door_2[GFX_SPECIAL_ARG_SCORES].border_size
  },
  {
    "viewport.door_2.SCORES.align",
    &viewport.door_2[GFX_SPECIAL_ARG_SCORES].align
  },
  {
    "viewport.door_2.SCORES.valign",
    &viewport.door_2[GFX_SPECIAL_ARG_SCORES].valign
  },
  {
    "viewport.door_2.EDITOR.x",
    &viewport.door_2[GFX_SPECIAL_ARG_EDITOR].x
  },
  {
    "viewport.door_2.EDITOR.y",
    &viewport.door_2[GFX_SPECIAL_ARG_EDITOR].y
  },
  {
    "viewport.door_2.EDITOR.width",
    &viewport.door_2[GFX_SPECIAL_ARG_EDITOR].width
  },
  {
    "viewport.door_2.EDITOR.height",
    &viewport.door_2[GFX_SPECIAL_ARG_EDITOR].height
  },
  {
    "viewport.door_2.EDITOR.border_size",
    &viewport.door_2[GFX_SPECIAL_ARG_EDITOR].border_size
  },
  {
    "viewport.door_2.EDITOR.align",
    &viewport.door_2[GFX_SPECIAL_ARG_EDITOR].align
  },
  {
    "viewport.door_2.EDITOR.valign",
    &viewport.door_2[GFX_SPECIAL_ARG_EDITOR].valign
  },
  {
    "viewport.door_2.PLAYING.x",
    &viewport.door_2[GFX_SPECIAL_ARG_PLAYING].x
  },
  {
    "viewport.door_2.PLAYING.y",
    &viewport.door_2[GFX_SPECIAL_ARG_PLAYING].y
  },
  {
    "viewport.door_2.PLAYING.width",
    &viewport.door_2[GFX_SPECIAL_ARG_PLAYING].width
  },
  {
    "viewport.door_2.PLAYING.height",
    &viewport.door_2[GFX_SPECIAL_ARG_PLAYING].height
  },
  {
    "viewport.door_2.PLAYING.border_size",
    &viewport.door_2[GFX_SPECIAL_ARG_PLAYING].border_size
  },
  {
    "viewport.door_2.PLAYING.align",
    &viewport.door_2[GFX_SPECIAL_ARG_PLAYING].align
  },
  {
    "viewport.door_2.PLAYING.valign",
    &viewport.door_2[GFX_SPECIAL_ARG_PLAYING].valign
  },
  {
    NULL,
    NULL
  },
};

#endif	// CONF_VAR_C
